/* Generated by Cython 0.27.3 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "depends": [
            "yt/utilities/lib/platform_dep.h"
        ],
        "include_dirs": [
            "yt/utilities/lib"
        ],
        "libraries": [
            "m"
        ],
        "name": "yt.utilities.lib.basic_octree",
        "sources": [
            "yt/utilities/lib/basic_octree.pyx"
        ]
    },
    "module_name": "yt.utilities.lib.basic_octree"
}
END: Cython Metadata */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_27_3"
#define CYTHON_FUTURE_DIVISION 0
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (0 && PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#if PY_VERSION_HEX < 0x030700A0 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject **args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject **args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : PyInstanceMethod_New(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif


#define __PYX_ERR(f_index, lineno, Ln_error) \
{ \
  __pyx_filename = __pyx_f[f_index]; __pyx_lineno = lineno; __pyx_clineno = __LINE__; goto Ln_error; \
}

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__yt__utilities__lib__basic_octree
#define __PYX_HAVE_API__yt__utilities__lib__basic_octree
#include <string.h>
#include <stdio.h>
#include "numpy/arrayobject.h"
#include "numpy/ufuncobject.h"
#include <stdlib.h>
#include "platform_dep.h"
#include "math.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
#define __Pyx_PyBool_FromLong(b) ((b) ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False))
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c));
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;

/* Header.proto */
#if !defined(CYTHON_CCOMPLEX)
  #if defined(__cplusplus)
    #define CYTHON_CCOMPLEX 1
  #elif defined(_Complex_I)
    #define CYTHON_CCOMPLEX 1
  #else
    #define CYTHON_CCOMPLEX 0
  #endif
#endif
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #include <complex>
  #else
    #include <complex.h>
  #endif
#endif
#if CYTHON_CCOMPLEX && !defined(__cplusplus) && defined(__sun__) && defined(__GNUC__)
  #undef _Complex_I
  #define _Complex_I 1.0fj
#endif


static const char *__pyx_f[] = {
  "yt/utilities/lib/basic_octree.pyx",
  "stringsource",
  "__init__.pxd",
  "type.pxd",
};
/* BufferFormatStructs.proto */
#define IS_UNSIGNED(type) (((type) -1) > 0)
struct __Pyx_StructField_;
#define __PYX_BUF_FLAGS_PACKED_STRUCT (1 << 0)
typedef struct {
  const char* name;
  struct __Pyx_StructField_* fields;
  size_t size;
  size_t arraysize[8];
  int ndim;
  char typegroup;
  char is_unsigned;
  int flags;
} __Pyx_TypeInfo;
typedef struct __Pyx_StructField_ {
  __Pyx_TypeInfo* type;
  const char* name;
  size_t offset;
} __Pyx_StructField;
typedef struct {
  __Pyx_StructField* field;
  size_t parent_offset;
} __Pyx_BufFmt_StackElem;
typedef struct {
  __Pyx_StructField root;
  __Pyx_BufFmt_StackElem* head;
  size_t fmt_offset;
  size_t new_count, enc_count;
  size_t struct_alignment;
  int is_complex;
  char enc_type;
  char new_packmode;
  char enc_packmode;
  char is_valid_array;
} __Pyx_BufFmt_Context;


/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":743
 * # in Cython to enable them only on the right systems.
 * 
 * ctypedef npy_int8       int8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 */
typedef npy_int8 __pyx_t_5numpy_int8_t;

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":744
 * 
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t
 */
typedef npy_int16 __pyx_t_5numpy_int16_t;

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":745
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int64      int64_t
 * #ctypedef npy_int96      int96_t
 */
typedef npy_int32 __pyx_t_5numpy_int32_t;

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":746
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_int96      int96_t
 * #ctypedef npy_int128     int128_t
 */
typedef npy_int64 __pyx_t_5numpy_int64_t;

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":750
 * #ctypedef npy_int128     int128_t
 * 
 * ctypedef npy_uint8      uint8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 */
typedef npy_uint8 __pyx_t_5numpy_uint8_t;

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":751
 * 
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t
 */
typedef npy_uint16 __pyx_t_5numpy_uint16_t;

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":752
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint64     uint64_t
 * #ctypedef npy_uint96     uint96_t
 */
typedef npy_uint32 __pyx_t_5numpy_uint32_t;

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":753
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_uint96     uint96_t
 * #ctypedef npy_uint128    uint128_t
 */
typedef npy_uint64 __pyx_t_5numpy_uint64_t;

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":757
 * #ctypedef npy_uint128    uint128_t
 * 
 * ctypedef npy_float32    float32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_float64    float64_t
 * #ctypedef npy_float80    float80_t
 */
typedef npy_float32 __pyx_t_5numpy_float32_t;

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":758
 * 
 * ctypedef npy_float32    float32_t
 * ctypedef npy_float64    float64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_float80    float80_t
 * #ctypedef npy_float128   float128_t
 */
typedef npy_float64 __pyx_t_5numpy_float64_t;

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":767
 * # The int types are mapped a bit surprising --
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longlong   long_t
 * ctypedef npy_longlong   longlong_t
 */
typedef npy_long __pyx_t_5numpy_int_t;

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":768
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t
 * ctypedef npy_longlong   long_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longlong   longlong_t
 * 
 */
typedef npy_longlong __pyx_t_5numpy_long_t;

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":769
 * ctypedef npy_long       int_t
 * ctypedef npy_longlong   long_t
 * ctypedef npy_longlong   longlong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_ulong      uint_t
 */
typedef npy_longlong __pyx_t_5numpy_longlong_t;

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":771
 * ctypedef npy_longlong   longlong_t
 * 
 * ctypedef npy_ulong      uint_t             # <<<<<<<<<<<<<<
 * ctypedef npy_ulonglong  ulong_t
 * ctypedef npy_ulonglong  ulonglong_t
 */
typedef npy_ulong __pyx_t_5numpy_uint_t;

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":772
 * 
 * ctypedef npy_ulong      uint_t
 * ctypedef npy_ulonglong  ulong_t             # <<<<<<<<<<<<<<
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 */
typedef npy_ulonglong __pyx_t_5numpy_ulong_t;

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":773
 * ctypedef npy_ulong      uint_t
 * ctypedef npy_ulonglong  ulong_t
 * ctypedef npy_ulonglong  ulonglong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_intp       intp_t
 */
typedef npy_ulonglong __pyx_t_5numpy_ulonglong_t;

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":775
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 * ctypedef npy_intp       intp_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uintp      uintp_t
 * 
 */
typedef npy_intp __pyx_t_5numpy_intp_t;

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":776
 * 
 * ctypedef npy_intp       intp_t
 * ctypedef npy_uintp      uintp_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_double     float_t
 */
typedef npy_uintp __pyx_t_5numpy_uintp_t;

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":778
 * ctypedef npy_uintp      uintp_t
 * 
 * ctypedef npy_double     float_t             # <<<<<<<<<<<<<<
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t
 */
typedef npy_double __pyx_t_5numpy_float_t;

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":779
 * 
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longdouble longdouble_t
 * 
 */
typedef npy_double __pyx_t_5numpy_double_t;

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":780
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cfloat      cfloat_t
 */
typedef npy_longdouble __pyx_t_5numpy_longdouble_t;
/* Declarations.proto */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    typedef ::std::complex< float > __pyx_t_float_complex;
  #else
    typedef float _Complex __pyx_t_float_complex;
  #endif
#else
    typedef struct { float real, imag; } __pyx_t_float_complex;
#endif
static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float, float);

/* Declarations.proto */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    typedef ::std::complex< double > __pyx_t_double_complex;
  #else
    typedef double _Complex __pyx_t_double_complex;
  #endif
#else
    typedef struct { double real, imag; } __pyx_t_double_complex;
#endif
static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double, double);


/*--- Type declarations ---*/
struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree;

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":782
 * ctypedef npy_longdouble longdouble_t
 * 
 * ctypedef npy_cfloat      cfloat_t             # <<<<<<<<<<<<<<
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t
 */
typedef npy_cfloat __pyx_t_5numpy_cfloat_t;

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":783
 * 
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t             # <<<<<<<<<<<<<<
 * ctypedef npy_clongdouble clongdouble_t
 * 
 */
typedef npy_cdouble __pyx_t_5numpy_cdouble_t;

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":784
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cdouble     complex_t
 */
typedef npy_clongdouble __pyx_t_5numpy_clongdouble_t;

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":786
 * ctypedef npy_clongdouble clongdouble_t
 * 
 * ctypedef npy_cdouble     complex_t             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 */
typedef npy_cdouble __pyx_t_5numpy_complex_t;
struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode;
struct __pyx_opt_args_2yt_9utilities_3lib_12basic_octree_OTN_refine;
struct __pyx_opt_args_2yt_9utilities_3lib_12basic_octree_OTN_initialize;

/* "yt/utilities/lib/basic_octree.pyx":39
 *     return f1
 * 
 * cdef struct OctreeNode:             # <<<<<<<<<<<<<<
 *     np.float64_t *val
 *     np.float64_t weight_val
 */
struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode {
  __pyx_t_5numpy_float64_t *val;
  __pyx_t_5numpy_float64_t weight_val;
  __pyx_t_5numpy_int64_t pos[3];
  int level;
  int nvals;
  int max_level;
  struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *children[2][2][2];
  struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *parent;
  struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *next;
  struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *up_next;
};

/* "yt/utilities/lib/basic_octree.pyx":60
 *         self.max_level = imax(self.max_level, level)
 * 
 * cdef void OTN_refine(OctreeNode *self, int incremental = 0):             # <<<<<<<<<<<<<<
 *     cdef int i, j, k
 *     cdef np.int64_t npos[3]
 */
struct __pyx_opt_args_2yt_9utilities_3lib_12basic_octree_OTN_refine {
  int __pyx_n;
  int incremental;
};

/* "yt/utilities/lib/basic_octree.pyx":78
 *     self.weight_val = 0.0
 * 
 * cdef OctreeNode *OTN_initialize(np.int64_t pos[3], int nvals,             # <<<<<<<<<<<<<<
 *                         np.float64_t *val, np.float64_t weight_val,
 *                         int level, OctreeNode *parent, int incremental = 0):
 */
struct __pyx_opt_args_2yt_9utilities_3lib_12basic_octree_OTN_initialize {
  int __pyx_n;
  int incremental;
};

/* "yt/utilities/lib/basic_octree.pyx":119
 *     free(node)
 * 
 * cdef class Octree:             # <<<<<<<<<<<<<<
 *     cdef int nvals
 *     cdef np.int64_t po2[80]
 */
struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree {
  PyObject_HEAD
  struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_vtab;
  int nvals;
  __pyx_t_5numpy_int64_t po2[80];
  struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode ****root_nodes;
  __pyx_t_5numpy_int64_t top_grid_dims[3];
  int incremental;
  __pyx_t_5numpy_float64_t opening_angle;
  __pyx_t_5numpy_float64_t dist;
  __pyx_t_5numpy_float64_t root_dx[3];
  struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *last_node;
};



struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree {
  void (*add_to_position)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, int, __pyx_t_5numpy_int64_t *, __pyx_t_5numpy_float64_t *, __pyx_t_5numpy_float64_t, PyObject *);
  struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *(*find_on_root_level)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, __pyx_t_5numpy_int64_t *, int);
  int (*count_at_level)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *, int);
  int (*fill_from_level)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *, int, __pyx_t_5numpy_int64_t, __pyx_t_5numpy_int64_t *, __pyx_t_5numpy_float64_t *, __pyx_t_5numpy_float64_t *);
  __pyx_t_5numpy_float64_t (*fbe_node_separation)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *);
  __pyx_t_5numpy_float64_t (*fbe_opening_angle)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *);
  void (*set_next)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *, int);
  void (*set_up_next)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *);
  __pyx_t_5numpy_float64_t (*fbe_main)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, __pyx_t_5numpy_float64_t, int, __pyx_t_5numpy_float64_t);
  int (*node_ID)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *);
  int (*node_ID_on_level)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *);
  void (*print_node_info)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *);
  void (*iterate_print_nodes)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *);
};
static struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_vtabptr_2yt_9utilities_3lib_12basic_octree_Octree;

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely((Py_TYPE(obj) == type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* IsLittleEndian.proto */
static CYTHON_INLINE int __Pyx_Is_Little_Endian(void);

/* BufferFormatCheck.proto */
static const char* __Pyx_BufFmt_CheckString(__Pyx_BufFmt_Context* ctx, const char* ts);
static void __Pyx_BufFmt_Init(__Pyx_BufFmt_Context* ctx,
                              __Pyx_BufFmt_StackElem* stack,
                              __Pyx_TypeInfo* type);

/* BufferGetAndValidate.proto */
#define __Pyx_GetBufferAndValidate(buf, obj, dtype, flags, nd, cast, stack)\
    ((obj == Py_None || obj == NULL) ?\
    (__Pyx_ZeroBuffer(buf), 0) :\
    __Pyx__GetBufferAndValidate(buf, obj, dtype, flags, nd, cast, stack))
static int  __Pyx__GetBufferAndValidate(Py_buffer* buf, PyObject* obj,
    __Pyx_TypeInfo* dtype, int flags, int nd, int cast, __Pyx_BufFmt_StackElem* stack);
static void __Pyx_ZeroBuffer(Py_buffer* buf);
static CYTHON_INLINE void __Pyx_SafeReleaseBuffer(Py_buffer* info);
static Py_ssize_t __Pyx_minusones[] = { -1, -1, -1, -1, -1, -1, -1, -1 };
static Py_ssize_t __Pyx_zeros[] = { 0, 0, 0, 0, 0, 0, 0, 0 };

/* BufferIndexError.proto */
static void __Pyx_RaiseBufferIndexError(int axis);

#define __Pyx_BufPtrStrided1d(type, buf, i0, s0) (type)((char*)buf + i0 * s0)
/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* WriteUnraisableException.proto */
static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback, int nogil);

/* None.proto */
static CYTHON_INLINE __pyx_t_5numpy_int64_t __Pyx_div___pyx_t_5numpy_int64_t(__pyx_t_5numpy_int64_t, __pyx_t_5numpy_int64_t);

/* UnaryNegOverflows.proto */
#define UNARY_NEG_WOULD_OVERFLOW(x)\
        (((x) < 0) & ((unsigned long)(x) == 0-(unsigned long)(x)))

/* GetModuleGlobalName.proto */
static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name);

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* BufferFallbackError.proto */
static void __Pyx_RaiseBufferFallbackError(void);

/* None.proto */
static CYTHON_INLINE __pyx_t_5numpy_int64_t __Pyx_mod___pyx_t_5numpy_int64_t(__pyx_t_5numpy_int64_t, __pyx_t_5numpy_int64_t);

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, int nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* PyObjectCallNoArg.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            PyObject* args = PyTuple_Pack(1, key);
            if (likely(args))
                PyErr_SetObject(PyExc_KeyError, args);
            Py_XDECREF(args);
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#else
    #define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#endif

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* RaiseNoneIterError.proto */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* SetVTable.proto */
static int __Pyx_SetVtable(PyObject *dict, void *vtable);

/* SetupReduce.proto */
static int __Pyx_setup_reduce(PyObject* type_obj);

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* BufferStructDeclare.proto */
typedef struct {
  Py_ssize_t shape, strides, suboffsets;
} __Pyx_Buf_DimInfo;
typedef struct {
  size_t refcount;
  Py_buffer pybuffer;
} __Pyx_Buffer;
typedef struct {
  __Pyx_Buffer *rcbuffer;
  char *data;
  __Pyx_Buf_DimInfo diminfo[8];
} __Pyx_LocalBuf_ND;

#if PY_MAJOR_VERSION < 3
    static int __Pyx_GetBuffer(PyObject *obj, Py_buffer *view, int flags);
    static void __Pyx_ReleaseBuffer(Py_buffer *view);
#else
    #define __Pyx_GetBuffer PyObject_GetBuffer
    #define __Pyx_ReleaseBuffer PyBuffer_Release
#endif


/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* None.proto */
static CYTHON_INLINE long __Pyx_pow_long(long, long);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_int64(npy_int64 value);

/* Print.proto */
static int __Pyx_Print(PyObject*, PyObject *, int);
#if CYTHON_COMPILING_IN_PYPY || PY_MAJOR_VERSION >= 3
static PyObject* __pyx_print = 0;
static PyObject* __pyx_print_kwargs = 0;
#endif

/* RealImag.proto */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #define __Pyx_CREAL(z) ((z).real())
    #define __Pyx_CIMAG(z) ((z).imag())
  #else
    #define __Pyx_CREAL(z) (__real__(z))
    #define __Pyx_CIMAG(z) (__imag__(z))
  #endif
#else
    #define __Pyx_CREAL(z) ((z).real)
    #define __Pyx_CIMAG(z) ((z).imag)
#endif
#if defined(__cplusplus) && CYTHON_CCOMPLEX\
        && (defined(_WIN32) || defined(__clang__) || (defined(__GNUC__) && (__GNUC__ >= 5 || __GNUC__ == 4 && __GNUC_MINOR__ >= 4 )) || __cplusplus >= 201103)
    #define __Pyx_SET_CREAL(z,x) ((z).real(x))
    #define __Pyx_SET_CIMAG(z,y) ((z).imag(y))
#else
    #define __Pyx_SET_CREAL(z,x) __Pyx_CREAL(z) = (x)
    #define __Pyx_SET_CIMAG(z,y) __Pyx_CIMAG(z) = (y)
#endif

/* Arithmetic.proto */
#if CYTHON_CCOMPLEX
    #define __Pyx_c_eq_float(a, b)   ((a)==(b))
    #define __Pyx_c_sum_float(a, b)  ((a)+(b))
    #define __Pyx_c_diff_float(a, b) ((a)-(b))
    #define __Pyx_c_prod_float(a, b) ((a)*(b))
    #define __Pyx_c_quot_float(a, b) ((a)/(b))
    #define __Pyx_c_neg_float(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero_float(z) ((z)==(float)0)
    #define __Pyx_c_conj_float(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs_float(z)     (::std::abs(z))
        #define __Pyx_c_pow_float(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero_float(z) ((z)==0)
    #define __Pyx_c_conj_float(z)    (conjf(z))
    #if 1
        #define __Pyx_c_abs_float(z)     (cabsf(z))
        #define __Pyx_c_pow_float(a, b)  (cpowf(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sum_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_diff_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prod_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_neg_float(__pyx_t_float_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero_float(__pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conj_float(__pyx_t_float_complex);
    #if 1
        static CYTHON_INLINE float __Pyx_c_abs_float(__pyx_t_float_complex);
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_pow_float(__pyx_t_float_complex, __pyx_t_float_complex);
    #endif
#endif

/* Arithmetic.proto */
#if CYTHON_CCOMPLEX
    #define __Pyx_c_eq_double(a, b)   ((a)==(b))
    #define __Pyx_c_sum_double(a, b)  ((a)+(b))
    #define __Pyx_c_diff_double(a, b) ((a)-(b))
    #define __Pyx_c_prod_double(a, b) ((a)*(b))
    #define __Pyx_c_quot_double(a, b) ((a)/(b))
    #define __Pyx_c_neg_double(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero_double(z) ((z)==(double)0)
    #define __Pyx_c_conj_double(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs_double(z)     (::std::abs(z))
        #define __Pyx_c_pow_double(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero_double(z) ((z)==0)
    #define __Pyx_c_conj_double(z)    (conj(z))
    #if 1
        #define __Pyx_c_abs_double(z)     (cabs(z))
        #define __Pyx_c_pow_double(a, b)  (cpow(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg_double(__pyx_t_double_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero_double(__pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj_double(__pyx_t_double_complex);
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs_double(__pyx_t_double_complex);
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow_double(__pyx_t_double_complex, __pyx_t_double_complex);
    #endif
#endif

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_enum__NPY_TYPES(enum NPY_TYPES value);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* PrintOne.proto */
static int __Pyx_PrintOne(PyObject* stream, PyObject *o);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* PyIdentifierFromString.proto */
#if !defined(__Pyx_PyIdentifier_FromString)
#if PY_MAJOR_VERSION < 3
  #define __Pyx_PyIdentifier_FromString(s) PyString_FromString(s)
#else
  #define __Pyx_PyIdentifier_FromString(s) PyUnicode_FromString(s)
#endif
#endif

/* ModuleImport.proto */
static PyObject *__Pyx_ImportModule(const char *name);

/* TypeImport.proto */
static PyTypeObject *__Pyx_ImportType(const char *module_name, const char *class_name, size_t size, int strict);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

static void __pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_add_to_position(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, int __pyx_v_level, __pyx_t_5numpy_int64_t *__pyx_v_pos, __pyx_t_5numpy_float64_t *__pyx_v_val, __pyx_t_5numpy_float64_t __pyx_v_weight_val, PyObject *__pyx_v_treecode); /* proto*/
static struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_find_on_root_level(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, __pyx_t_5numpy_int64_t *__pyx_v_pos, int __pyx_v_level); /* proto*/
static int __pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_count_at_level(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node, int __pyx_v_level); /* proto*/
static int __pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_fill_from_level(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node, int __pyx_v_level, __pyx_t_5numpy_int64_t __pyx_v_curpos, __pyx_t_5numpy_int64_t *__pyx_v_pdata, __pyx_t_5numpy_float64_t *__pyx_v_vdata, __pyx_t_5numpy_float64_t *__pyx_v_wdata); /* proto*/
static __pyx_t_5numpy_float64_t __pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_fbe_node_separation(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node1, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node2); /* proto*/
static __pyx_t_5numpy_float64_t __pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_fbe_opening_angle(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node1, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node2); /* proto*/
static void __pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_set_next(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node, int __pyx_v_treecode); /* proto*/
static void __pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_set_up_next(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node); /* proto*/
static __pyx_t_5numpy_float64_t __pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_fbe_main(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, __pyx_t_5numpy_float64_t __pyx_v_potential, int __pyx_v_truncate, __pyx_t_5numpy_float64_t __pyx_v_kinetic); /* proto*/
static int __pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_node_ID(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node); /* proto*/
static int __pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_node_ID_on_level(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node); /* proto*/
static void __pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_print_node_info(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node); /* proto*/
static void __pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_iterate_print_nodes(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node); /* proto*/

/* Module declarations from 'cpython.buffer' */

/* Module declarations from 'libc.string' */

/* Module declarations from 'libc.stdio' */

/* Module declarations from '__builtin__' */

/* Module declarations from 'cpython.type' */
static PyTypeObject *__pyx_ptype_7cpython_4type_type = 0;

/* Module declarations from 'cpython' */

/* Module declarations from 'cpython.object' */

/* Module declarations from 'cpython.ref' */

/* Module declarations from 'cpython.mem' */

/* Module declarations from 'numpy' */

/* Module declarations from 'numpy' */
static PyTypeObject *__pyx_ptype_5numpy_dtype = 0;
static PyTypeObject *__pyx_ptype_5numpy_flatiter = 0;
static PyTypeObject *__pyx_ptype_5numpy_broadcast = 0;
static PyTypeObject *__pyx_ptype_5numpy_ndarray = 0;
static PyTypeObject *__pyx_ptype_5numpy_ufunc = 0;
static CYTHON_INLINE char *__pyx_f_5numpy__util_dtypestring(PyArray_Descr *, char *, char *, int *); /*proto*/

/* Module declarations from 'cython' */

/* Module declarations from 'yt.utilities.lib.fp_utils' */
static CYTHON_INLINE __pyx_t_5numpy_int64_t __pyx_f_2yt_9utilities_3lib_8fp_utils_imax(__pyx_t_5numpy_int64_t, __pyx_t_5numpy_int64_t); /*proto*/
static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_2yt_9utilities_3lib_8fp_utils_fmax(__pyx_t_5numpy_float64_t, __pyx_t_5numpy_float64_t); /*proto*/
static CYTHON_INLINE __pyx_t_5numpy_int64_t __pyx_f_2yt_9utilities_3lib_8fp_utils_imin(__pyx_t_5numpy_int64_t, __pyx_t_5numpy_int64_t); /*proto*/
static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_2yt_9utilities_3lib_8fp_utils_fmin(__pyx_t_5numpy_float64_t, __pyx_t_5numpy_float64_t); /*proto*/
static CYTHON_INLINE __pyx_t_5numpy_int64_t __pyx_f_2yt_9utilities_3lib_8fp_utils_iclip(__pyx_t_5numpy_int64_t, __pyx_t_5numpy_int64_t, __pyx_t_5numpy_int64_t); /*proto*/
static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_2yt_9utilities_3lib_8fp_utils_fclip(__pyx_t_5numpy_float64_t, __pyx_t_5numpy_float64_t, __pyx_t_5numpy_float64_t); /*proto*/

/* Module declarations from 'libc.stdlib' */

/* Module declarations from 'yt.utilities.lib.basic_octree' */
static PyTypeObject *__pyx_ptype_2yt_9utilities_3lib_12basic_octree_Octree = 0;
static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_2yt_9utilities_3lib_12basic_octree_f64max(__pyx_t_5numpy_float64_t, __pyx_t_5numpy_float64_t); /*proto*/
static void __pyx_f_2yt_9utilities_3lib_12basic_octree_OTN_add_value(struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *, __pyx_t_5numpy_float64_t *, __pyx_t_5numpy_float64_t, int, int); /*proto*/
static void __pyx_f_2yt_9utilities_3lib_12basic_octree_OTN_refine(struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *, struct __pyx_opt_args_2yt_9utilities_3lib_12basic_octree_OTN_refine *__pyx_optional_args); /*proto*/
static struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_f_2yt_9utilities_3lib_12basic_octree_OTN_initialize(__pyx_t_5numpy_int64_t *, int, __pyx_t_5numpy_float64_t *, __pyx_t_5numpy_float64_t, int, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *, struct __pyx_opt_args_2yt_9utilities_3lib_12basic_octree_OTN_initialize *__pyx_optional_args); /*proto*/
static void __pyx_f_2yt_9utilities_3lib_12basic_octree_OTN_free(struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *); /*proto*/
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t = { "int64_t", NULL, sizeof(__pyx_t_5numpy_int64_t), { 0 }, 0, IS_UNSIGNED(__pyx_t_5numpy_int64_t) ? 'U' : 'I', IS_UNSIGNED(__pyx_t_5numpy_int64_t), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t = { "float64_t", NULL, sizeof(__pyx_t_5numpy_float64_t), { 0 }, 0, 'R', 0, 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t = { "int32_t", NULL, sizeof(__pyx_t_5numpy_int32_t), { 0 }, 0, IS_UNSIGNED(__pyx_t_5numpy_int32_t) ? 'U' : 'I', IS_UNSIGNED(__pyx_t_5numpy_int32_t), 0 };
#define __Pyx_MODULE_NAME "yt.utilities.lib.basic_octree"
extern int __pyx_module_is_main_yt__utilities__lib__basic_octree;
int __pyx_module_is_main_yt__utilities__lib__basic_octree = 0;

/* Implementation of 'yt.utilities.lib.basic_octree' */
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_RuntimeError;
static PyObject *__pyx_builtin_ImportError;
static const char __pyx_k_[] = "";
static const char __pyx_k_1[] = "-1\t";
static const char __pyx_k_d[] = "%d\t";
static const char __pyx_k_f[] = "%f\t";
static const char __pyx_k_cm[] = "cm";
static const char __pyx_k_np[] = "np";
static const char __pyx_k_d_2[] = "%d,";
static const char __pyx_k_end[] = "end";
static const char __pyx_k_pxs[] = "pxs";
static const char __pyx_k_pys[] = "pys";
static const char __pyx_k_pzs[] = "pzs";
static const char __pyx_k_s_s[] = "%s\t%s\t";
static const char __pyx_k_sys[] = "sys";
static const char __pyx_k_1_5e[] = "%1.5e\t";
static const char __pyx_k_file[] = "file";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_name[] = "__name__";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_time[] = "time";
static const char __pyx_k_dtype[] = "dtype";
static const char __pyx_k_flush[] = "flush";
static const char __pyx_k_int64[] = "int64";
static const char __pyx_k_level[] = "level";
static const char __pyx_k_numpy[] = "numpy";
static const char __pyx_k_nvals[] = "nvals";
static const char __pyx_k_print[] = "print";
static const char __pyx_k_pvals[] = "pvals";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_val_d[] = "val%d\t\t";
static const char __pyx_k_wvals[] = "wvals";
static const char __pyx_k_zeros[] = "zeros";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_stderr[] = "stderr";
static const char __pyx_k_stdout[] = "stdout";
static const char __pyx_k_d_d_d_d[] = "%d\t%d\t%d\t%d\t";
static const char __pyx_k_float64[] = "float64";
static const char __pyx_k_kinetic[] = "kinetic";
static const char __pyx_k_root_dx[] = "root_dx";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_treecode[] = "treecode";
static const char __pyx_k_truncate[] = "truncate";
static const char __pyx_k_TypeError[] = "TypeError";
static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
static const char __pyx_k_Truncating[] = "Truncating...";
static const char __pyx_k_ValueError[] = "ValueError";
static const char __pyx_k_count_only[] = "count_only";
static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static const char __pyx_k_ImportError[] = "ImportError";
static const char __pyx_k_incremental[] = "incremental";
static const char __pyx_k_start_index[] = "start_index";
static const char __pyx_k_RuntimeError[] = "RuntimeError";
static const char __pyx_k_pweight_vals[] = "pweight_vals";
static const char __pyx_k_opening_angle[] = "opening_angle";
static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
static const char __pyx_k_top_grid_dims[] = "top_grid_dims";
static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_ID_next_up_n_level_x_y_z[] = "ID\tnext\tup_n\tlevel\tx\ty\tz\t";
static const char __pyx_k_ndarray_is_not_C_contiguous[] = "ndarray is not C contiguous";
static const char __pyx_k_weight_child_parent_children[] = "weight\t\tchild?\tparent?\tchildren";
static const char __pyx_k_A_refine_by_two_AMR_specific_oc[] = "\nA refine-by-two AMR-specific octree\n\n\n\n";
static const char __pyx_k_Octree_print_all_nodes_line_562[] = "Octree.print_all_nodes (line 562)";
static const char __pyx_k_Prints_out_information_about_al[] = "\n        Prints out information about all the nodes in the octree.\n        \n        Parameters\n        ----------\n        None.\n        \n        Examples\n        --------\n        >>> octree.print_all_nodes()\n        (many lines of data)\n        ";
static const char __pyx_k_numpy_core_multiarray_failed_to[] = "numpy.core.multiarray failed to import";
static const char __pyx_k_unknown_dtype_code_in_numpy_pxd[] = "unknown dtype code in numpy.pxd (%d)";
static const char __pyx_k_Format_string_allocated_too_shor[] = "Format string allocated too short, see comment in numpy.pxd";
static const char __pyx_k_Non_native_byte_order_not_suppor[] = "Non-native byte order not supported";
static const char __pyx_k_ndarray_is_not_Fortran_contiguou[] = "ndarray is not Fortran contiguous";
static const char __pyx_k_no_default___reduce___due_to_non[] = "no default __reduce__ due to non-trivial __cinit__";
static const char __pyx_k_numpy_core_umath_failed_to_impor[] = "numpy.core.umath failed to import";
static const char __pyx_k_Format_string_allocated_too_shor_2[] = "Format string allocated too short.";
static PyObject *__pyx_kp_s_;
static PyObject *__pyx_kp_s_1;
static PyObject *__pyx_kp_s_1_5e;
static PyObject *__pyx_kp_u_Format_string_allocated_too_shor;
static PyObject *__pyx_kp_u_Format_string_allocated_too_shor_2;
static PyObject *__pyx_kp_s_ID_next_up_n_level_x_y_z;
static PyObject *__pyx_n_s_ImportError;
static PyObject *__pyx_kp_u_Non_native_byte_order_not_suppor;
static PyObject *__pyx_kp_u_Octree_print_all_nodes_line_562;
static PyObject *__pyx_kp_u_Prints_out_information_about_al;
static PyObject *__pyx_n_s_RuntimeError;
static PyObject *__pyx_kp_s_Truncating;
static PyObject *__pyx_n_s_TypeError;
static PyObject *__pyx_n_s_ValueError;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_s_cm;
static PyObject *__pyx_n_s_count_only;
static PyObject *__pyx_kp_s_d;
static PyObject *__pyx_kp_s_d_2;
static PyObject *__pyx_kp_s_d_d_d_d;
static PyObject *__pyx_n_s_dtype;
static PyObject *__pyx_n_s_end;
static PyObject *__pyx_kp_s_f;
static PyObject *__pyx_n_s_file;
static PyObject *__pyx_n_s_float64;
static PyObject *__pyx_n_s_flush;
static PyObject *__pyx_n_s_getstate;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_incremental;
static PyObject *__pyx_n_s_int64;
static PyObject *__pyx_n_s_kinetic;
static PyObject *__pyx_n_s_level;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_kp_u_ndarray_is_not_C_contiguous;
static PyObject *__pyx_kp_u_ndarray_is_not_Fortran_contiguou;
static PyObject *__pyx_kp_s_no_default___reduce___due_to_non;
static PyObject *__pyx_n_s_np;
static PyObject *__pyx_n_s_numpy;
static PyObject *__pyx_kp_s_numpy_core_multiarray_failed_to;
static PyObject *__pyx_kp_s_numpy_core_umath_failed_to_impor;
static PyObject *__pyx_n_s_nvals;
static PyObject *__pyx_n_s_opening_angle;
static PyObject *__pyx_n_s_print;
static PyObject *__pyx_n_s_pvals;
static PyObject *__pyx_n_s_pweight_vals;
static PyObject *__pyx_n_s_pxs;
static PyObject *__pyx_n_s_pys;
static PyObject *__pyx_n_s_pyx_vtable;
static PyObject *__pyx_n_s_pzs;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_reduce;
static PyObject *__pyx_n_s_reduce_cython;
static PyObject *__pyx_n_s_reduce_ex;
static PyObject *__pyx_n_s_root_dx;
static PyObject *__pyx_kp_s_s_s;
static PyObject *__pyx_n_s_setstate;
static PyObject *__pyx_n_s_setstate_cython;
static PyObject *__pyx_n_s_start_index;
static PyObject *__pyx_n_s_stderr;
static PyObject *__pyx_n_s_stdout;
static PyObject *__pyx_n_s_sys;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_time;
static PyObject *__pyx_n_s_top_grid_dims;
static PyObject *__pyx_n_s_treecode;
static PyObject *__pyx_n_s_truncate;
static PyObject *__pyx_kp_u_unknown_dtype_code_in_numpy_pxd;
static PyObject *__pyx_kp_s_val_d;
static PyObject *__pyx_kp_s_weight_child_parent_children;
static PyObject *__pyx_n_s_wvals;
static PyObject *__pyx_n_s_zeros;
static int __pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree___cinit__(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, PyArrayObject *__pyx_v_top_grid_dims, int __pyx_v_nvals, int __pyx_v_incremental); /* proto */
static PyObject *__pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_2add_array_to_tree(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, int __pyx_v_level, PyArrayObject *__pyx_v_pxs, PyArrayObject *__pyx_v_pys, PyArrayObject *__pyx_v_pzs, PyArrayObject *__pyx_v_pvals, PyArrayObject *__pyx_v_pweight_vals, int __pyx_v_treecode); /* proto */
static PyObject *__pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_4add_grid_to_tree(CYTHON_UNUSED struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, CYTHON_UNUSED int __pyx_v_level, CYTHON_UNUSED PyArrayObject *__pyx_v_start_index, CYTHON_UNUSED PyArrayObject *__pyx_v_pvals, CYTHON_UNUSED PyArrayObject *__pyx_v_wvals, CYTHON_UNUSED PyArrayObject *__pyx_v_cm); /* proto */
static PyObject *__pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_6get_all_from_level(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, int __pyx_v_level, int __pyx_v_count_only); /* proto */
static PyObject *__pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_8finalize(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, int __pyx_v_treecode); /* proto */
static PyObject *__pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_10find_binding_energy(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, int __pyx_v_truncate, __pyx_t_5numpy_float64_t __pyx_v_kinetic, PyArrayObject *__pyx_v_root_dx, float __pyx_v_opening_angle); /* proto */
static PyObject *__pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_12print_all_nodes(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self); /* proto */
static void __pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_14__dealloc__(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_16__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_18__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_5numpy_7ndarray___getbuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /* proto */
static void __pyx_pf_5numpy_7ndarray_2__releasebuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info); /* proto */
static PyObject *__pyx_tp_new_2yt_9utilities_3lib_12basic_octree_Octree(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_int_3;
static PyObject *__pyx_tuple__2;
static PyObject *__pyx_tuple__3;
static PyObject *__pyx_tuple__4;
static PyObject *__pyx_tuple__5;
static PyObject *__pyx_tuple__6;
static PyObject *__pyx_tuple__7;
static PyObject *__pyx_tuple__8;
static PyObject *__pyx_tuple__9;
static PyObject *__pyx_tuple__10;
static PyObject *__pyx_tuple__11;
static PyObject *__pyx_tuple__12;

/* "yt/utilities/lib/basic_octree.pyx":35
 *     double sqrt(double x)
 * 
 * cdef inline np.float64_t f64max(np.float64_t f0, np.float64_t f1):             # <<<<<<<<<<<<<<
 *     if f0 > f1: return f0
 *     return f1
 */

static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_2yt_9utilities_3lib_12basic_octree_f64max(__pyx_t_5numpy_float64_t __pyx_v_f0, __pyx_t_5numpy_float64_t __pyx_v_f1) {
  __pyx_t_5numpy_float64_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("f64max", 0);

  /* "yt/utilities/lib/basic_octree.pyx":36
 * 
 * cdef inline np.float64_t f64max(np.float64_t f0, np.float64_t f1):
 *     if f0 > f1: return f0             # <<<<<<<<<<<<<<
 *     return f1
 * 
 */
  __pyx_t_1 = ((__pyx_v_f0 > __pyx_v_f1) != 0);
  if (__pyx_t_1) {
    __pyx_r = __pyx_v_f0;
    goto __pyx_L0;
  }

  /* "yt/utilities/lib/basic_octree.pyx":37
 * cdef inline np.float64_t f64max(np.float64_t f0, np.float64_t f1):
 *     if f0 > f1: return f0
 *     return f1             # <<<<<<<<<<<<<<
 * 
 * cdef struct OctreeNode:
 */
  __pyx_r = __pyx_v_f1;
  goto __pyx_L0;

  /* "yt/utilities/lib/basic_octree.pyx":35
 *     double sqrt(double x)
 * 
 * cdef inline np.float64_t f64max(np.float64_t f0, np.float64_t f1):             # <<<<<<<<<<<<<<
 *     if f0 > f1: return f0
 *     return f1
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yt/utilities/lib/basic_octree.pyx":51
 *     OctreeNode *up_next
 * 
 * cdef void OTN_add_value(OctreeNode *self,             # <<<<<<<<<<<<<<
 *         np.float64_t *val, np.float64_t weight_val, int level, int treecode):
 *     cdef int i
 */

static void __pyx_f_2yt_9utilities_3lib_12basic_octree_OTN_add_value(struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_self, __pyx_t_5numpy_float64_t *__pyx_v_val, __pyx_t_5numpy_float64_t __pyx_v_weight_val, int __pyx_v_level, int __pyx_v_treecode) {
  int __pyx_v_i;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  __Pyx_RefNannySetupContext("OTN_add_value", 0);

  /* "yt/utilities/lib/basic_octree.pyx":54
 *         np.float64_t *val, np.float64_t weight_val, int level, int treecode):
 *     cdef int i
 *     for i in range(self.nvals):             # <<<<<<<<<<<<<<
 *         self.val[i] += val[i]
 *     self.weight_val += weight_val
 */
  __pyx_t_1 = __pyx_v_self->nvals;
  for (__pyx_t_2 = 0; __pyx_t_2 < __pyx_t_1; __pyx_t_2+=1) {
    __pyx_v_i = __pyx_t_2;

    /* "yt/utilities/lib/basic_octree.pyx":55
 *     cdef int i
 *     for i in range(self.nvals):
 *         self.val[i] += val[i]             # <<<<<<<<<<<<<<
 *     self.weight_val += weight_val
 *     if treecode and val[0] > 0.:
 */
    __pyx_t_3 = __pyx_v_i;
    (__pyx_v_self->val[__pyx_t_3]) = ((__pyx_v_self->val[__pyx_t_3]) + (__pyx_v_val[__pyx_v_i]));
  }

  /* "yt/utilities/lib/basic_octree.pyx":56
 *     for i in range(self.nvals):
 *         self.val[i] += val[i]
 *     self.weight_val += weight_val             # <<<<<<<<<<<<<<
 *     if treecode and val[0] > 0.:
 *         self.max_level = imax(self.max_level, level)
 */
  __pyx_v_self->weight_val = (__pyx_v_self->weight_val + __pyx_v_weight_val);

  /* "yt/utilities/lib/basic_octree.pyx":57
 *         self.val[i] += val[i]
 *     self.weight_val += weight_val
 *     if treecode and val[0] > 0.:             # <<<<<<<<<<<<<<
 *         self.max_level = imax(self.max_level, level)
 * 
 */
  __pyx_t_5 = (__pyx_v_treecode != 0);
  if (__pyx_t_5) {
  } else {
    __pyx_t_4 = __pyx_t_5;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_5 = (((__pyx_v_val[0]) > 0.) != 0);
  __pyx_t_4 = __pyx_t_5;
  __pyx_L6_bool_binop_done:;
  if (__pyx_t_4) {

    /* "yt/utilities/lib/basic_octree.pyx":58
 *     self.weight_val += weight_val
 *     if treecode and val[0] > 0.:
 *         self.max_level = imax(self.max_level, level)             # <<<<<<<<<<<<<<
 * 
 * cdef void OTN_refine(OctreeNode *self, int incremental = 0):
 */
    __pyx_v_self->max_level = __pyx_f_2yt_9utilities_3lib_8fp_utils_imax(__pyx_v_self->max_level, __pyx_v_level);

    /* "yt/utilities/lib/basic_octree.pyx":57
 *         self.val[i] += val[i]
 *     self.weight_val += weight_val
 *     if treecode and val[0] > 0.:             # <<<<<<<<<<<<<<
 *         self.max_level = imax(self.max_level, level)
 * 
 */
  }

  /* "yt/utilities/lib/basic_octree.pyx":51
 *     OctreeNode *up_next
 * 
 * cdef void OTN_add_value(OctreeNode *self,             # <<<<<<<<<<<<<<
 *         np.float64_t *val, np.float64_t weight_val, int level, int treecode):
 *     cdef int i
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "yt/utilities/lib/basic_octree.pyx":60
 *         self.max_level = imax(self.max_level, level)
 * 
 * cdef void OTN_refine(OctreeNode *self, int incremental = 0):             # <<<<<<<<<<<<<<
 *     cdef int i, j, k
 *     cdef np.int64_t npos[3]
 */

static void __pyx_f_2yt_9utilities_3lib_12basic_octree_OTN_refine(struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_self, struct __pyx_opt_args_2yt_9utilities_3lib_12basic_octree_OTN_refine *__pyx_optional_args) {
  int __pyx_v_incremental = ((int)0);
  int __pyx_v_i;
  int __pyx_v_j;
  int __pyx_v_k;
  __pyx_t_5numpy_int64_t __pyx_v_npos[3];
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_t_4;
  struct __pyx_opt_args_2yt_9utilities_3lib_12basic_octree_OTN_initialize __pyx_t_5;
  int __pyx_t_6;
  __Pyx_RefNannySetupContext("OTN_refine", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_incremental = __pyx_optional_args->incremental;
    }
  }

  /* "yt/utilities/lib/basic_octree.pyx":63
 *     cdef int i, j, k
 *     cdef np.int64_t npos[3]
 *     for i in range(2):             # <<<<<<<<<<<<<<
 *         npos[0] = self.pos[0] * 2 + i
 *         for j in range(2):
 */
  for (__pyx_t_1 = 0; __pyx_t_1 < 2; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "yt/utilities/lib/basic_octree.pyx":64
 *     cdef np.int64_t npos[3]
 *     for i in range(2):
 *         npos[0] = self.pos[0] * 2 + i             # <<<<<<<<<<<<<<
 *         for j in range(2):
 *             npos[1] = self.pos[1] * 2 + j
 */
    (__pyx_v_npos[0]) = (((__pyx_v_self->pos[0]) * 2) + __pyx_v_i);

    /* "yt/utilities/lib/basic_octree.pyx":65
 *     for i in range(2):
 *         npos[0] = self.pos[0] * 2 + i
 *         for j in range(2):             # <<<<<<<<<<<<<<
 *             npos[1] = self.pos[1] * 2 + j
 *             # We have to be careful with allocation...
 */
    for (__pyx_t_2 = 0; __pyx_t_2 < 2; __pyx_t_2+=1) {
      __pyx_v_j = __pyx_t_2;

      /* "yt/utilities/lib/basic_octree.pyx":66
 *         npos[0] = self.pos[0] * 2 + i
 *         for j in range(2):
 *             npos[1] = self.pos[1] * 2 + j             # <<<<<<<<<<<<<<
 *             # We have to be careful with allocation...
 *             for k in range(2):
 */
      (__pyx_v_npos[1]) = (((__pyx_v_self->pos[1]) * 2) + __pyx_v_j);

      /* "yt/utilities/lib/basic_octree.pyx":68
 *             npos[1] = self.pos[1] * 2 + j
 *             # We have to be careful with allocation...
 *             for k in range(2):             # <<<<<<<<<<<<<<
 *                 npos[2] = self.pos[2] * 2 + k
 *                 self.children[i][j][k] = OTN_initialize(
 */
      for (__pyx_t_3 = 0; __pyx_t_3 < 2; __pyx_t_3+=1) {
        __pyx_v_k = __pyx_t_3;

        /* "yt/utilities/lib/basic_octree.pyx":69
 *             # We have to be careful with allocation...
 *             for k in range(2):
 *                 npos[2] = self.pos[2] * 2 + k             # <<<<<<<<<<<<<<
 *                 self.children[i][j][k] = OTN_initialize(
 *                             npos,
 */
        (__pyx_v_npos[2]) = (((__pyx_v_self->pos[2]) * 2) + __pyx_v_k);

        /* "yt/utilities/lib/basic_octree.pyx":70
 *             for k in range(2):
 *                 npos[2] = self.pos[2] * 2 + k
 *                 self.children[i][j][k] = OTN_initialize(             # <<<<<<<<<<<<<<
 *                             npos,
 *                             self.nvals, self.val, self.weight_val,
 */
        __pyx_t_5.__pyx_n = 1;
        __pyx_t_5.incremental = __pyx_v_incremental;
        __pyx_t_4 = __pyx_f_2yt_9utilities_3lib_12basic_octree_OTN_initialize(__pyx_v_npos, __pyx_v_self->nvals, __pyx_v_self->val, __pyx_v_self->weight_val, (__pyx_v_self->level + 1), __pyx_v_self, &__pyx_t_5); 
        (((__pyx_v_self->children[__pyx_v_i])[__pyx_v_j])[__pyx_v_k]) = __pyx_t_4;
      }
    }
  }

  /* "yt/utilities/lib/basic_octree.pyx":74
 *                             self.nvals, self.val, self.weight_val,
 *                             self.level + 1, self, incremental)
 *     if incremental: return             # <<<<<<<<<<<<<<
 *     for i in range(self.nvals): self.val[i] = 0.0
 *     self.weight_val = 0.0
 */
  __pyx_t_6 = (__pyx_v_incremental != 0);
  if (__pyx_t_6) {
    goto __pyx_L0;
  }

  /* "yt/utilities/lib/basic_octree.pyx":75
 *                             self.level + 1, self, incremental)
 *     if incremental: return
 *     for i in range(self.nvals): self.val[i] = 0.0             # <<<<<<<<<<<<<<
 *     self.weight_val = 0.0
 * 
 */
  __pyx_t_1 = __pyx_v_self->nvals;
  for (__pyx_t_2 = 0; __pyx_t_2 < __pyx_t_1; __pyx_t_2+=1) {
    __pyx_v_i = __pyx_t_2;
    (__pyx_v_self->val[__pyx_v_i]) = 0.0;
  }

  /* "yt/utilities/lib/basic_octree.pyx":76
 *     if incremental: return
 *     for i in range(self.nvals): self.val[i] = 0.0
 *     self.weight_val = 0.0             # <<<<<<<<<<<<<<
 * 
 * cdef OctreeNode *OTN_initialize(np.int64_t pos[3], int nvals,
 */
  __pyx_v_self->weight_val = 0.0;

  /* "yt/utilities/lib/basic_octree.pyx":60
 *         self.max_level = imax(self.max_level, level)
 * 
 * cdef void OTN_refine(OctreeNode *self, int incremental = 0):             # <<<<<<<<<<<<<<
 *     cdef int i, j, k
 *     cdef np.int64_t npos[3]
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "yt/utilities/lib/basic_octree.pyx":78
 *     self.weight_val = 0.0
 * 
 * cdef OctreeNode *OTN_initialize(np.int64_t pos[3], int nvals,             # <<<<<<<<<<<<<<
 *                         np.float64_t *val, np.float64_t weight_val,
 *                         int level, OctreeNode *parent, int incremental = 0):
 */

static struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_f_2yt_9utilities_3lib_12basic_octree_OTN_initialize(__pyx_t_5numpy_int64_t *__pyx_v_pos, int __pyx_v_nvals, __pyx_t_5numpy_float64_t *__pyx_v_val, __pyx_t_5numpy_float64_t __pyx_v_weight_val, int __pyx_v_level, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_parent, struct __pyx_opt_args_2yt_9utilities_3lib_12basic_octree_OTN_initialize *__pyx_optional_args) {
  int __pyx_v_incremental = ((int)0);
  struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node;
  int __pyx_v_i;
  int __pyx_v_j;
  int __pyx_v_k;
  struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  __Pyx_RefNannySetupContext("OTN_initialize", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_incremental = __pyx_optional_args->incremental;
    }
  }

  /* "yt/utilities/lib/basic_octree.pyx":83
 *     cdef OctreeNode *node
 *     cdef int i, j, k
 *     node = <OctreeNode *> malloc(sizeof(OctreeNode))             # <<<<<<<<<<<<<<
 *     node.pos[0] = pos[0]
 *     node.pos[1] = pos[1]
 */
  __pyx_v_node = ((struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *)malloc((sizeof(struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode))));

  /* "yt/utilities/lib/basic_octree.pyx":84
 *     cdef int i, j, k
 *     node = <OctreeNode *> malloc(sizeof(OctreeNode))
 *     node.pos[0] = pos[0]             # <<<<<<<<<<<<<<
 *     node.pos[1] = pos[1]
 *     node.pos[2] = pos[2]
 */
  (__pyx_v_node->pos[0]) = (__pyx_v_pos[0]);

  /* "yt/utilities/lib/basic_octree.pyx":85
 *     node = <OctreeNode *> malloc(sizeof(OctreeNode))
 *     node.pos[0] = pos[0]
 *     node.pos[1] = pos[1]             # <<<<<<<<<<<<<<
 *     node.pos[2] = pos[2]
 *     node.nvals = nvals
 */
  (__pyx_v_node->pos[1]) = (__pyx_v_pos[1]);

  /* "yt/utilities/lib/basic_octree.pyx":86
 *     node.pos[0] = pos[0]
 *     node.pos[1] = pos[1]
 *     node.pos[2] = pos[2]             # <<<<<<<<<<<<<<
 *     node.nvals = nvals
 *     node.parent = parent
 */
  (__pyx_v_node->pos[2]) = (__pyx_v_pos[2]);

  /* "yt/utilities/lib/basic_octree.pyx":87
 *     node.pos[1] = pos[1]
 *     node.pos[2] = pos[2]
 *     node.nvals = nvals             # <<<<<<<<<<<<<<
 *     node.parent = parent
 *     node.next = NULL
 */
  __pyx_v_node->nvals = __pyx_v_nvals;

  /* "yt/utilities/lib/basic_octree.pyx":88
 *     node.pos[2] = pos[2]
 *     node.nvals = nvals
 *     node.parent = parent             # <<<<<<<<<<<<<<
 *     node.next = NULL
 *     node.up_next = NULL
 */
  __pyx_v_node->parent = __pyx_v_parent;

  /* "yt/utilities/lib/basic_octree.pyx":89
 *     node.nvals = nvals
 *     node.parent = parent
 *     node.next = NULL             # <<<<<<<<<<<<<<
 *     node.up_next = NULL
 *     node.max_level = 0
 */
  __pyx_v_node->next = NULL;

  /* "yt/utilities/lib/basic_octree.pyx":90
 *     node.parent = parent
 *     node.next = NULL
 *     node.up_next = NULL             # <<<<<<<<<<<<<<
 *     node.max_level = 0
 *     node.val = <np.float64_t *> malloc(
 */
  __pyx_v_node->up_next = NULL;

  /* "yt/utilities/lib/basic_octree.pyx":91
 *     node.next = NULL
 *     node.up_next = NULL
 *     node.max_level = 0             # <<<<<<<<<<<<<<
 *     node.val = <np.float64_t *> malloc(
 *                 nvals * sizeof(np.float64_t))
 */
  __pyx_v_node->max_level = 0;

  /* "yt/utilities/lib/basic_octree.pyx":92
 *     node.up_next = NULL
 *     node.max_level = 0
 *     node.val = <np.float64_t *> malloc(             # <<<<<<<<<<<<<<
 *                 nvals * sizeof(np.float64_t))
 *     if incremental:
 */
  __pyx_v_node->val = ((__pyx_t_5numpy_float64_t *)malloc((__pyx_v_nvals * (sizeof(__pyx_t_5numpy_float64_t)))));

  /* "yt/utilities/lib/basic_octree.pyx":94
 *     node.val = <np.float64_t *> malloc(
 *                 nvals * sizeof(np.float64_t))
 *     if incremental:             # <<<<<<<<<<<<<<
 *         for i in range(nvals):
 *             node.val[i] = 0.
 */
  __pyx_t_1 = (__pyx_v_incremental != 0);
  if (__pyx_t_1) {

    /* "yt/utilities/lib/basic_octree.pyx":95
 *                 nvals * sizeof(np.float64_t))
 *     if incremental:
 *         for i in range(nvals):             # <<<<<<<<<<<<<<
 *             node.val[i] = 0.
 *         node.weight_val = 0.
 */
    __pyx_t_2 = __pyx_v_nvals;
    for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
      __pyx_v_i = __pyx_t_3;

      /* "yt/utilities/lib/basic_octree.pyx":96
 *     if incremental:
 *         for i in range(nvals):
 *             node.val[i] = 0.             # <<<<<<<<<<<<<<
 *         node.weight_val = 0.
 *     else:
 */
      (__pyx_v_node->val[__pyx_v_i]) = 0.;
    }

    /* "yt/utilities/lib/basic_octree.pyx":97
 *         for i in range(nvals):
 *             node.val[i] = 0.
 *         node.weight_val = 0.             # <<<<<<<<<<<<<<
 *     else:
 *         for i in range(nvals):
 */
    __pyx_v_node->weight_val = 0.;

    /* "yt/utilities/lib/basic_octree.pyx":94
 *     node.val = <np.float64_t *> malloc(
 *                 nvals * sizeof(np.float64_t))
 *     if incremental:             # <<<<<<<<<<<<<<
 *         for i in range(nvals):
 *             node.val[i] = 0.
 */
    goto __pyx_L3;
  }

  /* "yt/utilities/lib/basic_octree.pyx":99
 *         node.weight_val = 0.
 *     else:
 *         for i in range(nvals):             # <<<<<<<<<<<<<<
 *             node.val[i] = val[i]
 *         node.weight_val = weight_val
 */
  /*else*/ {
    __pyx_t_2 = __pyx_v_nvals;
    for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
      __pyx_v_i = __pyx_t_3;

      /* "yt/utilities/lib/basic_octree.pyx":100
 *     else:
 *         for i in range(nvals):
 *             node.val[i] = val[i]             # <<<<<<<<<<<<<<
 *         node.weight_val = weight_val
 *     for i in range(2):
 */
      (__pyx_v_node->val[__pyx_v_i]) = (__pyx_v_val[__pyx_v_i]);
    }

    /* "yt/utilities/lib/basic_octree.pyx":101
 *         for i in range(nvals):
 *             node.val[i] = val[i]
 *         node.weight_val = weight_val             # <<<<<<<<<<<<<<
 *     for i in range(2):
 *         for j in range(2):
 */
    __pyx_v_node->weight_val = __pyx_v_weight_val;
  }
  __pyx_L3:;

  /* "yt/utilities/lib/basic_octree.pyx":102
 *             node.val[i] = val[i]
 *         node.weight_val = weight_val
 *     for i in range(2):             # <<<<<<<<<<<<<<
 *         for j in range(2):
 *             for k in range(2):
 */
  for (__pyx_t_2 = 0; __pyx_t_2 < 2; __pyx_t_2+=1) {
    __pyx_v_i = __pyx_t_2;

    /* "yt/utilities/lib/basic_octree.pyx":103
 *         node.weight_val = weight_val
 *     for i in range(2):
 *         for j in range(2):             # <<<<<<<<<<<<<<
 *             for k in range(2):
 *                 node.children[i][j][k] = NULL
 */
    for (__pyx_t_3 = 0; __pyx_t_3 < 2; __pyx_t_3+=1) {
      __pyx_v_j = __pyx_t_3;

      /* "yt/utilities/lib/basic_octree.pyx":104
 *     for i in range(2):
 *         for j in range(2):
 *             for k in range(2):             # <<<<<<<<<<<<<<
 *                 node.children[i][j][k] = NULL
 *     node.level = level
 */
      for (__pyx_t_4 = 0; __pyx_t_4 < 2; __pyx_t_4+=1) {
        __pyx_v_k = __pyx_t_4;

        /* "yt/utilities/lib/basic_octree.pyx":105
 *         for j in range(2):
 *             for k in range(2):
 *                 node.children[i][j][k] = NULL             # <<<<<<<<<<<<<<
 *     node.level = level
 *     return node
 */
        (((__pyx_v_node->children[__pyx_v_i])[__pyx_v_j])[__pyx_v_k]) = NULL;
      }
    }
  }

  /* "yt/utilities/lib/basic_octree.pyx":106
 *             for k in range(2):
 *                 node.children[i][j][k] = NULL
 *     node.level = level             # <<<<<<<<<<<<<<
 *     return node
 * 
 */
  __pyx_v_node->level = __pyx_v_level;

  /* "yt/utilities/lib/basic_octree.pyx":107
 *                 node.children[i][j][k] = NULL
 *     node.level = level
 *     return node             # <<<<<<<<<<<<<<
 * 
 * cdef void OTN_free(OctreeNode *node):
 */
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "yt/utilities/lib/basic_octree.pyx":78
 *     self.weight_val = 0.0
 * 
 * cdef OctreeNode *OTN_initialize(np.int64_t pos[3], int nvals,             # <<<<<<<<<<<<<<
 *                         np.float64_t *val, np.float64_t weight_val,
 *                         int level, OctreeNode *parent, int incremental = 0):
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yt/utilities/lib/basic_octree.pyx":109
 *     return node
 * 
 * cdef void OTN_free(OctreeNode *node):             # <<<<<<<<<<<<<<
 *     cdef int i, j, k
 *     for i in range(2):
 */

static void __pyx_f_2yt_9utilities_3lib_12basic_octree_OTN_free(struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node) {
  int __pyx_v_i;
  int __pyx_v_j;
  int __pyx_v_k;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  __Pyx_RefNannySetupContext("OTN_free", 0);

  /* "yt/utilities/lib/basic_octree.pyx":111
 * cdef void OTN_free(OctreeNode *node):
 *     cdef int i, j, k
 *     for i in range(2):             # <<<<<<<<<<<<<<
 *         for j in range(2):
 *             for k in range(2):
 */
  for (__pyx_t_1 = 0; __pyx_t_1 < 2; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "yt/utilities/lib/basic_octree.pyx":112
 *     cdef int i, j, k
 *     for i in range(2):
 *         for j in range(2):             # <<<<<<<<<<<<<<
 *             for k in range(2):
 *                 if node.children[i][j][k] == NULL: continue
 */
    for (__pyx_t_2 = 0; __pyx_t_2 < 2; __pyx_t_2+=1) {
      __pyx_v_j = __pyx_t_2;

      /* "yt/utilities/lib/basic_octree.pyx":113
 *     for i in range(2):
 *         for j in range(2):
 *             for k in range(2):             # <<<<<<<<<<<<<<
 *                 if node.children[i][j][k] == NULL: continue
 *                 OTN_free(node.children[i][j][k])
 */
      for (__pyx_t_3 = 0; __pyx_t_3 < 2; __pyx_t_3+=1) {
        __pyx_v_k = __pyx_t_3;

        /* "yt/utilities/lib/basic_octree.pyx":114
 *         for j in range(2):
 *             for k in range(2):
 *                 if node.children[i][j][k] == NULL: continue             # <<<<<<<<<<<<<<
 *                 OTN_free(node.children[i][j][k])
 *     free(node.val)
 */
        __pyx_t_4 = (((((__pyx_v_node->children[__pyx_v_i])[__pyx_v_j])[__pyx_v_k]) == NULL) != 0);
        if (__pyx_t_4) {
          goto __pyx_L7_continue;
        }

        /* "yt/utilities/lib/basic_octree.pyx":115
 *             for k in range(2):
 *                 if node.children[i][j][k] == NULL: continue
 *                 OTN_free(node.children[i][j][k])             # <<<<<<<<<<<<<<
 *     free(node.val)
 *     free(node)
 */
        __pyx_f_2yt_9utilities_3lib_12basic_octree_OTN_free((((__pyx_v_node->children[__pyx_v_i])[__pyx_v_j])[__pyx_v_k]));
        __pyx_L7_continue:;
      }
    }
  }

  /* "yt/utilities/lib/basic_octree.pyx":116
 *                 if node.children[i][j][k] == NULL: continue
 *                 OTN_free(node.children[i][j][k])
 *     free(node.val)             # <<<<<<<<<<<<<<
 *     free(node)
 * 
 */
  free(__pyx_v_node->val);

  /* "yt/utilities/lib/basic_octree.pyx":117
 *                 OTN_free(node.children[i][j][k])
 *     free(node.val)
 *     free(node)             # <<<<<<<<<<<<<<
 * 
 * cdef class Octree:
 */
  free(__pyx_v_node);

  /* "yt/utilities/lib/basic_octree.pyx":109
 *     return node
 * 
 * cdef void OTN_free(OctreeNode *node):             # <<<<<<<<<<<<<<
 *     cdef int i, j, k
 *     for i in range(2):
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "yt/utilities/lib/basic_octree.pyx":132
 *     cdef OctreeNode *last_node
 * 
 *     def __cinit__(self, np.ndarray[np.int64_t, ndim=1] top_grid_dims,             # <<<<<<<<<<<<<<
 *                   int nvals, int incremental = False):
 *         cdef int i, j, k
 */

/* Python wrapper */
static int __pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_top_grid_dims = 0;
  int __pyx_v_nvals;
  int __pyx_v_incremental;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_top_grid_dims,&__pyx_n_s_nvals,&__pyx_n_s_incremental,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_top_grid_dims)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_nvals)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 2, 3, 1); __PYX_ERR(0, 132, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_incremental);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__cinit__") < 0)) __PYX_ERR(0, 132, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_top_grid_dims = ((PyArrayObject *)values[0]);
    __pyx_v_nvals = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_nvals == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 133, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_incremental = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_incremental == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 133, __pyx_L3_error)
    } else {

      /* "yt/utilities/lib/basic_octree.pyx":133
 * 
 *     def __cinit__(self, np.ndarray[np.int64_t, ndim=1] top_grid_dims,
 *                   int nvals, int incremental = False):             # <<<<<<<<<<<<<<
 *         cdef int i, j, k
 *         self.incremental = incremental
 */
      __pyx_v_incremental = ((int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 132, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("yt.utilities.lib.basic_octree.Octree.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_top_grid_dims), __pyx_ptype_5numpy_ndarray, 1, "top_grid_dims", 0))) __PYX_ERR(0, 132, __pyx_L1_error)
  __pyx_r = __pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree___cinit__(((struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self), __pyx_v_top_grid_dims, __pyx_v_nvals, __pyx_v_incremental);

  /* "yt/utilities/lib/basic_octree.pyx":132
 *     cdef OctreeNode *last_node
 * 
 *     def __cinit__(self, np.ndarray[np.int64_t, ndim=1] top_grid_dims,             # <<<<<<<<<<<<<<
 *                   int nvals, int incremental = False):
 *         cdef int i, j, k
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree___cinit__(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, PyArrayObject *__pyx_v_top_grid_dims, int __pyx_v_nvals, int __pyx_v_incremental) {
  int __pyx_v_i;
  int __pyx_v_j;
  int __pyx_v_k;
  __pyx_t_5numpy_int64_t __pyx_v_pos[3];
  __pyx_t_5numpy_float64_t *__pyx_v_vals;
  __pyx_t_5numpy_float64_t __pyx_v_weight_val;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_top_grid_dims;
  __Pyx_Buffer __pyx_pybuffer_top_grid_dims;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  __pyx_t_5numpy_int64_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  __pyx_t_5numpy_int64_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  int __pyx_t_13;
  Py_ssize_t __pyx_t_14;
  __pyx_t_5numpy_int64_t __pyx_t_15;
  __Pyx_RefNannySetupContext("__cinit__", 0);
  __pyx_pybuffer_top_grid_dims.pybuffer.buf = NULL;
  __pyx_pybuffer_top_grid_dims.refcount = 0;
  __pyx_pybuffernd_top_grid_dims.data = NULL;
  __pyx_pybuffernd_top_grid_dims.rcbuffer = &__pyx_pybuffer_top_grid_dims;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_top_grid_dims.rcbuffer->pybuffer, (PyObject*)__pyx_v_top_grid_dims, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 132, __pyx_L1_error)
  }
  __pyx_pybuffernd_top_grid_dims.diminfo[0].strides = __pyx_pybuffernd_top_grid_dims.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_top_grid_dims.diminfo[0].shape = __pyx_pybuffernd_top_grid_dims.rcbuffer->pybuffer.shape[0];

  /* "yt/utilities/lib/basic_octree.pyx":135
 *                   int nvals, int incremental = False):
 *         cdef int i, j, k
 *         self.incremental = incremental             # <<<<<<<<<<<<<<
 *         cdef np.int64_t pos[3]
 *         cdef np.float64_t *vals = <np.float64_t *> alloca(
 */
  __pyx_v_self->incremental = __pyx_v_incremental;

  /* "yt/utilities/lib/basic_octree.pyx":137
 *         self.incremental = incremental
 *         cdef np.int64_t pos[3]
 *         cdef np.float64_t *vals = <np.float64_t *> alloca(             # <<<<<<<<<<<<<<
 *                 sizeof(np.float64_t)*nvals)
 *         cdef np.float64_t weight_val = 0.0
 */
  __pyx_v_vals = ((__pyx_t_5numpy_float64_t *)alloca(((sizeof(__pyx_t_5numpy_float64_t)) * __pyx_v_nvals)));

  /* "yt/utilities/lib/basic_octree.pyx":139
 *         cdef np.float64_t *vals = <np.float64_t *> alloca(
 *                 sizeof(np.float64_t)*nvals)
 *         cdef np.float64_t weight_val = 0.0             # <<<<<<<<<<<<<<
 *         self.nvals = nvals
 *         for i in range(nvals): vals[i] = 0.0
 */
  __pyx_v_weight_val = 0.0;

  /* "yt/utilities/lib/basic_octree.pyx":140
 *                 sizeof(np.float64_t)*nvals)
 *         cdef np.float64_t weight_val = 0.0
 *         self.nvals = nvals             # <<<<<<<<<<<<<<
 *         for i in range(nvals): vals[i] = 0.0
 * 
 */
  __pyx_v_self->nvals = __pyx_v_nvals;

  /* "yt/utilities/lib/basic_octree.pyx":141
 *         cdef np.float64_t weight_val = 0.0
 *         self.nvals = nvals
 *         for i in range(nvals): vals[i] = 0.0             # <<<<<<<<<<<<<<
 * 
 *         self.top_grid_dims[0] = top_grid_dims[0]
 */
  __pyx_t_1 = __pyx_v_nvals;
  for (__pyx_t_2 = 0; __pyx_t_2 < __pyx_t_1; __pyx_t_2+=1) {
    __pyx_v_i = __pyx_t_2;
    (__pyx_v_vals[__pyx_v_i]) = 0.0;
  }

  /* "yt/utilities/lib/basic_octree.pyx":143
 *         for i in range(nvals): vals[i] = 0.0
 * 
 *         self.top_grid_dims[0] = top_grid_dims[0]             # <<<<<<<<<<<<<<
 *         self.top_grid_dims[1] = top_grid_dims[1]
 *         self.top_grid_dims[2] = top_grid_dims[2]
 */
  __pyx_t_3 = 0;
  __pyx_t_1 = -1;
  if (__pyx_t_3 < 0) {
    __pyx_t_3 += __pyx_pybuffernd_top_grid_dims.diminfo[0].shape;
    if (unlikely(__pyx_t_3 < 0)) __pyx_t_1 = 0;
  } else if (unlikely(__pyx_t_3 >= __pyx_pybuffernd_top_grid_dims.diminfo[0].shape)) __pyx_t_1 = 0;
  if (unlikely(__pyx_t_1 != -1)) {
    __Pyx_RaiseBufferIndexError(__pyx_t_1);
    __PYX_ERR(0, 143, __pyx_L1_error)
  }
  (__pyx_v_self->top_grid_dims[0]) = (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_int64_t *, __pyx_pybuffernd_top_grid_dims.rcbuffer->pybuffer.buf, __pyx_t_3, __pyx_pybuffernd_top_grid_dims.diminfo[0].strides));

  /* "yt/utilities/lib/basic_octree.pyx":144
 * 
 *         self.top_grid_dims[0] = top_grid_dims[0]
 *         self.top_grid_dims[1] = top_grid_dims[1]             # <<<<<<<<<<<<<<
 *         self.top_grid_dims[2] = top_grid_dims[2]
 * 
 */
  __pyx_t_4 = 1;
  __pyx_t_1 = -1;
  if (__pyx_t_4 < 0) {
    __pyx_t_4 += __pyx_pybuffernd_top_grid_dims.diminfo[0].shape;
    if (unlikely(__pyx_t_4 < 0)) __pyx_t_1 = 0;
  } else if (unlikely(__pyx_t_4 >= __pyx_pybuffernd_top_grid_dims.diminfo[0].shape)) __pyx_t_1 = 0;
  if (unlikely(__pyx_t_1 != -1)) {
    __Pyx_RaiseBufferIndexError(__pyx_t_1);
    __PYX_ERR(0, 144, __pyx_L1_error)
  }
  (__pyx_v_self->top_grid_dims[1]) = (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_int64_t *, __pyx_pybuffernd_top_grid_dims.rcbuffer->pybuffer.buf, __pyx_t_4, __pyx_pybuffernd_top_grid_dims.diminfo[0].strides));

  /* "yt/utilities/lib/basic_octree.pyx":145
 *         self.top_grid_dims[0] = top_grid_dims[0]
 *         self.top_grid_dims[1] = top_grid_dims[1]
 *         self.top_grid_dims[2] = top_grid_dims[2]             # <<<<<<<<<<<<<<
 * 
 *         # This wouldn't be necessary if we did bitshifting...
 */
  __pyx_t_5 = 2;
  __pyx_t_1 = -1;
  if (__pyx_t_5 < 0) {
    __pyx_t_5 += __pyx_pybuffernd_top_grid_dims.diminfo[0].shape;
    if (unlikely(__pyx_t_5 < 0)) __pyx_t_1 = 0;
  } else if (unlikely(__pyx_t_5 >= __pyx_pybuffernd_top_grid_dims.diminfo[0].shape)) __pyx_t_1 = 0;
  if (unlikely(__pyx_t_1 != -1)) {
    __Pyx_RaiseBufferIndexError(__pyx_t_1);
    __PYX_ERR(0, 145, __pyx_L1_error)
  }
  (__pyx_v_self->top_grid_dims[2]) = (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_int64_t *, __pyx_pybuffernd_top_grid_dims.rcbuffer->pybuffer.buf, __pyx_t_5, __pyx_pybuffernd_top_grid_dims.diminfo[0].strides));

  /* "yt/utilities/lib/basic_octree.pyx":148
 * 
 *         # This wouldn't be necessary if we did bitshifting...
 *         for i in range(80):             # <<<<<<<<<<<<<<
 *             self.po2[i] = 2**i
 *         # Cython doesn't seem to like sizeof(OctreeNode ***)
 */
  for (__pyx_t_1 = 0; __pyx_t_1 < 80; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "yt/utilities/lib/basic_octree.pyx":149
 *         # This wouldn't be necessary if we did bitshifting...
 *         for i in range(80):
 *             self.po2[i] = 2**i             # <<<<<<<<<<<<<<
 *         # Cython doesn't seem to like sizeof(OctreeNode ***)
 *         self.root_nodes = <OctreeNode ****> \
 */
    (__pyx_v_self->po2[__pyx_v_i]) = __Pyx_pow_long(2, ((long)__pyx_v_i));
  }

  /* "yt/utilities/lib/basic_octree.pyx":152
 *         # Cython doesn't seem to like sizeof(OctreeNode ***)
 *         self.root_nodes = <OctreeNode ****> \
 *             malloc(sizeof(void*) * top_grid_dims[0])             # <<<<<<<<<<<<<<
 * 
 *         # We initialize our root values to 0.0.
 */
  __pyx_t_6 = 0;
  __pyx_t_1 = -1;
  if (__pyx_t_6 < 0) {
    __pyx_t_6 += __pyx_pybuffernd_top_grid_dims.diminfo[0].shape;
    if (unlikely(__pyx_t_6 < 0)) __pyx_t_1 = 0;
  } else if (unlikely(__pyx_t_6 >= __pyx_pybuffernd_top_grid_dims.diminfo[0].shape)) __pyx_t_1 = 0;
  if (unlikely(__pyx_t_1 != -1)) {
    __Pyx_RaiseBufferIndexError(__pyx_t_1);
    __PYX_ERR(0, 152, __pyx_L1_error)
  }

  /* "yt/utilities/lib/basic_octree.pyx":151
 *             self.po2[i] = 2**i
 *         # Cython doesn't seem to like sizeof(OctreeNode ***)
 *         self.root_nodes = <OctreeNode ****> \             # <<<<<<<<<<<<<<
 *             malloc(sizeof(void*) * top_grid_dims[0])
 * 
 */
  __pyx_v_self->root_nodes = ((struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode ****)malloc(((sizeof(void *)) * (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_int64_t *, __pyx_pybuffernd_top_grid_dims.rcbuffer->pybuffer.buf, __pyx_t_6, __pyx_pybuffernd_top_grid_dims.diminfo[0].strides)))));

  /* "yt/utilities/lib/basic_octree.pyx":155
 * 
 *         # We initialize our root values to 0.0.
 *         for i in range(top_grid_dims[0]):             # <<<<<<<<<<<<<<
 *             pos[0] = i
 *             self.root_nodes[i] = <OctreeNode ***> \
 */
  __pyx_t_7 = 0;
  __pyx_t_1 = -1;
  if (__pyx_t_7 < 0) {
    __pyx_t_7 += __pyx_pybuffernd_top_grid_dims.diminfo[0].shape;
    if (unlikely(__pyx_t_7 < 0)) __pyx_t_1 = 0;
  } else if (unlikely(__pyx_t_7 >= __pyx_pybuffernd_top_grid_dims.diminfo[0].shape)) __pyx_t_1 = 0;
  if (unlikely(__pyx_t_1 != -1)) {
    __Pyx_RaiseBufferIndexError(__pyx_t_1);
    __PYX_ERR(0, 155, __pyx_L1_error)
  }
  __pyx_t_8 = (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_int64_t *, __pyx_pybuffernd_top_grid_dims.rcbuffer->pybuffer.buf, __pyx_t_7, __pyx_pybuffernd_top_grid_dims.diminfo[0].strides));
  for (__pyx_t_1 = 0; __pyx_t_1 < __pyx_t_8; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "yt/utilities/lib/basic_octree.pyx":156
 *         # We initialize our root values to 0.0.
 *         for i in range(top_grid_dims[0]):
 *             pos[0] = i             # <<<<<<<<<<<<<<
 *             self.root_nodes[i] = <OctreeNode ***> \
 *                 malloc(sizeof(OctreeNode **) * top_grid_dims[1])
 */
    (__pyx_v_pos[0]) = __pyx_v_i;

    /* "yt/utilities/lib/basic_octree.pyx":158
 *             pos[0] = i
 *             self.root_nodes[i] = <OctreeNode ***> \
 *                 malloc(sizeof(OctreeNode **) * top_grid_dims[1])             # <<<<<<<<<<<<<<
 *             for j in range(top_grid_dims[1]):
 *                 pos[1] = j
 */
    __pyx_t_9 = 1;
    __pyx_t_2 = -1;
    if (__pyx_t_9 < 0) {
      __pyx_t_9 += __pyx_pybuffernd_top_grid_dims.diminfo[0].shape;
      if (unlikely(__pyx_t_9 < 0)) __pyx_t_2 = 0;
    } else if (unlikely(__pyx_t_9 >= __pyx_pybuffernd_top_grid_dims.diminfo[0].shape)) __pyx_t_2 = 0;
    if (unlikely(__pyx_t_2 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_2);
      __PYX_ERR(0, 158, __pyx_L1_error)
    }

    /* "yt/utilities/lib/basic_octree.pyx":157
 *         for i in range(top_grid_dims[0]):
 *             pos[0] = i
 *             self.root_nodes[i] = <OctreeNode ***> \             # <<<<<<<<<<<<<<
 *                 malloc(sizeof(OctreeNode **) * top_grid_dims[1])
 *             for j in range(top_grid_dims[1]):
 */
    (__pyx_v_self->root_nodes[__pyx_v_i]) = ((struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode ***)malloc(((sizeof(struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode **)) * (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_int64_t *, __pyx_pybuffernd_top_grid_dims.rcbuffer->pybuffer.buf, __pyx_t_9, __pyx_pybuffernd_top_grid_dims.diminfo[0].strides)))));

    /* "yt/utilities/lib/basic_octree.pyx":159
 *             self.root_nodes[i] = <OctreeNode ***> \
 *                 malloc(sizeof(OctreeNode **) * top_grid_dims[1])
 *             for j in range(top_grid_dims[1]):             # <<<<<<<<<<<<<<
 *                 pos[1] = j
 *                 self.root_nodes[i][j] = <OctreeNode **> \
 */
    __pyx_t_10 = 1;
    __pyx_t_2 = -1;
    if (__pyx_t_10 < 0) {
      __pyx_t_10 += __pyx_pybuffernd_top_grid_dims.diminfo[0].shape;
      if (unlikely(__pyx_t_10 < 0)) __pyx_t_2 = 0;
    } else if (unlikely(__pyx_t_10 >= __pyx_pybuffernd_top_grid_dims.diminfo[0].shape)) __pyx_t_2 = 0;
    if (unlikely(__pyx_t_2 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_2);
      __PYX_ERR(0, 159, __pyx_L1_error)
    }
    __pyx_t_11 = (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_int64_t *, __pyx_pybuffernd_top_grid_dims.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_top_grid_dims.diminfo[0].strides));
    for (__pyx_t_2 = 0; __pyx_t_2 < __pyx_t_11; __pyx_t_2+=1) {
      __pyx_v_j = __pyx_t_2;

      /* "yt/utilities/lib/basic_octree.pyx":160
 *                 malloc(sizeof(OctreeNode **) * top_grid_dims[1])
 *             for j in range(top_grid_dims[1]):
 *                 pos[1] = j             # <<<<<<<<<<<<<<
 *                 self.root_nodes[i][j] = <OctreeNode **> \
 *                     malloc(sizeof(OctreeNode *) * top_grid_dims[1])
 */
      (__pyx_v_pos[1]) = __pyx_v_j;

      /* "yt/utilities/lib/basic_octree.pyx":162
 *                 pos[1] = j
 *                 self.root_nodes[i][j] = <OctreeNode **> \
 *                     malloc(sizeof(OctreeNode *) * top_grid_dims[1])             # <<<<<<<<<<<<<<
 *                 for k in range(top_grid_dims[2]):
 *                     pos[2] = k
 */
      __pyx_t_12 = 1;
      __pyx_t_13 = -1;
      if (__pyx_t_12 < 0) {
        __pyx_t_12 += __pyx_pybuffernd_top_grid_dims.diminfo[0].shape;
        if (unlikely(__pyx_t_12 < 0)) __pyx_t_13 = 0;
      } else if (unlikely(__pyx_t_12 >= __pyx_pybuffernd_top_grid_dims.diminfo[0].shape)) __pyx_t_13 = 0;
      if (unlikely(__pyx_t_13 != -1)) {
        __Pyx_RaiseBufferIndexError(__pyx_t_13);
        __PYX_ERR(0, 162, __pyx_L1_error)
      }

      /* "yt/utilities/lib/basic_octree.pyx":161
 *             for j in range(top_grid_dims[1]):
 *                 pos[1] = j
 *                 self.root_nodes[i][j] = <OctreeNode **> \             # <<<<<<<<<<<<<<
 *                     malloc(sizeof(OctreeNode *) * top_grid_dims[1])
 *                 for k in range(top_grid_dims[2]):
 */
      ((__pyx_v_self->root_nodes[__pyx_v_i])[__pyx_v_j]) = ((struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode **)malloc(((sizeof(struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *)) * (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_int64_t *, __pyx_pybuffernd_top_grid_dims.rcbuffer->pybuffer.buf, __pyx_t_12, __pyx_pybuffernd_top_grid_dims.diminfo[0].strides)))));

      /* "yt/utilities/lib/basic_octree.pyx":163
 *                 self.root_nodes[i][j] = <OctreeNode **> \
 *                     malloc(sizeof(OctreeNode *) * top_grid_dims[1])
 *                 for k in range(top_grid_dims[2]):             # <<<<<<<<<<<<<<
 *                     pos[2] = k
 *                     self.root_nodes[i][j][k] = OTN_initialize(
 */
      __pyx_t_14 = 2;
      __pyx_t_13 = -1;
      if (__pyx_t_14 < 0) {
        __pyx_t_14 += __pyx_pybuffernd_top_grid_dims.diminfo[0].shape;
        if (unlikely(__pyx_t_14 < 0)) __pyx_t_13 = 0;
      } else if (unlikely(__pyx_t_14 >= __pyx_pybuffernd_top_grid_dims.diminfo[0].shape)) __pyx_t_13 = 0;
      if (unlikely(__pyx_t_13 != -1)) {
        __Pyx_RaiseBufferIndexError(__pyx_t_13);
        __PYX_ERR(0, 163, __pyx_L1_error)
      }
      __pyx_t_15 = (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_int64_t *, __pyx_pybuffernd_top_grid_dims.rcbuffer->pybuffer.buf, __pyx_t_14, __pyx_pybuffernd_top_grid_dims.diminfo[0].strides));
      for (__pyx_t_13 = 0; __pyx_t_13 < __pyx_t_15; __pyx_t_13+=1) {
        __pyx_v_k = __pyx_t_13;

        /* "yt/utilities/lib/basic_octree.pyx":164
 *                     malloc(sizeof(OctreeNode *) * top_grid_dims[1])
 *                 for k in range(top_grid_dims[2]):
 *                     pos[2] = k             # <<<<<<<<<<<<<<
 *                     self.root_nodes[i][j][k] = OTN_initialize(
 *                         pos, nvals, vals, weight_val, 0, NULL)
 */
        (__pyx_v_pos[2]) = __pyx_v_k;

        /* "yt/utilities/lib/basic_octree.pyx":165
 *                 for k in range(top_grid_dims[2]):
 *                     pos[2] = k
 *                     self.root_nodes[i][j][k] = OTN_initialize(             # <<<<<<<<<<<<<<
 *                         pos, nvals, vals, weight_val, 0, NULL)
 * 
 */
        (((__pyx_v_self->root_nodes[__pyx_v_i])[__pyx_v_j])[__pyx_v_k]) = __pyx_f_2yt_9utilities_3lib_12basic_octree_OTN_initialize(__pyx_v_pos, __pyx_v_nvals, __pyx_v_vals, __pyx_v_weight_val, 0, NULL, NULL);
      }
    }
  }

  /* "yt/utilities/lib/basic_octree.pyx":132
 *     cdef OctreeNode *last_node
 * 
 *     def __cinit__(self, np.ndarray[np.int64_t, ndim=1] top_grid_dims,             # <<<<<<<<<<<<<<
 *                   int nvals, int incremental = False):
 *         cdef int i, j, k
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_top_grid_dims.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("yt.utilities.lib.basic_octree.Octree.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_top_grid_dims.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yt/utilities/lib/basic_octree.pyx":168
 *                         pos, nvals, vals, weight_val, 0, NULL)
 * 
 *     cdef void add_to_position(self,             # <<<<<<<<<<<<<<
 *                  int level, np.int64_t pos[3],
 *                  np.float64_t *val,
 */

static void __pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_add_to_position(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, int __pyx_v_level, __pyx_t_5numpy_int64_t *__pyx_v_pos, __pyx_t_5numpy_float64_t *__pyx_v_val, __pyx_t_5numpy_float64_t __pyx_v_weight_val, PyObject *__pyx_v_treecode) {
  int __pyx_v_i;
  int __pyx_v_j;
  int __pyx_v_k;
  int __pyx_v_L;
  struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node;
  __pyx_t_5numpy_int64_t __pyx_v_fac;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  struct __pyx_opt_args_2yt_9utilities_3lib_12basic_octree_OTN_refine __pyx_t_5;
  __Pyx_RefNannySetupContext("add_to_position", 0);

  /* "yt/utilities/lib/basic_octree.pyx":174
 *         cdef int i, j, k, L
 *         cdef OctreeNode *node
 *         node = self.find_on_root_level(pos, level)             # <<<<<<<<<<<<<<
 *         cdef np.int64_t fac
 *         for L in range(level):
 */
  __pyx_v_node = ((struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self->__pyx_vtab)->find_on_root_level(__pyx_v_self, __pyx_v_pos, __pyx_v_level);

  /* "yt/utilities/lib/basic_octree.pyx":176
 *         node = self.find_on_root_level(pos, level)
 *         cdef np.int64_t fac
 *         for L in range(level):             # <<<<<<<<<<<<<<
 *             if self.incremental:
 *                 OTN_add_value(node, val, weight_val, level, treecode)
 */
  __pyx_t_1 = __pyx_v_level;
  for (__pyx_t_2 = 0; __pyx_t_2 < __pyx_t_1; __pyx_t_2+=1) {
    __pyx_v_L = __pyx_t_2;

    /* "yt/utilities/lib/basic_octree.pyx":177
 *         cdef np.int64_t fac
 *         for L in range(level):
 *             if self.incremental:             # <<<<<<<<<<<<<<
 *                 OTN_add_value(node, val, weight_val, level, treecode)
 *             if node.children[0][0][0] == NULL:
 */
    __pyx_t_3 = (__pyx_v_self->incremental != 0);
    if (__pyx_t_3) {

      /* "yt/utilities/lib/basic_octree.pyx":178
 *         for L in range(level):
 *             if self.incremental:
 *                 OTN_add_value(node, val, weight_val, level, treecode)             # <<<<<<<<<<<<<<
 *             if node.children[0][0][0] == NULL:
 *                 OTN_refine(node, self.incremental)
 */
      __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_v_treecode); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 178, __pyx_L1_error)
      __pyx_f_2yt_9utilities_3lib_12basic_octree_OTN_add_value(__pyx_v_node, __pyx_v_val, __pyx_v_weight_val, __pyx_v_level, __pyx_t_4);

      /* "yt/utilities/lib/basic_octree.pyx":177
 *         cdef np.int64_t fac
 *         for L in range(level):
 *             if self.incremental:             # <<<<<<<<<<<<<<
 *                 OTN_add_value(node, val, weight_val, level, treecode)
 *             if node.children[0][0][0] == NULL:
 */
    }

    /* "yt/utilities/lib/basic_octree.pyx":179
 *             if self.incremental:
 *                 OTN_add_value(node, val, weight_val, level, treecode)
 *             if node.children[0][0][0] == NULL:             # <<<<<<<<<<<<<<
 *                 OTN_refine(node, self.incremental)
 *             # Maybe we should use bitwise operators?
 */
    __pyx_t_3 = (((((__pyx_v_node->children[0])[0])[0]) == NULL) != 0);
    if (__pyx_t_3) {

      /* "yt/utilities/lib/basic_octree.pyx":180
 *                 OTN_add_value(node, val, weight_val, level, treecode)
 *             if node.children[0][0][0] == NULL:
 *                 OTN_refine(node, self.incremental)             # <<<<<<<<<<<<<<
 *             # Maybe we should use bitwise operators?
 *             fac = self.po2[level - L - 1]
 */
      __pyx_t_5.__pyx_n = 1;
      __pyx_t_5.incremental = __pyx_v_self->incremental;
      __pyx_f_2yt_9utilities_3lib_12basic_octree_OTN_refine(__pyx_v_node, &__pyx_t_5); 

      /* "yt/utilities/lib/basic_octree.pyx":179
 *             if self.incremental:
 *                 OTN_add_value(node, val, weight_val, level, treecode)
 *             if node.children[0][0][0] == NULL:             # <<<<<<<<<<<<<<
 *                 OTN_refine(node, self.incremental)
 *             # Maybe we should use bitwise operators?
 */
    }

    /* "yt/utilities/lib/basic_octree.pyx":182
 *                 OTN_refine(node, self.incremental)
 *             # Maybe we should use bitwise operators?
 *             fac = self.po2[level - L - 1]             # <<<<<<<<<<<<<<
 *             i = (pos[0] >= fac*(2*node.pos[0]+1))
 *             j = (pos[1] >= fac*(2*node.pos[1]+1))
 */
    __pyx_v_fac = (__pyx_v_self->po2[((__pyx_v_level - __pyx_v_L) - 1)]);

    /* "yt/utilities/lib/basic_octree.pyx":183
 *             # Maybe we should use bitwise operators?
 *             fac = self.po2[level - L - 1]
 *             i = (pos[0] >= fac*(2*node.pos[0]+1))             # <<<<<<<<<<<<<<
 *             j = (pos[1] >= fac*(2*node.pos[1]+1))
 *             k = (pos[2] >= fac*(2*node.pos[2]+1))
 */
    __pyx_v_i = ((__pyx_v_pos[0]) >= (__pyx_v_fac * ((2 * (__pyx_v_node->pos[0])) + 1)));

    /* "yt/utilities/lib/basic_octree.pyx":184
 *             fac = self.po2[level - L - 1]
 *             i = (pos[0] >= fac*(2*node.pos[0]+1))
 *             j = (pos[1] >= fac*(2*node.pos[1]+1))             # <<<<<<<<<<<<<<
 *             k = (pos[2] >= fac*(2*node.pos[2]+1))
 *             node = node.children[i][j][k]
 */
    __pyx_v_j = ((__pyx_v_pos[1]) >= (__pyx_v_fac * ((2 * (__pyx_v_node->pos[1])) + 1)));

    /* "yt/utilities/lib/basic_octree.pyx":185
 *             i = (pos[0] >= fac*(2*node.pos[0]+1))
 *             j = (pos[1] >= fac*(2*node.pos[1]+1))
 *             k = (pos[2] >= fac*(2*node.pos[2]+1))             # <<<<<<<<<<<<<<
 *             node = node.children[i][j][k]
 *         OTN_add_value(node, val, weight_val, level, treecode)
 */
    __pyx_v_k = ((__pyx_v_pos[2]) >= (__pyx_v_fac * ((2 * (__pyx_v_node->pos[2])) + 1)));

    /* "yt/utilities/lib/basic_octree.pyx":186
 *             j = (pos[1] >= fac*(2*node.pos[1]+1))
 *             k = (pos[2] >= fac*(2*node.pos[2]+1))
 *             node = node.children[i][j][k]             # <<<<<<<<<<<<<<
 *         OTN_add_value(node, val, weight_val, level, treecode)
 * 
 */
    __pyx_v_node = (((__pyx_v_node->children[__pyx_v_i])[__pyx_v_j])[__pyx_v_k]);
  }

  /* "yt/utilities/lib/basic_octree.pyx":187
 *             k = (pos[2] >= fac*(2*node.pos[2]+1))
 *             node = node.children[i][j][k]
 *         OTN_add_value(node, val, weight_val, level, treecode)             # <<<<<<<<<<<<<<
 * 
 *     cdef OctreeNode *find_on_root_level(self, np.int64_t pos[3], int level):
 */
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_treecode); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 187, __pyx_L1_error)
  __pyx_f_2yt_9utilities_3lib_12basic_octree_OTN_add_value(__pyx_v_node, __pyx_v_val, __pyx_v_weight_val, __pyx_v_level, __pyx_t_1);

  /* "yt/utilities/lib/basic_octree.pyx":168
 *                         pos, nvals, vals, weight_val, 0, NULL)
 * 
 *     cdef void add_to_position(self,             # <<<<<<<<<<<<<<
 *                  int level, np.int64_t pos[3],
 *                  np.float64_t *val,
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_WriteUnraisable("yt.utilities.lib.basic_octree.Octree.add_to_position", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "yt/utilities/lib/basic_octree.pyx":189
 *         OTN_add_value(node, val, weight_val, level, treecode)
 * 
 *     cdef OctreeNode *find_on_root_level(self, np.int64_t pos[3], int level):             # <<<<<<<<<<<<<<
 *         # We need this because the root level won't just have four children
 *         # So we find on the root level, then we traverse the tree.
 */

static struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_find_on_root_level(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, __pyx_t_5numpy_int64_t *__pyx_v_pos, int __pyx_v_level) {
  __pyx_t_5numpy_int64_t __pyx_v_i;
  __pyx_t_5numpy_int64_t __pyx_v_j;
  __pyx_t_5numpy_int64_t __pyx_v_k;
  struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("find_on_root_level", 0);

  /* "yt/utilities/lib/basic_octree.pyx":193
 *         # So we find on the root level, then we traverse the tree.
 *         cdef np.int64_t i, j, k
 *         i = <np.int64_t> (pos[0] / self.po2[level])             # <<<<<<<<<<<<<<
 *         j = <np.int64_t> (pos[1] / self.po2[level])
 *         k = <np.int64_t> (pos[2] / self.po2[level])
 */
  if (unlikely((__pyx_v_self->po2[__pyx_v_level]) == 0)) {
    PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
    __PYX_ERR(0, 193, __pyx_L1_error)
  }
  else if (sizeof(__pyx_t_5numpy_int64_t) == sizeof(long) && (!(((__pyx_t_5numpy_int64_t)-1) > 0)) && unlikely((__pyx_v_self->po2[__pyx_v_level]) == (__pyx_t_5numpy_int64_t)-1)  && unlikely(UNARY_NEG_WOULD_OVERFLOW((__pyx_v_pos[0])))) {
    PyErr_SetString(PyExc_OverflowError, "value too large to perform division");
    __PYX_ERR(0, 193, __pyx_L1_error)
  }
  __pyx_v_i = ((__pyx_t_5numpy_int64_t)__Pyx_div___pyx_t_5numpy_int64_t((__pyx_v_pos[0]), (__pyx_v_self->po2[__pyx_v_level])));

  /* "yt/utilities/lib/basic_octree.pyx":194
 *         cdef np.int64_t i, j, k
 *         i = <np.int64_t> (pos[0] / self.po2[level])
 *         j = <np.int64_t> (pos[1] / self.po2[level])             # <<<<<<<<<<<<<<
 *         k = <np.int64_t> (pos[2] / self.po2[level])
 *         return self.root_nodes[i][j][k]
 */
  if (unlikely((__pyx_v_self->po2[__pyx_v_level]) == 0)) {
    PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
    __PYX_ERR(0, 194, __pyx_L1_error)
  }
  else if (sizeof(__pyx_t_5numpy_int64_t) == sizeof(long) && (!(((__pyx_t_5numpy_int64_t)-1) > 0)) && unlikely((__pyx_v_self->po2[__pyx_v_level]) == (__pyx_t_5numpy_int64_t)-1)  && unlikely(UNARY_NEG_WOULD_OVERFLOW((__pyx_v_pos[1])))) {
    PyErr_SetString(PyExc_OverflowError, "value too large to perform division");
    __PYX_ERR(0, 194, __pyx_L1_error)
  }
  __pyx_v_j = ((__pyx_t_5numpy_int64_t)__Pyx_div___pyx_t_5numpy_int64_t((__pyx_v_pos[1]), (__pyx_v_self->po2[__pyx_v_level])));

  /* "yt/utilities/lib/basic_octree.pyx":195
 *         i = <np.int64_t> (pos[0] / self.po2[level])
 *         j = <np.int64_t> (pos[1] / self.po2[level])
 *         k = <np.int64_t> (pos[2] / self.po2[level])             # <<<<<<<<<<<<<<
 *         return self.root_nodes[i][j][k]
 * 
 */
  if (unlikely((__pyx_v_self->po2[__pyx_v_level]) == 0)) {
    PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
    __PYX_ERR(0, 195, __pyx_L1_error)
  }
  else if (sizeof(__pyx_t_5numpy_int64_t) == sizeof(long) && (!(((__pyx_t_5numpy_int64_t)-1) > 0)) && unlikely((__pyx_v_self->po2[__pyx_v_level]) == (__pyx_t_5numpy_int64_t)-1)  && unlikely(UNARY_NEG_WOULD_OVERFLOW((__pyx_v_pos[2])))) {
    PyErr_SetString(PyExc_OverflowError, "value too large to perform division");
    __PYX_ERR(0, 195, __pyx_L1_error)
  }
  __pyx_v_k = ((__pyx_t_5numpy_int64_t)__Pyx_div___pyx_t_5numpy_int64_t((__pyx_v_pos[2]), (__pyx_v_self->po2[__pyx_v_level])));

  /* "yt/utilities/lib/basic_octree.pyx":196
 *         j = <np.int64_t> (pos[1] / self.po2[level])
 *         k = <np.int64_t> (pos[2] / self.po2[level])
 *         return self.root_nodes[i][j][k]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = (((__pyx_v_self->root_nodes[__pyx_v_i])[__pyx_v_j])[__pyx_v_k]);
  goto __pyx_L0;

  /* "yt/utilities/lib/basic_octree.pyx":189
 *         OTN_add_value(node, val, weight_val, level, treecode)
 * 
 *     cdef OctreeNode *find_on_root_level(self, np.int64_t pos[3], int level):             # <<<<<<<<<<<<<<
 *         # We need this because the root level won't just have four children
 *         # So we find on the root level, then we traverse the tree.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_WriteUnraisable("yt.utilities.lib.basic_octree.Octree.find_on_root_level", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yt/utilities/lib/basic_octree.pyx":201
 *     @cython.boundscheck(False)
 *     @cython.wraparound(False)
 *     def add_array_to_tree(self, int level,             # <<<<<<<<<<<<<<
 *             np.ndarray[np.int64_t, ndim=1] pxs,
 *             np.ndarray[np.int64_t, ndim=1] pys,
 */

/* Python wrapper */
static PyObject *__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_3add_array_to_tree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_3add_array_to_tree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_v_level;
  PyArrayObject *__pyx_v_pxs = 0;
  PyArrayObject *__pyx_v_pys = 0;
  PyArrayObject *__pyx_v_pzs = 0;
  PyArrayObject *__pyx_v_pvals = 0;
  PyArrayObject *__pyx_v_pweight_vals = 0;
  int __pyx_v_treecode;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add_array_to_tree (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_level,&__pyx_n_s_pxs,&__pyx_n_s_pys,&__pyx_n_s_pzs,&__pyx_n_s_pvals,&__pyx_n_s_pweight_vals,&__pyx_n_s_treecode,0};
    PyObject* values[7] = {0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_level)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_pxs)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("add_array_to_tree", 0, 6, 7, 1); __PYX_ERR(0, 201, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_pys)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("add_array_to_tree", 0, 6, 7, 2); __PYX_ERR(0, 201, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_pzs)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("add_array_to_tree", 0, 6, 7, 3); __PYX_ERR(0, 201, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_pvals)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("add_array_to_tree", 0, 6, 7, 4); __PYX_ERR(0, 201, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_pweight_vals)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("add_array_to_tree", 0, 6, 7, 5); __PYX_ERR(0, 201, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_treecode);
          if (value) { values[6] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "add_array_to_tree") < 0)) __PYX_ERR(0, 201, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_level = __Pyx_PyInt_As_int(values[0]); if (unlikely((__pyx_v_level == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 201, __pyx_L3_error)
    __pyx_v_pxs = ((PyArrayObject *)values[1]);
    __pyx_v_pys = ((PyArrayObject *)values[2]);
    __pyx_v_pzs = ((PyArrayObject *)values[3]);
    __pyx_v_pvals = ((PyArrayObject *)values[4]);
    __pyx_v_pweight_vals = ((PyArrayObject *)values[5]);
    if (values[6]) {
      __pyx_v_treecode = __Pyx_PyInt_As_int(values[6]); if (unlikely((__pyx_v_treecode == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 207, __pyx_L3_error)
    } else {
      __pyx_v_treecode = ((int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("add_array_to_tree", 0, 6, 7, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 201, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("yt.utilities.lib.basic_octree.Octree.add_array_to_tree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_pxs), __pyx_ptype_5numpy_ndarray, 1, "pxs", 0))) __PYX_ERR(0, 202, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_pys), __pyx_ptype_5numpy_ndarray, 1, "pys", 0))) __PYX_ERR(0, 203, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_pzs), __pyx_ptype_5numpy_ndarray, 1, "pzs", 0))) __PYX_ERR(0, 204, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_pvals), __pyx_ptype_5numpy_ndarray, 1, "pvals", 0))) __PYX_ERR(0, 205, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_pweight_vals), __pyx_ptype_5numpy_ndarray, 1, "pweight_vals", 0))) __PYX_ERR(0, 206, __pyx_L1_error)
  __pyx_r = __pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_2add_array_to_tree(((struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self), __pyx_v_level, __pyx_v_pxs, __pyx_v_pys, __pyx_v_pzs, __pyx_v_pvals, __pyx_v_pweight_vals, __pyx_v_treecode);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_2add_array_to_tree(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, int __pyx_v_level, PyArrayObject *__pyx_v_pxs, PyArrayObject *__pyx_v_pys, PyArrayObject *__pyx_v_pzs, PyArrayObject *__pyx_v_pvals, PyArrayObject *__pyx_v_pweight_vals, int __pyx_v_treecode) {
  int __pyx_v_np;
  int __pyx_v_p;
  __pyx_t_5numpy_float64_t *__pyx_v_vals;
  __pyx_t_5numpy_float64_t *__pyx_v_data;
  __pyx_t_5numpy_int64_t __pyx_v_pos[3];
  __Pyx_LocalBuf_ND __pyx_pybuffernd_pvals;
  __Pyx_Buffer __pyx_pybuffer_pvals;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_pweight_vals;
  __Pyx_Buffer __pyx_pybuffer_pweight_vals;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_pxs;
  __Pyx_Buffer __pyx_pybuffer_pxs;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_pys;
  __Pyx_Buffer __pyx_pybuffer_pys;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_pzs;
  __Pyx_Buffer __pyx_pybuffer_pzs;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("add_array_to_tree", 0);
  __pyx_pybuffer_pxs.pybuffer.buf = NULL;
  __pyx_pybuffer_pxs.refcount = 0;
  __pyx_pybuffernd_pxs.data = NULL;
  __pyx_pybuffernd_pxs.rcbuffer = &__pyx_pybuffer_pxs;
  __pyx_pybuffer_pys.pybuffer.buf = NULL;
  __pyx_pybuffer_pys.refcount = 0;
  __pyx_pybuffernd_pys.data = NULL;
  __pyx_pybuffernd_pys.rcbuffer = &__pyx_pybuffer_pys;
  __pyx_pybuffer_pzs.pybuffer.buf = NULL;
  __pyx_pybuffer_pzs.refcount = 0;
  __pyx_pybuffernd_pzs.data = NULL;
  __pyx_pybuffernd_pzs.rcbuffer = &__pyx_pybuffer_pzs;
  __pyx_pybuffer_pvals.pybuffer.buf = NULL;
  __pyx_pybuffer_pvals.refcount = 0;
  __pyx_pybuffernd_pvals.data = NULL;
  __pyx_pybuffernd_pvals.rcbuffer = &__pyx_pybuffer_pvals;
  __pyx_pybuffer_pweight_vals.pybuffer.buf = NULL;
  __pyx_pybuffer_pweight_vals.refcount = 0;
  __pyx_pybuffernd_pweight_vals.data = NULL;
  __pyx_pybuffernd_pweight_vals.rcbuffer = &__pyx_pybuffer_pweight_vals;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_pxs.rcbuffer->pybuffer, (PyObject*)__pyx_v_pxs, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 201, __pyx_L1_error)
  }
  __pyx_pybuffernd_pxs.diminfo[0].strides = __pyx_pybuffernd_pxs.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_pxs.diminfo[0].shape = __pyx_pybuffernd_pxs.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_pys.rcbuffer->pybuffer, (PyObject*)__pyx_v_pys, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 201, __pyx_L1_error)
  }
  __pyx_pybuffernd_pys.diminfo[0].strides = __pyx_pybuffernd_pys.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_pys.diminfo[0].shape = __pyx_pybuffernd_pys.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_pzs.rcbuffer->pybuffer, (PyObject*)__pyx_v_pzs, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 201, __pyx_L1_error)
  }
  __pyx_pybuffernd_pzs.diminfo[0].strides = __pyx_pybuffernd_pzs.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_pzs.diminfo[0].shape = __pyx_pybuffernd_pzs.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_pvals.rcbuffer->pybuffer, (PyObject*)__pyx_v_pvals, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 2, 0, __pyx_stack) == -1)) __PYX_ERR(0, 201, __pyx_L1_error)
  }
  __pyx_pybuffernd_pvals.diminfo[0].strides = __pyx_pybuffernd_pvals.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_pvals.diminfo[0].shape = __pyx_pybuffernd_pvals.rcbuffer->pybuffer.shape[0]; __pyx_pybuffernd_pvals.diminfo[1].strides = __pyx_pybuffernd_pvals.rcbuffer->pybuffer.strides[1]; __pyx_pybuffernd_pvals.diminfo[1].shape = __pyx_pybuffernd_pvals.rcbuffer->pybuffer.shape[1];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_pweight_vals.rcbuffer->pybuffer, (PyObject*)__pyx_v_pweight_vals, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 201, __pyx_L1_error)
  }
  __pyx_pybuffernd_pweight_vals.diminfo[0].strides = __pyx_pybuffernd_pweight_vals.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_pweight_vals.diminfo[0].shape = __pyx_pybuffernd_pweight_vals.rcbuffer->pybuffer.shape[0];

  /* "yt/utilities/lib/basic_octree.pyx":208
 *             np.ndarray[np.float64_t, ndim=1] pweight_vals,
 *             int treecode = 0):
 *         cdef int np = pxs.shape[0]             # <<<<<<<<<<<<<<
 *         cdef int p
 *         cdef cnp.float64_t *vals
 */
  __pyx_v_np = (__pyx_v_pxs->dimensions[0]);

  /* "yt/utilities/lib/basic_octree.pyx":211
 *         cdef int p
 *         cdef cnp.float64_t *vals
 *         cdef cnp.float64_t *data = <cnp.float64_t *> pvals.data             # <<<<<<<<<<<<<<
 *         cdef cnp.int64_t pos[3]
 *         for p in range(np):
 */
  __pyx_v_data = ((__pyx_t_5numpy_float64_t *)__pyx_v_pvals->data);

  /* "yt/utilities/lib/basic_octree.pyx":213
 *         cdef cnp.float64_t *data = <cnp.float64_t *> pvals.data
 *         cdef cnp.int64_t pos[3]
 *         for p in range(np):             # <<<<<<<<<<<<<<
 *             vals = data + self.nvals*p
 *             pos[0] = pxs[p]
 */
  __pyx_t_1 = __pyx_v_np;
  for (__pyx_t_2 = 0; __pyx_t_2 < __pyx_t_1; __pyx_t_2+=1) {
    __pyx_v_p = __pyx_t_2;

    /* "yt/utilities/lib/basic_octree.pyx":214
 *         cdef cnp.int64_t pos[3]
 *         for p in range(np):
 *             vals = data + self.nvals*p             # <<<<<<<<<<<<<<
 *             pos[0] = pxs[p]
 *             pos[1] = pys[p]
 */
    __pyx_v_vals = (__pyx_v_data + (__pyx_v_self->nvals * __pyx_v_p));

    /* "yt/utilities/lib/basic_octree.pyx":215
 *         for p in range(np):
 *             vals = data + self.nvals*p
 *             pos[0] = pxs[p]             # <<<<<<<<<<<<<<
 *             pos[1] = pys[p]
 *             pos[2] = pzs[p]
 */
    __pyx_t_3 = __pyx_v_p;
    (__pyx_v_pos[0]) = (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_int64_t *, __pyx_pybuffernd_pxs.rcbuffer->pybuffer.buf, __pyx_t_3, __pyx_pybuffernd_pxs.diminfo[0].strides));

    /* "yt/utilities/lib/basic_octree.pyx":216
 *             vals = data + self.nvals*p
 *             pos[0] = pxs[p]
 *             pos[1] = pys[p]             # <<<<<<<<<<<<<<
 *             pos[2] = pzs[p]
 *             self.add_to_position(level, pos, vals, pweight_vals[p], treecode)
 */
    __pyx_t_4 = __pyx_v_p;
    (__pyx_v_pos[1]) = (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_int64_t *, __pyx_pybuffernd_pys.rcbuffer->pybuffer.buf, __pyx_t_4, __pyx_pybuffernd_pys.diminfo[0].strides));

    /* "yt/utilities/lib/basic_octree.pyx":217
 *             pos[0] = pxs[p]
 *             pos[1] = pys[p]
 *             pos[2] = pzs[p]             # <<<<<<<<<<<<<<
 *             self.add_to_position(level, pos, vals, pweight_vals[p], treecode)
 * 
 */
    __pyx_t_5 = __pyx_v_p;
    (__pyx_v_pos[2]) = (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_int64_t *, __pyx_pybuffernd_pzs.rcbuffer->pybuffer.buf, __pyx_t_5, __pyx_pybuffernd_pzs.diminfo[0].strides));

    /* "yt/utilities/lib/basic_octree.pyx":218
 *             pos[1] = pys[p]
 *             pos[2] = pzs[p]
 *             self.add_to_position(level, pos, vals, pweight_vals[p], treecode)             # <<<<<<<<<<<<<<
 * 
 *     def add_grid_to_tree(self, int level,
 */
    __pyx_t_6 = __pyx_v_p;
    __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_treecode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    ((struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self->__pyx_vtab)->add_to_position(__pyx_v_self, __pyx_v_level, __pyx_v_pos, __pyx_v_vals, (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_float64_t *, __pyx_pybuffernd_pweight_vals.rcbuffer->pybuffer.buf, __pyx_t_6, __pyx_pybuffernd_pweight_vals.diminfo[0].strides)), __pyx_t_7);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }

  /* "yt/utilities/lib/basic_octree.pyx":201
 *     @cython.boundscheck(False)
 *     @cython.wraparound(False)
 *     def add_array_to_tree(self, int level,             # <<<<<<<<<<<<<<
 *             np.ndarray[np.int64_t, ndim=1] pxs,
 *             np.ndarray[np.int64_t, ndim=1] pys,
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_7);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pvals.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pweight_vals.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pxs.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pys.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pzs.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("yt.utilities.lib.basic_octree.Octree.add_array_to_tree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pvals.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pweight_vals.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pxs.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pys.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pzs.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yt/utilities/lib/basic_octree.pyx":220
 *             self.add_to_position(level, pos, vals, pweight_vals[p], treecode)
 * 
 *     def add_grid_to_tree(self, int level,             # <<<<<<<<<<<<<<
 *                          np.ndarray[np.int64_t, ndim=1] start_index,
 *                          np.ndarray[np.float64_t, ndim=2] pvals,
 */

/* Python wrapper */
static PyObject *__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_5add_grid_to_tree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_5add_grid_to_tree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED int __pyx_v_level;
  CYTHON_UNUSED PyArrayObject *__pyx_v_start_index = 0;
  CYTHON_UNUSED PyArrayObject *__pyx_v_pvals = 0;
  CYTHON_UNUSED PyArrayObject *__pyx_v_wvals = 0;
  CYTHON_UNUSED PyArrayObject *__pyx_v_cm = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add_grid_to_tree (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_level,&__pyx_n_s_start_index,&__pyx_n_s_pvals,&__pyx_n_s_wvals,&__pyx_n_s_cm,0};
    PyObject* values[5] = {0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_level)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_start_index)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("add_grid_to_tree", 1, 5, 5, 1); __PYX_ERR(0, 220, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_pvals)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("add_grid_to_tree", 1, 5, 5, 2); __PYX_ERR(0, 220, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_wvals)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("add_grid_to_tree", 1, 5, 5, 3); __PYX_ERR(0, 220, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_cm)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("add_grid_to_tree", 1, 5, 5, 4); __PYX_ERR(0, 220, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "add_grid_to_tree") < 0)) __PYX_ERR(0, 220, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 5) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
    }
    __pyx_v_level = __Pyx_PyInt_As_int(values[0]); if (unlikely((__pyx_v_level == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 220, __pyx_L3_error)
    __pyx_v_start_index = ((PyArrayObject *)values[1]);
    __pyx_v_pvals = ((PyArrayObject *)values[2]);
    __pyx_v_wvals = ((PyArrayObject *)values[3]);
    __pyx_v_cm = ((PyArrayObject *)values[4]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("add_grid_to_tree", 1, 5, 5, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 220, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("yt.utilities.lib.basic_octree.Octree.add_grid_to_tree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_start_index), __pyx_ptype_5numpy_ndarray, 1, "start_index", 0))) __PYX_ERR(0, 221, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_pvals), __pyx_ptype_5numpy_ndarray, 1, "pvals", 0))) __PYX_ERR(0, 222, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_wvals), __pyx_ptype_5numpy_ndarray, 1, "wvals", 0))) __PYX_ERR(0, 223, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_cm), __pyx_ptype_5numpy_ndarray, 1, "cm", 0))) __PYX_ERR(0, 224, __pyx_L1_error)
  __pyx_r = __pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_4add_grid_to_tree(((struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self), __pyx_v_level, __pyx_v_start_index, __pyx_v_pvals, __pyx_v_wvals, __pyx_v_cm);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_4add_grid_to_tree(CYTHON_UNUSED struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, CYTHON_UNUSED int __pyx_v_level, CYTHON_UNUSED PyArrayObject *__pyx_v_start_index, CYTHON_UNUSED PyArrayObject *__pyx_v_pvals, CYTHON_UNUSED PyArrayObject *__pyx_v_wvals, CYTHON_UNUSED PyArrayObject *__pyx_v_cm) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_cm;
  __Pyx_Buffer __pyx_pybuffer_cm;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_pvals;
  __Pyx_Buffer __pyx_pybuffer_pvals;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_start_index;
  __Pyx_Buffer __pyx_pybuffer_start_index;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_wvals;
  __Pyx_Buffer __pyx_pybuffer_wvals;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add_grid_to_tree", 0);
  __pyx_pybuffer_start_index.pybuffer.buf = NULL;
  __pyx_pybuffer_start_index.refcount = 0;
  __pyx_pybuffernd_start_index.data = NULL;
  __pyx_pybuffernd_start_index.rcbuffer = &__pyx_pybuffer_start_index;
  __pyx_pybuffer_pvals.pybuffer.buf = NULL;
  __pyx_pybuffer_pvals.refcount = 0;
  __pyx_pybuffernd_pvals.data = NULL;
  __pyx_pybuffernd_pvals.rcbuffer = &__pyx_pybuffer_pvals;
  __pyx_pybuffer_wvals.pybuffer.buf = NULL;
  __pyx_pybuffer_wvals.refcount = 0;
  __pyx_pybuffernd_wvals.data = NULL;
  __pyx_pybuffernd_wvals.rcbuffer = &__pyx_pybuffer_wvals;
  __pyx_pybuffer_cm.pybuffer.buf = NULL;
  __pyx_pybuffer_cm.refcount = 0;
  __pyx_pybuffernd_cm.data = NULL;
  __pyx_pybuffernd_cm.rcbuffer = &__pyx_pybuffer_cm;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_start_index.rcbuffer->pybuffer, (PyObject*)__pyx_v_start_index, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 220, __pyx_L1_error)
  }
  __pyx_pybuffernd_start_index.diminfo[0].strides = __pyx_pybuffernd_start_index.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_start_index.diminfo[0].shape = __pyx_pybuffernd_start_index.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_pvals.rcbuffer->pybuffer, (PyObject*)__pyx_v_pvals, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 2, 0, __pyx_stack) == -1)) __PYX_ERR(0, 220, __pyx_L1_error)
  }
  __pyx_pybuffernd_pvals.diminfo[0].strides = __pyx_pybuffernd_pvals.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_pvals.diminfo[0].shape = __pyx_pybuffernd_pvals.rcbuffer->pybuffer.shape[0]; __pyx_pybuffernd_pvals.diminfo[1].strides = __pyx_pybuffernd_pvals.rcbuffer->pybuffer.strides[1]; __pyx_pybuffernd_pvals.diminfo[1].shape = __pyx_pybuffernd_pvals.rcbuffer->pybuffer.shape[1];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_wvals.rcbuffer->pybuffer, (PyObject*)__pyx_v_wvals, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 2, 0, __pyx_stack) == -1)) __PYX_ERR(0, 220, __pyx_L1_error)
  }
  __pyx_pybuffernd_wvals.diminfo[0].strides = __pyx_pybuffernd_wvals.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_wvals.diminfo[0].shape = __pyx_pybuffernd_wvals.rcbuffer->pybuffer.shape[0]; __pyx_pybuffernd_wvals.diminfo[1].strides = __pyx_pybuffernd_wvals.rcbuffer->pybuffer.strides[1]; __pyx_pybuffernd_wvals.diminfo[1].shape = __pyx_pybuffernd_wvals.rcbuffer->pybuffer.shape[1];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_cm.rcbuffer->pybuffer, (PyObject*)__pyx_v_cm, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_STRIDES, 2, 0, __pyx_stack) == -1)) __PYX_ERR(0, 220, __pyx_L1_error)
  }
  __pyx_pybuffernd_cm.diminfo[0].strides = __pyx_pybuffernd_cm.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_cm.diminfo[0].shape = __pyx_pybuffernd_cm.rcbuffer->pybuffer.shape[0]; __pyx_pybuffernd_cm.diminfo[1].strides = __pyx_pybuffernd_cm.rcbuffer->pybuffer.strides[1]; __pyx_pybuffernd_cm.diminfo[1].shape = __pyx_pybuffernd_cm.rcbuffer->pybuffer.shape[1];

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_cm.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pvals.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_start_index.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_wvals.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("yt.utilities.lib.basic_octree.Octree.add_grid_to_tree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_cm.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pvals.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_start_index.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_wvals.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yt/utilities/lib/basic_octree.pyx":229
 *     @cython.boundscheck(False)
 *     @cython.wraparound(False)
 *     def get_all_from_level(self, int level, int count_only = 0):             # <<<<<<<<<<<<<<
 *         cdef int i, j, k
 *         cdef int total = 0
 */

/* Python wrapper */
static PyObject *__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_7get_all_from_level(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_7get_all_from_level(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_v_level;
  int __pyx_v_count_only;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_all_from_level (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_level,&__pyx_n_s_count_only,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_level)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_count_only);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_all_from_level") < 0)) __PYX_ERR(0, 229, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_level = __Pyx_PyInt_As_int(values[0]); if (unlikely((__pyx_v_level == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 229, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_count_only = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_count_only == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 229, __pyx_L3_error)
    } else {
      __pyx_v_count_only = ((int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_all_from_level", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 229, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("yt.utilities.lib.basic_octree.Octree.get_all_from_level", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_6get_all_from_level(((struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self), __pyx_v_level, __pyx_v_count_only);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_6get_all_from_level(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, int __pyx_v_level, int __pyx_v_count_only) {
  int __pyx_v_i;
  int __pyx_v_j;
  int __pyx_v_k;
  int __pyx_v_total;
  PyArrayObject *__pyx_v_npos = 0;
  PyArrayObject *__pyx_v_nvals = 0;
  PyArrayObject *__pyx_v_nwvals = 0;
  __pyx_t_5numpy_int64_t __pyx_v_curpos;
  __pyx_t_5numpy_int64_t *__pyx_v_pdata;
  __pyx_t_5numpy_float64_t *__pyx_v_vdata;
  __pyx_t_5numpy_float64_t *__pyx_v_wdata;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_npos;
  __Pyx_Buffer __pyx_pybuffer_npos;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_nvals;
  __Pyx_Buffer __pyx_pybuffer_nvals;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_nwvals;
  __Pyx_Buffer __pyx_pybuffer_nwvals;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __pyx_t_5numpy_int64_t __pyx_t_1;
  int __pyx_t_2;
  __pyx_t_5numpy_int64_t __pyx_t_3;
  int __pyx_t_4;
  __pyx_t_5numpy_int64_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyArrayObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyArrayObject *__pyx_t_16 = NULL;
  PyArrayObject *__pyx_t_17 = NULL;
  __Pyx_RefNannySetupContext("get_all_from_level", 0);
  __pyx_pybuffer_npos.pybuffer.buf = NULL;
  __pyx_pybuffer_npos.refcount = 0;
  __pyx_pybuffernd_npos.data = NULL;
  __pyx_pybuffernd_npos.rcbuffer = &__pyx_pybuffer_npos;
  __pyx_pybuffer_nvals.pybuffer.buf = NULL;
  __pyx_pybuffer_nvals.refcount = 0;
  __pyx_pybuffernd_nvals.data = NULL;
  __pyx_pybuffernd_nvals.rcbuffer = &__pyx_pybuffer_nvals;
  __pyx_pybuffer_nwvals.pybuffer.buf = NULL;
  __pyx_pybuffer_nwvals.refcount = 0;
  __pyx_pybuffernd_nwvals.data = NULL;
  __pyx_pybuffernd_nwvals.rcbuffer = &__pyx_pybuffer_nwvals;

  /* "yt/utilities/lib/basic_octree.pyx":231
 *     def get_all_from_level(self, int level, int count_only = 0):
 *         cdef int i, j, k
 *         cdef int total = 0             # <<<<<<<<<<<<<<
 *         for i in range(self.top_grid_dims[0]):
 *             for j in range(self.top_grid_dims[1]):
 */
  __pyx_v_total = 0;

  /* "yt/utilities/lib/basic_octree.pyx":232
 *         cdef int i, j, k
 *         cdef int total = 0
 *         for i in range(self.top_grid_dims[0]):             # <<<<<<<<<<<<<<
 *             for j in range(self.top_grid_dims[1]):
 *                 for k in range(self.top_grid_dims[2]):
 */
  __pyx_t_1 = (__pyx_v_self->top_grid_dims[0]);
  for (__pyx_t_2 = 0; __pyx_t_2 < __pyx_t_1; __pyx_t_2+=1) {
    __pyx_v_i = __pyx_t_2;

    /* "yt/utilities/lib/basic_octree.pyx":233
 *         cdef int total = 0
 *         for i in range(self.top_grid_dims[0]):
 *             for j in range(self.top_grid_dims[1]):             # <<<<<<<<<<<<<<
 *                 for k in range(self.top_grid_dims[2]):
 *                     total += self.count_at_level(self.root_nodes[i][j][k], level)
 */
    __pyx_t_3 = (__pyx_v_self->top_grid_dims[1]);
    for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_j = __pyx_t_4;

      /* "yt/utilities/lib/basic_octree.pyx":234
 *         for i in range(self.top_grid_dims[0]):
 *             for j in range(self.top_grid_dims[1]):
 *                 for k in range(self.top_grid_dims[2]):             # <<<<<<<<<<<<<<
 *                     total += self.count_at_level(self.root_nodes[i][j][k], level)
 *         if count_only: return total
 */
      __pyx_t_5 = (__pyx_v_self->top_grid_dims[2]);
      for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
        __pyx_v_k = __pyx_t_6;

        /* "yt/utilities/lib/basic_octree.pyx":235
 *             for j in range(self.top_grid_dims[1]):
 *                 for k in range(self.top_grid_dims[2]):
 *                     total += self.count_at_level(self.root_nodes[i][j][k], level)             # <<<<<<<<<<<<<<
 *         if count_only: return total
 *         # Allocate our array
 */
        __pyx_v_total = (__pyx_v_total + ((struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self->__pyx_vtab)->count_at_level(__pyx_v_self, (((__pyx_v_self->root_nodes[__pyx_v_i])[__pyx_v_j])[__pyx_v_k]), __pyx_v_level));
      }
    }
  }

  /* "yt/utilities/lib/basic_octree.pyx":236
 *                 for k in range(self.top_grid_dims[2]):
 *                     total += self.count_at_level(self.root_nodes[i][j][k], level)
 *         if count_only: return total             # <<<<<<<<<<<<<<
 *         # Allocate our array
 *         cdef np.ndarray[np.int64_t, ndim=2] npos
 */
  __pyx_t_7 = (__pyx_v_count_only != 0);
  if (__pyx_t_7) {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_total); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 236, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_r = __pyx_t_8;
    __pyx_t_8 = 0;
    goto __pyx_L0;
  }

  /* "yt/utilities/lib/basic_octree.pyx":241
 *         cdef np.ndarray[np.float64_t, ndim=2] nvals
 *         cdef np.ndarray[np.float64_t, ndim=1] nwvals
 *         npos = np.zeros( (total, 3), dtype='int64')             # <<<<<<<<<<<<<<
 *         nvals = np.zeros( (total, self.nvals), dtype='float64')
 *         nwvals = np.zeros( total, dtype='float64')
 */
  __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_zeros); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_total); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_8);
  PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8);
  __Pyx_INCREF(__pyx_int_3);
  __Pyx_GIVEREF(__pyx_int_3);
  PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_int_3);
  __pyx_t_8 = 0;
  __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_10);
  PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_10);
  __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_dtype, __pyx_n_s_int64) < 0) __PYX_ERR(0, 241, __pyx_L1_error)
  __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_8, __pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (!(likely(((__pyx_t_11) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_11, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 241, __pyx_L1_error)
  __pyx_t_12 = ((PyArrayObject *)__pyx_t_11);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_npos.rcbuffer->pybuffer);
    __pyx_t_2 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_npos.rcbuffer->pybuffer, (PyObject*)__pyx_t_12, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_STRIDES, 2, 0, __pyx_stack);
    if (unlikely(__pyx_t_2 < 0)) {
      PyErr_Fetch(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_npos.rcbuffer->pybuffer, (PyObject*)__pyx_v_npos, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_STRIDES, 2, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_13); Py_XDECREF(__pyx_t_14); Py_XDECREF(__pyx_t_15);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_13, __pyx_t_14, __pyx_t_15);
      }
      __pyx_t_13 = __pyx_t_14 = __pyx_t_15 = 0;
    }
    __pyx_pybuffernd_npos.diminfo[0].strides = __pyx_pybuffernd_npos.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_npos.diminfo[0].shape = __pyx_pybuffernd_npos.rcbuffer->pybuffer.shape[0]; __pyx_pybuffernd_npos.diminfo[1].strides = __pyx_pybuffernd_npos.rcbuffer->pybuffer.strides[1]; __pyx_pybuffernd_npos.diminfo[1].shape = __pyx_pybuffernd_npos.rcbuffer->pybuffer.shape[1];
    if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 241, __pyx_L1_error)
  }
  __pyx_t_12 = 0;
  __pyx_v_npos = ((PyArrayObject *)__pyx_t_11);
  __pyx_t_11 = 0;

  /* "yt/utilities/lib/basic_octree.pyx":242
 *         cdef np.ndarray[np.float64_t, ndim=1] nwvals
 *         npos = np.zeros( (total, 3), dtype='int64')
 *         nvals = np.zeros( (total, self.nvals), dtype='float64')             # <<<<<<<<<<<<<<
 *         nwvals = np.zeros( total, dtype='float64')
 *         cdef np.int64_t curpos = 0
 */
  __pyx_t_11 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_zeros); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyInt_From_int(__pyx_v_total); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_self->nvals); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_11);
  PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_11);
  __Pyx_GIVEREF(__pyx_t_8);
  PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_8);
  __pyx_t_11 = 0;
  __pyx_t_8 = 0;
  __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_9);
  PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_9);
  __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_dtype, __pyx_n_s_float64) < 0) __PYX_ERR(0, 242, __pyx_L1_error)
  __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (!(likely(((__pyx_t_11) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_11, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 242, __pyx_L1_error)
  __pyx_t_16 = ((PyArrayObject *)__pyx_t_11);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_nvals.rcbuffer->pybuffer);
    __pyx_t_2 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_nvals.rcbuffer->pybuffer, (PyObject*)__pyx_t_16, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 2, 0, __pyx_stack);
    if (unlikely(__pyx_t_2 < 0)) {
      PyErr_Fetch(&__pyx_t_15, &__pyx_t_14, &__pyx_t_13);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_nvals.rcbuffer->pybuffer, (PyObject*)__pyx_v_nvals, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 2, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_15); Py_XDECREF(__pyx_t_14); Py_XDECREF(__pyx_t_13);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_15, __pyx_t_14, __pyx_t_13);
      }
      __pyx_t_15 = __pyx_t_14 = __pyx_t_13 = 0;
    }
    __pyx_pybuffernd_nvals.diminfo[0].strides = __pyx_pybuffernd_nvals.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_nvals.diminfo[0].shape = __pyx_pybuffernd_nvals.rcbuffer->pybuffer.shape[0]; __pyx_pybuffernd_nvals.diminfo[1].strides = __pyx_pybuffernd_nvals.rcbuffer->pybuffer.strides[1]; __pyx_pybuffernd_nvals.diminfo[1].shape = __pyx_pybuffernd_nvals.rcbuffer->pybuffer.shape[1];
    if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 242, __pyx_L1_error)
  }
  __pyx_t_16 = 0;
  __pyx_v_nvals = ((PyArrayObject *)__pyx_t_11);
  __pyx_t_11 = 0;

  /* "yt/utilities/lib/basic_octree.pyx":243
 *         npos = np.zeros( (total, 3), dtype='int64')
 *         nvals = np.zeros( (total, self.nvals), dtype='float64')
 *         nwvals = np.zeros( total, dtype='float64')             # <<<<<<<<<<<<<<
 *         cdef np.int64_t curpos = 0
 *         cdef np.int64_t *pdata = <np.int64_t *> npos.data
 */
  __pyx_t_11 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_zeros); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyInt_From_int(__pyx_v_total); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_11);
  PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_11);
  __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_dtype, __pyx_n_s_float64) < 0) __PYX_ERR(0, 243, __pyx_L1_error)
  __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_8, __pyx_t_11); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (!(likely(((__pyx_t_10) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_10, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 243, __pyx_L1_error)
  __pyx_t_17 = ((PyArrayObject *)__pyx_t_10);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_nwvals.rcbuffer->pybuffer);
    __pyx_t_2 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_nwvals.rcbuffer->pybuffer, (PyObject*)__pyx_t_17, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_2 < 0)) {
      PyErr_Fetch(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_nwvals.rcbuffer->pybuffer, (PyObject*)__pyx_v_nwvals, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_13); Py_XDECREF(__pyx_t_14); Py_XDECREF(__pyx_t_15);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_13, __pyx_t_14, __pyx_t_15);
      }
      __pyx_t_13 = __pyx_t_14 = __pyx_t_15 = 0;
    }
    __pyx_pybuffernd_nwvals.diminfo[0].strides = __pyx_pybuffernd_nwvals.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_nwvals.diminfo[0].shape = __pyx_pybuffernd_nwvals.rcbuffer->pybuffer.shape[0];
    if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 243, __pyx_L1_error)
  }
  __pyx_t_17 = 0;
  __pyx_v_nwvals = ((PyArrayObject *)__pyx_t_10);
  __pyx_t_10 = 0;

  /* "yt/utilities/lib/basic_octree.pyx":244
 *         nvals = np.zeros( (total, self.nvals), dtype='float64')
 *         nwvals = np.zeros( total, dtype='float64')
 *         cdef np.int64_t curpos = 0             # <<<<<<<<<<<<<<
 *         cdef np.int64_t *pdata = <np.int64_t *> npos.data
 *         cdef np.float64_t *vdata = <np.float64_t *> nvals.data
 */
  __pyx_v_curpos = 0;

  /* "yt/utilities/lib/basic_octree.pyx":245
 *         nwvals = np.zeros( total, dtype='float64')
 *         cdef np.int64_t curpos = 0
 *         cdef np.int64_t *pdata = <np.int64_t *> npos.data             # <<<<<<<<<<<<<<
 *         cdef np.float64_t *vdata = <np.float64_t *> nvals.data
 *         cdef np.float64_t *wdata = <np.float64_t *> nwvals.data
 */
  __pyx_v_pdata = ((__pyx_t_5numpy_int64_t *)__pyx_v_npos->data);

  /* "yt/utilities/lib/basic_octree.pyx":246
 *         cdef np.int64_t curpos = 0
 *         cdef np.int64_t *pdata = <np.int64_t *> npos.data
 *         cdef np.float64_t *vdata = <np.float64_t *> nvals.data             # <<<<<<<<<<<<<<
 *         cdef np.float64_t *wdata = <np.float64_t *> nwvals.data
 *         for i in range(self.top_grid_dims[0]):
 */
  __pyx_v_vdata = ((__pyx_t_5numpy_float64_t *)__pyx_v_nvals->data);

  /* "yt/utilities/lib/basic_octree.pyx":247
 *         cdef np.int64_t *pdata = <np.int64_t *> npos.data
 *         cdef np.float64_t *vdata = <np.float64_t *> nvals.data
 *         cdef np.float64_t *wdata = <np.float64_t *> nwvals.data             # <<<<<<<<<<<<<<
 *         for i in range(self.top_grid_dims[0]):
 *             for j in range(self.top_grid_dims[1]):
 */
  __pyx_v_wdata = ((__pyx_t_5numpy_float64_t *)__pyx_v_nwvals->data);

  /* "yt/utilities/lib/basic_octree.pyx":248
 *         cdef np.float64_t *vdata = <np.float64_t *> nvals.data
 *         cdef np.float64_t *wdata = <np.float64_t *> nwvals.data
 *         for i in range(self.top_grid_dims[0]):             # <<<<<<<<<<<<<<
 *             for j in range(self.top_grid_dims[1]):
 *                 for k in range(self.top_grid_dims[2]):
 */
  __pyx_t_1 = (__pyx_v_self->top_grid_dims[0]);
  for (__pyx_t_2 = 0; __pyx_t_2 < __pyx_t_1; __pyx_t_2+=1) {
    __pyx_v_i = __pyx_t_2;

    /* "yt/utilities/lib/basic_octree.pyx":249
 *         cdef np.float64_t *wdata = <np.float64_t *> nwvals.data
 *         for i in range(self.top_grid_dims[0]):
 *             for j in range(self.top_grid_dims[1]):             # <<<<<<<<<<<<<<
 *                 for k in range(self.top_grid_dims[2]):
 *                     curpos += self.fill_from_level(self.root_nodes[i][j][k],
 */
    __pyx_t_3 = (__pyx_v_self->top_grid_dims[1]);
    for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_j = __pyx_t_4;

      /* "yt/utilities/lib/basic_octree.pyx":250
 *         for i in range(self.top_grid_dims[0]):
 *             for j in range(self.top_grid_dims[1]):
 *                 for k in range(self.top_grid_dims[2]):             # <<<<<<<<<<<<<<
 *                     curpos += self.fill_from_level(self.root_nodes[i][j][k],
 *                         level, curpos, pdata, vdata, wdata)
 */
      __pyx_t_5 = (__pyx_v_self->top_grid_dims[2]);
      for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
        __pyx_v_k = __pyx_t_6;

        /* "yt/utilities/lib/basic_octree.pyx":251
 *             for j in range(self.top_grid_dims[1]):
 *                 for k in range(self.top_grid_dims[2]):
 *                     curpos += self.fill_from_level(self.root_nodes[i][j][k],             # <<<<<<<<<<<<<<
 *                         level, curpos, pdata, vdata, wdata)
 *         return npos, nvals, nwvals
 */
        __pyx_v_curpos = (__pyx_v_curpos + ((struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self->__pyx_vtab)->fill_from_level(__pyx_v_self, (((__pyx_v_self->root_nodes[__pyx_v_i])[__pyx_v_j])[__pyx_v_k]), __pyx_v_level, __pyx_v_curpos, __pyx_v_pdata, __pyx_v_vdata, __pyx_v_wdata));
      }
    }
  }

  /* "yt/utilities/lib/basic_octree.pyx":253
 *                     curpos += self.fill_from_level(self.root_nodes[i][j][k],
 *                         level, curpos, pdata, vdata, wdata)
 *         return npos, nvals, nwvals             # <<<<<<<<<<<<<<
 * 
 *     cdef int count_at_level(self, OctreeNode *node, int level):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_10 = PyTuple_New(3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_INCREF(((PyObject *)__pyx_v_npos));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_npos));
  PyTuple_SET_ITEM(__pyx_t_10, 0, ((PyObject *)__pyx_v_npos));
  __Pyx_INCREF(((PyObject *)__pyx_v_nvals));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_nvals));
  PyTuple_SET_ITEM(__pyx_t_10, 1, ((PyObject *)__pyx_v_nvals));
  __Pyx_INCREF(((PyObject *)__pyx_v_nwvals));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_nwvals));
  PyTuple_SET_ITEM(__pyx_t_10, 2, ((PyObject *)__pyx_v_nwvals));
  __pyx_r = __pyx_t_10;
  __pyx_t_10 = 0;
  goto __pyx_L0;

  /* "yt/utilities/lib/basic_octree.pyx":229
 *     @cython.boundscheck(False)
 *     @cython.wraparound(False)
 *     def get_all_from_level(self, int level, int count_only = 0):             # <<<<<<<<<<<<<<
 *         cdef int i, j, k
 *         cdef int total = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_npos.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_nvals.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_nwvals.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("yt.utilities.lib.basic_octree.Octree.get_all_from_level", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_npos.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_nvals.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_nwvals.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_npos);
  __Pyx_XDECREF((PyObject *)__pyx_v_nvals);
  __Pyx_XDECREF((PyObject *)__pyx_v_nwvals);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yt/utilities/lib/basic_octree.pyx":255
 *         return npos, nvals, nwvals
 * 
 *     cdef int count_at_level(self, OctreeNode *node, int level):             # <<<<<<<<<<<<<<
 *         cdef int i, j, k
 *         # We only really return a non-zero, calculated value if we are at the
 */

static int __pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_count_at_level(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node, int __pyx_v_level) {
  int __pyx_v_i;
  int __pyx_v_j;
  int __pyx_v_k;
  int __pyx_v_count;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  __Pyx_RefNannySetupContext("count_at_level", 0);

  /* "yt/utilities/lib/basic_octree.pyx":259
 *         # We only really return a non-zero, calculated value if we are at the
 *         # level in question.
 *         if node.level == level:             # <<<<<<<<<<<<<<
 *             if self.incremental: return 1
 *             # We return 1 if there are no finer points at this level and zero
 */
  __pyx_t_1 = ((__pyx_v_node->level == __pyx_v_level) != 0);
  if (__pyx_t_1) {

    /* "yt/utilities/lib/basic_octree.pyx":260
 *         # level in question.
 *         if node.level == level:
 *             if self.incremental: return 1             # <<<<<<<<<<<<<<
 *             # We return 1 if there are no finer points at this level and zero
 *             # if there are
 */
    __pyx_t_1 = (__pyx_v_self->incremental != 0);
    if (__pyx_t_1) {
      __pyx_r = 1;
      goto __pyx_L0;
    }

    /* "yt/utilities/lib/basic_octree.pyx":263
 *             # We return 1 if there are no finer points at this level and zero
 *             # if there are
 *             return (node.children[0][0][0] == NULL)             # <<<<<<<<<<<<<<
 *         if node.children[0][0][0] == NULL: return 0
 *         cdef int count = 0
 */
    __pyx_r = ((((__pyx_v_node->children[0])[0])[0]) == NULL);
    goto __pyx_L0;

    /* "yt/utilities/lib/basic_octree.pyx":259
 *         # We only really return a non-zero, calculated value if we are at the
 *         # level in question.
 *         if node.level == level:             # <<<<<<<<<<<<<<
 *             if self.incremental: return 1
 *             # We return 1 if there are no finer points at this level and zero
 */
  }

  /* "yt/utilities/lib/basic_octree.pyx":264
 *             # if there are
 *             return (node.children[0][0][0] == NULL)
 *         if node.children[0][0][0] == NULL: return 0             # <<<<<<<<<<<<<<
 *         cdef int count = 0
 *         for i in range(2):
 */
  __pyx_t_1 = (((((__pyx_v_node->children[0])[0])[0]) == NULL) != 0);
  if (__pyx_t_1) {
    __pyx_r = 0;
    goto __pyx_L0;
  }

  /* "yt/utilities/lib/basic_octree.pyx":265
 *             return (node.children[0][0][0] == NULL)
 *         if node.children[0][0][0] == NULL: return 0
 *         cdef int count = 0             # <<<<<<<<<<<<<<
 *         for i in range(2):
 *             for j in range(2):
 */
  __pyx_v_count = 0;

  /* "yt/utilities/lib/basic_octree.pyx":266
 *         if node.children[0][0][0] == NULL: return 0
 *         cdef int count = 0
 *         for i in range(2):             # <<<<<<<<<<<<<<
 *             for j in range(2):
 *                 for k in range(2):
 */
  for (__pyx_t_2 = 0; __pyx_t_2 < 2; __pyx_t_2+=1) {
    __pyx_v_i = __pyx_t_2;

    /* "yt/utilities/lib/basic_octree.pyx":267
 *         cdef int count = 0
 *         for i in range(2):
 *             for j in range(2):             # <<<<<<<<<<<<<<
 *                 for k in range(2):
 *                     count += self.count_at_level(node.children[i][j][k], level)
 */
    for (__pyx_t_3 = 0; __pyx_t_3 < 2; __pyx_t_3+=1) {
      __pyx_v_j = __pyx_t_3;

      /* "yt/utilities/lib/basic_octree.pyx":268
 *         for i in range(2):
 *             for j in range(2):
 *                 for k in range(2):             # <<<<<<<<<<<<<<
 *                     count += self.count_at_level(node.children[i][j][k], level)
 *         return count
 */
      for (__pyx_t_4 = 0; __pyx_t_4 < 2; __pyx_t_4+=1) {
        __pyx_v_k = __pyx_t_4;

        /* "yt/utilities/lib/basic_octree.pyx":269
 *             for j in range(2):
 *                 for k in range(2):
 *                     count += self.count_at_level(node.children[i][j][k], level)             # <<<<<<<<<<<<<<
 *         return count
 * 
 */
        __pyx_v_count = (__pyx_v_count + ((struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self->__pyx_vtab)->count_at_level(__pyx_v_self, (((__pyx_v_node->children[__pyx_v_i])[__pyx_v_j])[__pyx_v_k]), __pyx_v_level));
      }
    }
  }

  /* "yt/utilities/lib/basic_octree.pyx":270
 *                 for k in range(2):
 *                     count += self.count_at_level(node.children[i][j][k], level)
 *         return count             # <<<<<<<<<<<<<<
 * 
 *     cdef int fill_from_level(self, OctreeNode *node, int level,
 */
  __pyx_r = __pyx_v_count;
  goto __pyx_L0;

  /* "yt/utilities/lib/basic_octree.pyx":255
 *         return npos, nvals, nwvals
 * 
 *     cdef int count_at_level(self, OctreeNode *node, int level):             # <<<<<<<<<<<<<<
 *         cdef int i, j, k
 *         # We only really return a non-zero, calculated value if we are at the
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yt/utilities/lib/basic_octree.pyx":272
 *         return count
 * 
 *     cdef int fill_from_level(self, OctreeNode *node, int level,             # <<<<<<<<<<<<<<
 *                               np.int64_t curpos,
 *                               np.int64_t *pdata,
 */

static int __pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_fill_from_level(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node, int __pyx_v_level, __pyx_t_5numpy_int64_t __pyx_v_curpos, __pyx_t_5numpy_int64_t *__pyx_v_pdata, __pyx_t_5numpy_float64_t *__pyx_v_vdata, __pyx_t_5numpy_float64_t *__pyx_v_wdata) {
  int __pyx_v_i;
  int __pyx_v_j;
  int __pyx_v_k;
  __pyx_t_5numpy_int64_t __pyx_v_added;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  __pyx_t_5numpy_float64_t __pyx_t_5;
  int __pyx_t_6;
  __Pyx_RefNannySetupContext("fill_from_level", 0);

  /* "yt/utilities/lib/basic_octree.pyx":278
 *                               np.float64_t *wdata):
 *         cdef int i, j, k
 *         if node.level == level:             # <<<<<<<<<<<<<<
 *             if node.children[0][0][0] != NULL and not self.incremental:
 *                 return 0
 */
  __pyx_t_1 = ((__pyx_v_node->level == __pyx_v_level) != 0);
  if (__pyx_t_1) {

    /* "yt/utilities/lib/basic_octree.pyx":279
 *         cdef int i, j, k
 *         if node.level == level:
 *             if node.children[0][0][0] != NULL and not self.incremental:             # <<<<<<<<<<<<<<
 *                 return 0
 *             for i in range(self.nvals):
 */
    __pyx_t_2 = (((((__pyx_v_node->children[0])[0])[0]) != NULL) != 0);
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_2 = ((!(__pyx_v_self->incremental != 0)) != 0);
    __pyx_t_1 = __pyx_t_2;
    __pyx_L5_bool_binop_done:;
    if (__pyx_t_1) {

      /* "yt/utilities/lib/basic_octree.pyx":280
 *         if node.level == level:
 *             if node.children[0][0][0] != NULL and not self.incremental:
 *                 return 0             # <<<<<<<<<<<<<<
 *             for i in range(self.nvals):
 *                 vdata[self.nvals * curpos + i] = node.val[i]
 */
      __pyx_r = 0;
      goto __pyx_L0;

      /* "yt/utilities/lib/basic_octree.pyx":279
 *         cdef int i, j, k
 *         if node.level == level:
 *             if node.children[0][0][0] != NULL and not self.incremental:             # <<<<<<<<<<<<<<
 *                 return 0
 *             for i in range(self.nvals):
 */
    }

    /* "yt/utilities/lib/basic_octree.pyx":281
 *             if node.children[0][0][0] != NULL and not self.incremental:
 *                 return 0
 *             for i in range(self.nvals):             # <<<<<<<<<<<<<<
 *                 vdata[self.nvals * curpos + i] = node.val[i]
 *             wdata[curpos] = node.weight_val
 */
    __pyx_t_3 = __pyx_v_self->nvals;
    for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_i = __pyx_t_4;

      /* "yt/utilities/lib/basic_octree.pyx":282
 *                 return 0
 *             for i in range(self.nvals):
 *                 vdata[self.nvals * curpos + i] = node.val[i]             # <<<<<<<<<<<<<<
 *             wdata[curpos] = node.weight_val
 *             pdata[curpos * 3] = node.pos[0]
 */
      (__pyx_v_vdata[((__pyx_v_self->nvals * __pyx_v_curpos) + __pyx_v_i)]) = (__pyx_v_node->val[__pyx_v_i]);
    }

    /* "yt/utilities/lib/basic_octree.pyx":283
 *             for i in range(self.nvals):
 *                 vdata[self.nvals * curpos + i] = node.val[i]
 *             wdata[curpos] = node.weight_val             # <<<<<<<<<<<<<<
 *             pdata[curpos * 3] = node.pos[0]
 *             pdata[curpos * 3 + 1] = node.pos[1]
 */
    __pyx_t_5 = __pyx_v_node->weight_val;
    (__pyx_v_wdata[__pyx_v_curpos]) = __pyx_t_5;

    /* "yt/utilities/lib/basic_octree.pyx":284
 *                 vdata[self.nvals * curpos + i] = node.val[i]
 *             wdata[curpos] = node.weight_val
 *             pdata[curpos * 3] = node.pos[0]             # <<<<<<<<<<<<<<
 *             pdata[curpos * 3 + 1] = node.pos[1]
 *             pdata[curpos * 3 + 2] = node.pos[2]
 */
    (__pyx_v_pdata[(__pyx_v_curpos * 3)]) = (__pyx_v_node->pos[0]);

    /* "yt/utilities/lib/basic_octree.pyx":285
 *             wdata[curpos] = node.weight_val
 *             pdata[curpos * 3] = node.pos[0]
 *             pdata[curpos * 3 + 1] = node.pos[1]             # <<<<<<<<<<<<<<
 *             pdata[curpos * 3 + 2] = node.pos[2]
 *             return 1
 */
    (__pyx_v_pdata[((__pyx_v_curpos * 3) + 1)]) = (__pyx_v_node->pos[1]);

    /* "yt/utilities/lib/basic_octree.pyx":286
 *             pdata[curpos * 3] = node.pos[0]
 *             pdata[curpos * 3 + 1] = node.pos[1]
 *             pdata[curpos * 3 + 2] = node.pos[2]             # <<<<<<<<<<<<<<
 *             return 1
 *         if node.children[0][0][0] == NULL: return 0
 */
    (__pyx_v_pdata[((__pyx_v_curpos * 3) + 2)]) = (__pyx_v_node->pos[2]);

    /* "yt/utilities/lib/basic_octree.pyx":287
 *             pdata[curpos * 3 + 1] = node.pos[1]
 *             pdata[curpos * 3 + 2] = node.pos[2]
 *             return 1             # <<<<<<<<<<<<<<
 *         if node.children[0][0][0] == NULL: return 0
 *         cdef np.int64_t added = 0
 */
    __pyx_r = 1;
    goto __pyx_L0;

    /* "yt/utilities/lib/basic_octree.pyx":278
 *                               np.float64_t *wdata):
 *         cdef int i, j, k
 *         if node.level == level:             # <<<<<<<<<<<<<<
 *             if node.children[0][0][0] != NULL and not self.incremental:
 *                 return 0
 */
  }

  /* "yt/utilities/lib/basic_octree.pyx":288
 *             pdata[curpos * 3 + 2] = node.pos[2]
 *             return 1
 *         if node.children[0][0][0] == NULL: return 0             # <<<<<<<<<<<<<<
 *         cdef np.int64_t added = 0
 *         for i in range(2):
 */
  __pyx_t_1 = (((((__pyx_v_node->children[0])[0])[0]) == NULL) != 0);
  if (__pyx_t_1) {
    __pyx_r = 0;
    goto __pyx_L0;
  }

  /* "yt/utilities/lib/basic_octree.pyx":289
 *             return 1
 *         if node.children[0][0][0] == NULL: return 0
 *         cdef np.int64_t added = 0             # <<<<<<<<<<<<<<
 *         for i in range(2):
 *             for j in range(2):
 */
  __pyx_v_added = 0;

  /* "yt/utilities/lib/basic_octree.pyx":290
 *         if node.children[0][0][0] == NULL: return 0
 *         cdef np.int64_t added = 0
 *         for i in range(2):             # <<<<<<<<<<<<<<
 *             for j in range(2):
 *                 for k in range(2):
 */
  for (__pyx_t_3 = 0; __pyx_t_3 < 2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "yt/utilities/lib/basic_octree.pyx":291
 *         cdef np.int64_t added = 0
 *         for i in range(2):
 *             for j in range(2):             # <<<<<<<<<<<<<<
 *                 for k in range(2):
 *                     added += self.fill_from_level(node.children[i][j][k],
 */
    for (__pyx_t_4 = 0; __pyx_t_4 < 2; __pyx_t_4+=1) {
      __pyx_v_j = __pyx_t_4;

      /* "yt/utilities/lib/basic_octree.pyx":292
 *         for i in range(2):
 *             for j in range(2):
 *                 for k in range(2):             # <<<<<<<<<<<<<<
 *                     added += self.fill_from_level(node.children[i][j][k],
 *                             level, curpos + added, pdata, vdata, wdata)
 */
      for (__pyx_t_6 = 0; __pyx_t_6 < 2; __pyx_t_6+=1) {
        __pyx_v_k = __pyx_t_6;

        /* "yt/utilities/lib/basic_octree.pyx":293
 *             for j in range(2):
 *                 for k in range(2):
 *                     added += self.fill_from_level(node.children[i][j][k],             # <<<<<<<<<<<<<<
 *                             level, curpos + added, pdata, vdata, wdata)
 *         return added
 */
        __pyx_v_added = (__pyx_v_added + ((struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self->__pyx_vtab)->fill_from_level(__pyx_v_self, (((__pyx_v_node->children[__pyx_v_i])[__pyx_v_j])[__pyx_v_k]), __pyx_v_level, (__pyx_v_curpos + __pyx_v_added), __pyx_v_pdata, __pyx_v_vdata, __pyx_v_wdata));
      }
    }
  }

  /* "yt/utilities/lib/basic_octree.pyx":295
 *                     added += self.fill_from_level(node.children[i][j][k],
 *                             level, curpos + added, pdata, vdata, wdata)
 *         return added             # <<<<<<<<<<<<<<
 * 
 *     @cython.cdivision(True)
 */
  __pyx_r = __pyx_v_added;
  goto __pyx_L0;

  /* "yt/utilities/lib/basic_octree.pyx":272
 *         return count
 * 
 *     cdef int fill_from_level(self, OctreeNode *node, int level,             # <<<<<<<<<<<<<<
 *                               np.int64_t curpos,
 *                               np.int64_t *pdata,
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yt/utilities/lib/basic_octree.pyx":298
 * 
 *     @cython.cdivision(True)
 *     cdef np.float64_t fbe_node_separation(self, OctreeNode *node1, OctreeNode *node2):             # <<<<<<<<<<<<<<
 *         # Find the distance between the two nodes.
 *         cdef np.float64_t dx1, dx2, p1, p2, dist
 */

static __pyx_t_5numpy_float64_t __pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_fbe_node_separation(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node1, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node2) {
  __pyx_t_5numpy_float64_t __pyx_v_dx1;
  __pyx_t_5numpy_float64_t __pyx_v_dx2;
  __pyx_t_5numpy_float64_t __pyx_v_p1;
  __pyx_t_5numpy_float64_t __pyx_v_p2;
  __pyx_t_5numpy_float64_t __pyx_v_dist;
  int __pyx_v_i;
  __pyx_t_5numpy_float64_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("fbe_node_separation", 0);

  /* "yt/utilities/lib/basic_octree.pyx":302
 *         cdef np.float64_t dx1, dx2, p1, p2, dist
 *         cdef int i
 *         dist = 0.0             # <<<<<<<<<<<<<<
 *         for i in range(3):
 *             # Discover the appropriate dx for each node/dim.
 */
  __pyx_v_dist = 0.0;

  /* "yt/utilities/lib/basic_octree.pyx":303
 *         cdef int i
 *         dist = 0.0
 *         for i in range(3):             # <<<<<<<<<<<<<<
 *             # Discover the appropriate dx for each node/dim.
 *             dx1 = self.root_dx[i] / (<np.float64_t> self.po2[node1.level])
 */
  for (__pyx_t_1 = 0; __pyx_t_1 < 3; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "yt/utilities/lib/basic_octree.pyx":305
 *         for i in range(3):
 *             # Discover the appropriate dx for each node/dim.
 *             dx1 = self.root_dx[i] / (<np.float64_t> self.po2[node1.level])             # <<<<<<<<<<<<<<
 *             dx2 = self.root_dx[i] / (<np.float64_t> self.po2[node2.level])
 *             # The added term is to re-cell center the data.
 */
    __pyx_v_dx1 = ((__pyx_v_self->root_dx[__pyx_v_i]) / ((__pyx_t_5numpy_float64_t)(__pyx_v_self->po2[__pyx_v_node1->level])));

    /* "yt/utilities/lib/basic_octree.pyx":306
 *             # Discover the appropriate dx for each node/dim.
 *             dx1 = self.root_dx[i] / (<np.float64_t> self.po2[node1.level])
 *             dx2 = self.root_dx[i] / (<np.float64_t> self.po2[node2.level])             # <<<<<<<<<<<<<<
 *             # The added term is to re-cell center the data.
 *             p1 = (<np.float64_t> node1.pos[i]) * dx1 + dx1/2.
 */
    __pyx_v_dx2 = ((__pyx_v_self->root_dx[__pyx_v_i]) / ((__pyx_t_5numpy_float64_t)(__pyx_v_self->po2[__pyx_v_node2->level])));

    /* "yt/utilities/lib/basic_octree.pyx":308
 *             dx2 = self.root_dx[i] / (<np.float64_t> self.po2[node2.level])
 *             # The added term is to re-cell center the data.
 *             p1 = (<np.float64_t> node1.pos[i]) * dx1 + dx1/2.             # <<<<<<<<<<<<<<
 *             p2 = (<np.float64_t> node2.pos[i]) * dx2 + dx2/2.
 *             dist += (p1 - p2) * (p1 - p2)
 */
    __pyx_v_p1 = ((((__pyx_t_5numpy_float64_t)(__pyx_v_node1->pos[__pyx_v_i])) * __pyx_v_dx1) + (__pyx_v_dx1 / 2.));

    /* "yt/utilities/lib/basic_octree.pyx":309
 *             # The added term is to re-cell center the data.
 *             p1 = (<np.float64_t> node1.pos[i]) * dx1 + dx1/2.
 *             p2 = (<np.float64_t> node2.pos[i]) * dx2 + dx2/2.             # <<<<<<<<<<<<<<
 *             dist += (p1 - p2) * (p1 - p2)
 *         dist = sqrt(dist)
 */
    __pyx_v_p2 = ((((__pyx_t_5numpy_float64_t)(__pyx_v_node2->pos[__pyx_v_i])) * __pyx_v_dx2) + (__pyx_v_dx2 / 2.));

    /* "yt/utilities/lib/basic_octree.pyx":310
 *             p1 = (<np.float64_t> node1.pos[i]) * dx1 + dx1/2.
 *             p2 = (<np.float64_t> node2.pos[i]) * dx2 + dx2/2.
 *             dist += (p1 - p2) * (p1 - p2)             # <<<<<<<<<<<<<<
 *         dist = sqrt(dist)
 *         return dist
 */
    __pyx_v_dist = (__pyx_v_dist + ((__pyx_v_p1 - __pyx_v_p2) * (__pyx_v_p1 - __pyx_v_p2)));
  }

  /* "yt/utilities/lib/basic_octree.pyx":311
 *             p2 = (<np.float64_t> node2.pos[i]) * dx2 + dx2/2.
 *             dist += (p1 - p2) * (p1 - p2)
 *         dist = sqrt(dist)             # <<<<<<<<<<<<<<
 *         return dist
 * 
 */
  __pyx_v_dist = sqrt(__pyx_v_dist);

  /* "yt/utilities/lib/basic_octree.pyx":312
 *             dist += (p1 - p2) * (p1 - p2)
 *         dist = sqrt(dist)
 *         return dist             # <<<<<<<<<<<<<<
 * 
 *     @cython.cdivision(True)
 */
  __pyx_r = __pyx_v_dist;
  goto __pyx_L0;

  /* "yt/utilities/lib/basic_octree.pyx":298
 * 
 *     @cython.cdivision(True)
 *     cdef np.float64_t fbe_node_separation(self, OctreeNode *node1, OctreeNode *node2):             # <<<<<<<<<<<<<<
 *         # Find the distance between the two nodes.
 *         cdef np.float64_t dx1, dx2, p1, p2, dist
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yt/utilities/lib/basic_octree.pyx":315
 * 
 *     @cython.cdivision(True)
 *     cdef np.float64_t fbe_opening_angle(self, OctreeNode *node1,             # <<<<<<<<<<<<<<
 *             OctreeNode *node2):
 *         # Calculate the opening angle of node2 upon the center of node1.
 */

static __pyx_t_5numpy_float64_t __pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_fbe_opening_angle(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node1, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node2) {
  __pyx_t_5numpy_float64_t __pyx_v_d2;
  __pyx_t_5numpy_float64_t __pyx_v_dx2;
  __pyx_t_5numpy_float64_t __pyx_v_dist;
  __pyx_t_5numpy_int64_t __pyx_v_n2;
  int __pyx_v_i;
  __pyx_t_5numpy_float64_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  __Pyx_RefNannySetupContext("fbe_opening_angle", 0);

  /* "yt/utilities/lib/basic_octree.pyx":326
 *         cdef np.int64_t n2
 *         cdef int i
 *         d2 = 0.0             # <<<<<<<<<<<<<<
 *         if node1 is node2: return 100000.0 # Just some large number.
 *         if self.top_grid_dims[1] == self.top_grid_dims[0] and \
 */
  __pyx_v_d2 = 0.0;

  /* "yt/utilities/lib/basic_octree.pyx":327
 *         cdef int i
 *         d2 = 0.0
 *         if node1 is node2: return 100000.0 # Just some large number.             # <<<<<<<<<<<<<<
 *         if self.top_grid_dims[1] == self.top_grid_dims[0] and \
 *                 self.top_grid_dims[2] == self.top_grid_dims[0]:
 */
  __pyx_t_1 = ((__pyx_v_node1 == __pyx_v_node2) != 0);
  if (__pyx_t_1) {
    __pyx_r = 100000.0;
    goto __pyx_L0;
  }

  /* "yt/utilities/lib/basic_octree.pyx":328
 *         d2 = 0.0
 *         if node1 is node2: return 100000.0 # Just some large number.
 *         if self.top_grid_dims[1] == self.top_grid_dims[0] and \             # <<<<<<<<<<<<<<
 *                 self.top_grid_dims[2] == self.top_grid_dims[0]:
 *             # Symmetric
 */
  __pyx_t_2 = (((__pyx_v_self->top_grid_dims[1]) == (__pyx_v_self->top_grid_dims[0])) != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L5_bool_binop_done;
  }

  /* "yt/utilities/lib/basic_octree.pyx":329
 *         if node1 is node2: return 100000.0 # Just some large number.
 *         if self.top_grid_dims[1] == self.top_grid_dims[0] and \
 *                 self.top_grid_dims[2] == self.top_grid_dims[0]:             # <<<<<<<<<<<<<<
 *             # Symmetric
 *             n2 = self.po2[node2.level] * self.top_grid_dims[0]
 */
  __pyx_t_2 = (((__pyx_v_self->top_grid_dims[2]) == (__pyx_v_self->top_grid_dims[0])) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L5_bool_binop_done:;

  /* "yt/utilities/lib/basic_octree.pyx":328
 *         d2 = 0.0
 *         if node1 is node2: return 100000.0 # Just some large number.
 *         if self.top_grid_dims[1] == self.top_grid_dims[0] and \             # <<<<<<<<<<<<<<
 *                 self.top_grid_dims[2] == self.top_grid_dims[0]:
 *             # Symmetric
 */
  if (__pyx_t_1) {

    /* "yt/utilities/lib/basic_octree.pyx":331
 *                 self.top_grid_dims[2] == self.top_grid_dims[0]:
 *             # Symmetric
 *             n2 = self.po2[node2.level] * self.top_grid_dims[0]             # <<<<<<<<<<<<<<
 *             d2 = 1. / (<np.float64_t> n2)
 *         else:
 */
    __pyx_v_n2 = ((__pyx_v_self->po2[__pyx_v_node2->level]) * (__pyx_v_self->top_grid_dims[0]));

    /* "yt/utilities/lib/basic_octree.pyx":332
 *             # Symmetric
 *             n2 = self.po2[node2.level] * self.top_grid_dims[0]
 *             d2 = 1. / (<np.float64_t> n2)             # <<<<<<<<<<<<<<
 *         else:
 *             # Not symmetric
 */
    __pyx_v_d2 = (1. / ((__pyx_t_5numpy_float64_t)__pyx_v_n2));

    /* "yt/utilities/lib/basic_octree.pyx":328
 *         d2 = 0.0
 *         if node1 is node2: return 100000.0 # Just some large number.
 *         if self.top_grid_dims[1] == self.top_grid_dims[0] and \             # <<<<<<<<<<<<<<
 *                 self.top_grid_dims[2] == self.top_grid_dims[0]:
 *             # Symmetric
 */
    goto __pyx_L4;
  }

  /* "yt/utilities/lib/basic_octree.pyx":335
 *         else:
 *             # Not symmetric
 *             for i in range(3):             # <<<<<<<<<<<<<<
 *                 n2 = self.po2[node2.level] * self.top_grid_dims[i]
 *                 dx2 = 1. / (<np.float64_t> n2)
 */
  /*else*/ {
    for (__pyx_t_3 = 0; __pyx_t_3 < 3; __pyx_t_3+=1) {
      __pyx_v_i = __pyx_t_3;

      /* "yt/utilities/lib/basic_octree.pyx":336
 *             # Not symmetric
 *             for i in range(3):
 *                 n2 = self.po2[node2.level] * self.top_grid_dims[i]             # <<<<<<<<<<<<<<
 *                 dx2 = 1. / (<np.float64_t> n2)
 *                 d2 = f64max(d2, dx2)
 */
      __pyx_v_n2 = ((__pyx_v_self->po2[__pyx_v_node2->level]) * (__pyx_v_self->top_grid_dims[__pyx_v_i]));

      /* "yt/utilities/lib/basic_octree.pyx":337
 *             for i in range(3):
 *                 n2 = self.po2[node2.level] * self.top_grid_dims[i]
 *                 dx2 = 1. / (<np.float64_t> n2)             # <<<<<<<<<<<<<<
 *                 d2 = f64max(d2, dx2)
 *         # Now calculate the opening angle.
 */
      __pyx_v_dx2 = (1. / ((__pyx_t_5numpy_float64_t)__pyx_v_n2));

      /* "yt/utilities/lib/basic_octree.pyx":338
 *                 n2 = self.po2[node2.level] * self.top_grid_dims[i]
 *                 dx2 = 1. / (<np.float64_t> n2)
 *                 d2 = f64max(d2, dx2)             # <<<<<<<<<<<<<<
 *         # Now calculate the opening angle.
 *         dist = self.fbe_node_separation(node1, node2)
 */
      __pyx_v_d2 = __pyx_f_2yt_9utilities_3lib_12basic_octree_f64max(__pyx_v_d2, __pyx_v_dx2);
    }
  }
  __pyx_L4:;

  /* "yt/utilities/lib/basic_octree.pyx":340
 *                 d2 = f64max(d2, dx2)
 *         # Now calculate the opening angle.
 *         dist = self.fbe_node_separation(node1, node2)             # <<<<<<<<<<<<<<
 *         self.dist = dist
 *         return d2 / dist
 */
  __pyx_v_dist = ((struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self->__pyx_vtab)->fbe_node_separation(__pyx_v_self, __pyx_v_node1, __pyx_v_node2);

  /* "yt/utilities/lib/basic_octree.pyx":341
 *         # Now calculate the opening angle.
 *         dist = self.fbe_node_separation(node1, node2)
 *         self.dist = dist             # <<<<<<<<<<<<<<
 *         return d2 / dist
 * 
 */
  __pyx_v_self->dist = __pyx_v_dist;

  /* "yt/utilities/lib/basic_octree.pyx":342
 *         dist = self.fbe_node_separation(node1, node2)
 *         self.dist = dist
 *         return d2 / dist             # <<<<<<<<<<<<<<
 * 
 *     cdef void set_next(self, OctreeNode *node, int treecode):
 */
  __pyx_r = (__pyx_v_d2 / __pyx_v_dist);
  goto __pyx_L0;

  /* "yt/utilities/lib/basic_octree.pyx":315
 * 
 *     @cython.cdivision(True)
 *     cdef np.float64_t fbe_opening_angle(self, OctreeNode *node1,             # <<<<<<<<<<<<<<
 *             OctreeNode *node2):
 *         # Calculate the opening angle of node2 upon the center of node1.
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yt/utilities/lib/basic_octree.pyx":344
 *         return d2 / dist
 * 
 *     cdef void set_next(self, OctreeNode *node, int treecode):             # <<<<<<<<<<<<<<
 *         # This sets up the linked list, pointing node.next to the next node
 *         # in the iteration order.
 */

static void __pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_set_next(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node, int __pyx_v_treecode) {
  int __pyx_v_i;
  int __pyx_v_j;
  int __pyx_v_k;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  __Pyx_RefNannySetupContext("set_next", 0);

  /* "yt/utilities/lib/basic_octree.pyx":348
 *         # in the iteration order.
 *         cdef int i, j, k
 *         if treecode and node.val[0] is not 0.:             # <<<<<<<<<<<<<<
 *             # In a treecode, we only make a new next link if this node has mass.
 *             self.last_node.next = node
 */
  __pyx_t_2 = (__pyx_v_treecode != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (((__pyx_v_node->val[0]) != 0.) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "yt/utilities/lib/basic_octree.pyx":350
 *         if treecode and node.val[0] is not 0.:
 *             # In a treecode, we only make a new next link if this node has mass.
 *             self.last_node.next = node             # <<<<<<<<<<<<<<
 *             self.last_node = node
 *         elif treecode and node.val[0] is 0.:
 */
    __pyx_v_self->last_node->next = __pyx_v_node;

    /* "yt/utilities/lib/basic_octree.pyx":351
 *             # In a treecode, we only make a new next link if this node has mass.
 *             self.last_node.next = node
 *             self.last_node = node             # <<<<<<<<<<<<<<
 *         elif treecode and node.val[0] is 0.:
 *             # No mass means it's children have no mass, no need to dig an
 */
    __pyx_v_self->last_node = __pyx_v_node;

    /* "yt/utilities/lib/basic_octree.pyx":348
 *         # in the iteration order.
 *         cdef int i, j, k
 *         if treecode and node.val[0] is not 0.:             # <<<<<<<<<<<<<<
 *             # In a treecode, we only make a new next link if this node has mass.
 *             self.last_node.next = node
 */
    goto __pyx_L3;
  }

  /* "yt/utilities/lib/basic_octree.pyx":352
 *             self.last_node.next = node
 *             self.last_node = node
 *         elif treecode and node.val[0] is 0.:             # <<<<<<<<<<<<<<
 *             # No mass means it's children have no mass, no need to dig an
 *             # further.
 */
  __pyx_t_2 = (__pyx_v_treecode != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_2 = (((__pyx_v_node->val[0]) == 0.) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L6_bool_binop_done:;
  if (__pyx_t_1) {

    /* "yt/utilities/lib/basic_octree.pyx":355
 *             # No mass means it's children have no mass, no need to dig an
 *             # further.
 *             return             # <<<<<<<<<<<<<<
 *         else:
 *             # We're not doing the treecode, but we still want a linked list,
 */
    goto __pyx_L0;

    /* "yt/utilities/lib/basic_octree.pyx":352
 *             self.last_node.next = node
 *             self.last_node = node
 *         elif treecode and node.val[0] is 0.:             # <<<<<<<<<<<<<<
 *             # No mass means it's children have no mass, no need to dig an
 *             # further.
 */
  }

  /* "yt/utilities/lib/basic_octree.pyx":359
 *             # We're not doing the treecode, but we still want a linked list,
 *             # we don't care about val[0] necessarily.
 *             self.last_node.next = node             # <<<<<<<<<<<<<<
 *             self.last_node = node
 *         if node.children[0][0][0] is NULL: return
 */
  /*else*/ {
    __pyx_v_self->last_node->next = __pyx_v_node;

    /* "yt/utilities/lib/basic_octree.pyx":360
 *             # we don't care about val[0] necessarily.
 *             self.last_node.next = node
 *             self.last_node = node             # <<<<<<<<<<<<<<
 *         if node.children[0][0][0] is NULL: return
 *         for i in range(2):
 */
    __pyx_v_self->last_node = __pyx_v_node;
  }
  __pyx_L3:;

  /* "yt/utilities/lib/basic_octree.pyx":361
 *             self.last_node.next = node
 *             self.last_node = node
 *         if node.children[0][0][0] is NULL: return             # <<<<<<<<<<<<<<
 *         for i in range(2):
 *             for j in range(2):
 */
  __pyx_t_1 = (((((__pyx_v_node->children[0])[0])[0]) == NULL) != 0);
  if (__pyx_t_1) {
    goto __pyx_L0;
  }

  /* "yt/utilities/lib/basic_octree.pyx":362
 *             self.last_node = node
 *         if node.children[0][0][0] is NULL: return
 *         for i in range(2):             # <<<<<<<<<<<<<<
 *             for j in range(2):
 *                 for k in range(2):
 */
  for (__pyx_t_3 = 0; __pyx_t_3 < 2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "yt/utilities/lib/basic_octree.pyx":363
 *         if node.children[0][0][0] is NULL: return
 *         for i in range(2):
 *             for j in range(2):             # <<<<<<<<<<<<<<
 *                 for k in range(2):
 *                     self.set_next(node.children[i][j][k], treecode)
 */
    for (__pyx_t_4 = 0; __pyx_t_4 < 2; __pyx_t_4+=1) {
      __pyx_v_j = __pyx_t_4;

      /* "yt/utilities/lib/basic_octree.pyx":364
 *         for i in range(2):
 *             for j in range(2):
 *                 for k in range(2):             # <<<<<<<<<<<<<<
 *                     self.set_next(node.children[i][j][k], treecode)
 *         return
 */
      for (__pyx_t_5 = 0; __pyx_t_5 < 2; __pyx_t_5+=1) {
        __pyx_v_k = __pyx_t_5;

        /* "yt/utilities/lib/basic_octree.pyx":365
 *             for j in range(2):
 *                 for k in range(2):
 *                     self.set_next(node.children[i][j][k], treecode)             # <<<<<<<<<<<<<<
 *         return
 * 
 */
        ((struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self->__pyx_vtab)->set_next(__pyx_v_self, (((__pyx_v_node->children[__pyx_v_i])[__pyx_v_j])[__pyx_v_k]), __pyx_v_treecode);
      }
    }
  }

  /* "yt/utilities/lib/basic_octree.pyx":366
 *                 for k in range(2):
 *                     self.set_next(node.children[i][j][k], treecode)
 *         return             # <<<<<<<<<<<<<<
 * 
 *     cdef void set_up_next(self, OctreeNode *node):
 */
  goto __pyx_L0;

  /* "yt/utilities/lib/basic_octree.pyx":344
 *         return d2 / dist
 * 
 *     cdef void set_next(self, OctreeNode *node, int treecode):             # <<<<<<<<<<<<<<
 *         # This sets up the linked list, pointing node.next to the next node
 *         # in the iteration order.
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "yt/utilities/lib/basic_octree.pyx":368
 *         return
 * 
 *     cdef void set_up_next(self, OctreeNode *node):             # <<<<<<<<<<<<<<
 *         # This sets up a second linked list, pointing node.up_next to the next
 *         # node in the list that is at the same or lower (coarser) level than
 */

static void __pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_set_up_next(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node) {
  struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_initial_next;
  struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_temp_next;
  __Pyx_RefNannyDeclarations
  struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_t_1;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("set_up_next", 0);

  /* "yt/utilities/lib/basic_octree.pyx":375
 *         cdef OctreeNode *initial_next
 *         cdef OctreeNode *temp_next
 *         initial_next = node.next             # <<<<<<<<<<<<<<
 *         temp_next = node.next
 *         if node.next is NULL: return
 */
  __pyx_t_1 = __pyx_v_node->next;
  __pyx_v_initial_next = __pyx_t_1;

  /* "yt/utilities/lib/basic_octree.pyx":376
 *         cdef OctreeNode *temp_next
 *         initial_next = node.next
 *         temp_next = node.next             # <<<<<<<<<<<<<<
 *         if node.next is NULL: return
 *         while temp_next.level > node.level:
 */
  __pyx_t_1 = __pyx_v_node->next;
  __pyx_v_temp_next = __pyx_t_1;

  /* "yt/utilities/lib/basic_octree.pyx":377
 *         initial_next = node.next
 *         temp_next = node.next
 *         if node.next is NULL: return             # <<<<<<<<<<<<<<
 *         while temp_next.level > node.level:
 *             temp_next = temp_next.next
 */
  __pyx_t_2 = ((__pyx_v_node->next == NULL) != 0);
  if (__pyx_t_2) {
    goto __pyx_L0;
  }

  /* "yt/utilities/lib/basic_octree.pyx":378
 *         temp_next = node.next
 *         if node.next is NULL: return
 *         while temp_next.level > node.level:             # <<<<<<<<<<<<<<
 *             temp_next = temp_next.next
 *             if temp_next is NULL: break
 */
  while (1) {
    __pyx_t_2 = ((__pyx_v_temp_next->level > __pyx_v_node->level) != 0);
    if (!__pyx_t_2) break;

    /* "yt/utilities/lib/basic_octree.pyx":379
 *         if node.next is NULL: return
 *         while temp_next.level > node.level:
 *             temp_next = temp_next.next             # <<<<<<<<<<<<<<
 *             if temp_next is NULL: break
 *         node.up_next = temp_next
 */
    __pyx_t_1 = __pyx_v_temp_next->next;
    __pyx_v_temp_next = __pyx_t_1;

    /* "yt/utilities/lib/basic_octree.pyx":380
 *         while temp_next.level > node.level:
 *             temp_next = temp_next.next
 *             if temp_next is NULL: break             # <<<<<<<<<<<<<<
 *         node.up_next = temp_next
 *         self.set_up_next(initial_next)
 */
    __pyx_t_2 = ((__pyx_v_temp_next == NULL) != 0);
    if (__pyx_t_2) {
      goto __pyx_L5_break;
    }
  }
  __pyx_L5_break:;

  /* "yt/utilities/lib/basic_octree.pyx":381
 *             temp_next = temp_next.next
 *             if temp_next is NULL: break
 *         node.up_next = temp_next             # <<<<<<<<<<<<<<
 *         self.set_up_next(initial_next)
 * 
 */
  __pyx_v_node->up_next = __pyx_v_temp_next;

  /* "yt/utilities/lib/basic_octree.pyx":382
 *             if temp_next is NULL: break
 *         node.up_next = temp_next
 *         self.set_up_next(initial_next)             # <<<<<<<<<<<<<<
 * 
 *     def finalize(self, int treecode = 0):
 */
  ((struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self->__pyx_vtab)->set_up_next(__pyx_v_self, __pyx_v_initial_next);

  /* "yt/utilities/lib/basic_octree.pyx":368
 *         return
 * 
 *     cdef void set_up_next(self, OctreeNode *node):             # <<<<<<<<<<<<<<
 *         # This sets up a second linked list, pointing node.up_next to the next
 *         # node in the list that is at the same or lower (coarser) level than
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "yt/utilities/lib/basic_octree.pyx":384
 *         self.set_up_next(initial_next)
 * 
 *     def finalize(self, int treecode = 0):             # <<<<<<<<<<<<<<
 *         # Set up the linked list for the nodes.
 *         # Set treecode = 1 if nodes with no mass are to be skipped in the
 */

/* Python wrapper */
static PyObject *__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_9finalize(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_9finalize(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_v_treecode;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("finalize (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_treecode,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_treecode);
          if (value) { values[0] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "finalize") < 0)) __PYX_ERR(0, 384, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_treecode = __Pyx_PyInt_As_int(values[0]); if (unlikely((__pyx_v_treecode == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 384, __pyx_L3_error)
    } else {
      __pyx_v_treecode = ((int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("finalize", 0, 0, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 384, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("yt.utilities.lib.basic_octree.Octree.finalize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_8finalize(((struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self), __pyx_v_treecode);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_8finalize(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, int __pyx_v_treecode) {
  int __pyx_v_i;
  int __pyx_v_j;
  int __pyx_v_k;
  int __pyx_v_sum;
  int __pyx_v_top_grid_total;
  int __pyx_v_ii;
  int __pyx_v_jj;
  int __pyx_v_kk;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __pyx_t_5numpy_int64_t __pyx_t_1;
  int __pyx_t_2;
  __pyx_t_5numpy_int64_t __pyx_t_3;
  int __pyx_t_4;
  __pyx_t_5numpy_int64_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  long __pyx_t_8;
  __Pyx_RefNannySetupContext("finalize", 0);

  /* "yt/utilities/lib/basic_octree.pyx":389
 *         # list.
 *         cdef int i, j, k, sum, top_grid_total, ii, jj, kk
 *         self.last_node = self.root_nodes[0][0][0]             # <<<<<<<<<<<<<<
 *         for i in range(self.top_grid_dims[0]):
 *             for j in range(self.top_grid_dims[1]):
 */
  __pyx_v_self->last_node = (((__pyx_v_self->root_nodes[0])[0])[0]);

  /* "yt/utilities/lib/basic_octree.pyx":390
 *         cdef int i, j, k, sum, top_grid_total, ii, jj, kk
 *         self.last_node = self.root_nodes[0][0][0]
 *         for i in range(self.top_grid_dims[0]):             # <<<<<<<<<<<<<<
 *             for j in range(self.top_grid_dims[1]):
 *                 for k in range(self.top_grid_dims[2]):
 */
  __pyx_t_1 = (__pyx_v_self->top_grid_dims[0]);
  for (__pyx_t_2 = 0; __pyx_t_2 < __pyx_t_1; __pyx_t_2+=1) {
    __pyx_v_i = __pyx_t_2;

    /* "yt/utilities/lib/basic_octree.pyx":391
 *         self.last_node = self.root_nodes[0][0][0]
 *         for i in range(self.top_grid_dims[0]):
 *             for j in range(self.top_grid_dims[1]):             # <<<<<<<<<<<<<<
 *                 for k in range(self.top_grid_dims[2]):
 *                     self.set_next(self.root_nodes[i][j][k], treecode)
 */
    __pyx_t_3 = (__pyx_v_self->top_grid_dims[1]);
    for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_j = __pyx_t_4;

      /* "yt/utilities/lib/basic_octree.pyx":392
 *         for i in range(self.top_grid_dims[0]):
 *             for j in range(self.top_grid_dims[1]):
 *                 for k in range(self.top_grid_dims[2]):             # <<<<<<<<<<<<<<
 *                     self.set_next(self.root_nodes[i][j][k], treecode)
 *         # Now we want to link to the next node in the list that is
 */
      __pyx_t_5 = (__pyx_v_self->top_grid_dims[2]);
      for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
        __pyx_v_k = __pyx_t_6;

        /* "yt/utilities/lib/basic_octree.pyx":393
 *             for j in range(self.top_grid_dims[1]):
 *                 for k in range(self.top_grid_dims[2]):
 *                     self.set_next(self.root_nodes[i][j][k], treecode)             # <<<<<<<<<<<<<<
 *         # Now we want to link to the next node in the list that is
 *         # on a level the same or lower (coarser) than us. This will be used
 */
        ((struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self->__pyx_vtab)->set_next(__pyx_v_self, (((__pyx_v_self->root_nodes[__pyx_v_i])[__pyx_v_j])[__pyx_v_k]), __pyx_v_treecode);
      }
    }
  }

  /* "yt/utilities/lib/basic_octree.pyx":397
 *         # on a level the same or lower (coarser) than us. This will be used
 *         # during a treecode search so we can skip higher-level (finer) nodes.
 *         sum = 1             # <<<<<<<<<<<<<<
 *         top_grid_total = self.top_grid_dims[0] * self.top_grid_dims[1] * \
 *             self.top_grid_dims[2]
 */
  __pyx_v_sum = 1;

  /* "yt/utilities/lib/basic_octree.pyx":398
 *         # during a treecode search so we can skip higher-level (finer) nodes.
 *         sum = 1
 *         top_grid_total = self.top_grid_dims[0] * self.top_grid_dims[1] * \             # <<<<<<<<<<<<<<
 *             self.top_grid_dims[2]
 *         for i in range(self.top_grid_dims[0]):
 */
  __pyx_v_top_grid_total = (((__pyx_v_self->top_grid_dims[0]) * (__pyx_v_self->top_grid_dims[1])) * (__pyx_v_self->top_grid_dims[2]));

  /* "yt/utilities/lib/basic_octree.pyx":400
 *         top_grid_total = self.top_grid_dims[0] * self.top_grid_dims[1] * \
 *             self.top_grid_dims[2]
 *         for i in range(self.top_grid_dims[0]):             # <<<<<<<<<<<<<<
 *             for j in range(self.top_grid_dims[1]):
 *                 for k in range(self.top_grid_dims[2]):
 */
  __pyx_t_1 = (__pyx_v_self->top_grid_dims[0]);
  for (__pyx_t_2 = 0; __pyx_t_2 < __pyx_t_1; __pyx_t_2+=1) {
    __pyx_v_i = __pyx_t_2;

    /* "yt/utilities/lib/basic_octree.pyx":401
 *             self.top_grid_dims[2]
 *         for i in range(self.top_grid_dims[0]):
 *             for j in range(self.top_grid_dims[1]):             # <<<<<<<<<<<<<<
 *                 for k in range(self.top_grid_dims[2]):
 *                     self.set_up_next(self.root_nodes[i][j][k])
 */
    __pyx_t_3 = (__pyx_v_self->top_grid_dims[1]);
    for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_j = __pyx_t_4;

      /* "yt/utilities/lib/basic_octree.pyx":402
 *         for i in range(self.top_grid_dims[0]):
 *             for j in range(self.top_grid_dims[1]):
 *                 for k in range(self.top_grid_dims[2]):             # <<<<<<<<<<<<<<
 *                     self.set_up_next(self.root_nodes[i][j][k])
 *                     # Point the root_nodes.up_next to the next root_node in the
 */
      __pyx_t_5 = (__pyx_v_self->top_grid_dims[2]);
      for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
        __pyx_v_k = __pyx_t_6;

        /* "yt/utilities/lib/basic_octree.pyx":403
 *             for j in range(self.top_grid_dims[1]):
 *                 for k in range(self.top_grid_dims[2]):
 *                     self.set_up_next(self.root_nodes[i][j][k])             # <<<<<<<<<<<<<<
 *                     # Point the root_nodes.up_next to the next root_node in the
 *                     # list, except for the last one which stays pointing to NULL.
 */
        ((struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self->__pyx_vtab)->set_up_next(__pyx_v_self, (((__pyx_v_self->root_nodes[__pyx_v_i])[__pyx_v_j])[__pyx_v_k]));

        /* "yt/utilities/lib/basic_octree.pyx":406
 *                     # Point the root_nodes.up_next to the next root_node in the
 *                     # list, except for the last one which stays pointing to NULL.
 *                     if sum < top_grid_total - 1:             # <<<<<<<<<<<<<<
 *                         ii = i
 *                         jj = j
 */
        __pyx_t_7 = ((__pyx_v_sum < (__pyx_v_top_grid_total - 1)) != 0);
        if (__pyx_t_7) {

          /* "yt/utilities/lib/basic_octree.pyx":407
 *                     # list, except for the last one which stays pointing to NULL.
 *                     if sum < top_grid_total - 1:
 *                         ii = i             # <<<<<<<<<<<<<<
 *                         jj = j
 *                         kk = (k + 1) % self.top_grid_dims[2]
 */
          __pyx_v_ii = __pyx_v_i;

          /* "yt/utilities/lib/basic_octree.pyx":408
 *                     if sum < top_grid_total - 1:
 *                         ii = i
 *                         jj = j             # <<<<<<<<<<<<<<
 *                         kk = (k + 1) % self.top_grid_dims[2]
 *                         if kk < k:
 */
          __pyx_v_jj = __pyx_v_j;

          /* "yt/utilities/lib/basic_octree.pyx":409
 *                         ii = i
 *                         jj = j
 *                         kk = (k + 1) % self.top_grid_dims[2]             # <<<<<<<<<<<<<<
 *                         if kk < k:
 *                             jj = (j + 1) % self.top_grid_dims[1]
 */
          __pyx_t_8 = (__pyx_v_k + 1);
          if (unlikely((__pyx_v_self->top_grid_dims[2]) == 0)) {
            PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
            __PYX_ERR(0, 409, __pyx_L1_error)
          }
          __pyx_v_kk = __Pyx_mod___pyx_t_5numpy_int64_t(__pyx_t_8, (__pyx_v_self->top_grid_dims[2]));

          /* "yt/utilities/lib/basic_octree.pyx":410
 *                         jj = j
 *                         kk = (k + 1) % self.top_grid_dims[2]
 *                         if kk < k:             # <<<<<<<<<<<<<<
 *                             jj = (j + 1) % self.top_grid_dims[1]
 *                             if jj < j:
 */
          __pyx_t_7 = ((__pyx_v_kk < __pyx_v_k) != 0);
          if (__pyx_t_7) {

            /* "yt/utilities/lib/basic_octree.pyx":411
 *                         kk = (k + 1) % self.top_grid_dims[2]
 *                         if kk < k:
 *                             jj = (j + 1) % self.top_grid_dims[1]             # <<<<<<<<<<<<<<
 *                             if jj < j:
 *                                 ii = (i + 1) % self.top_grid_dims[0]
 */
            __pyx_t_8 = (__pyx_v_j + 1);
            if (unlikely((__pyx_v_self->top_grid_dims[1]) == 0)) {
              PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
              __PYX_ERR(0, 411, __pyx_L1_error)
            }
            __pyx_v_jj = __Pyx_mod___pyx_t_5numpy_int64_t(__pyx_t_8, (__pyx_v_self->top_grid_dims[1]));

            /* "yt/utilities/lib/basic_octree.pyx":412
 *                         if kk < k:
 *                             jj = (j + 1) % self.top_grid_dims[1]
 *                             if jj < j:             # <<<<<<<<<<<<<<
 *                                 ii = (i + 1) % self.top_grid_dims[0]
 *                         self.root_nodes[i][j][k].up_next = \
 */
            __pyx_t_7 = ((__pyx_v_jj < __pyx_v_j) != 0);
            if (__pyx_t_7) {

              /* "yt/utilities/lib/basic_octree.pyx":413
 *                             jj = (j + 1) % self.top_grid_dims[1]
 *                             if jj < j:
 *                                 ii = (i + 1) % self.top_grid_dims[0]             # <<<<<<<<<<<<<<
 *                         self.root_nodes[i][j][k].up_next = \
 *                             self.root_nodes[ii][jj][kk]
 */
              __pyx_t_8 = (__pyx_v_i + 1);
              if (unlikely((__pyx_v_self->top_grid_dims[0]) == 0)) {
                PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
                __PYX_ERR(0, 413, __pyx_L1_error)
              }
              __pyx_v_ii = __Pyx_mod___pyx_t_5numpy_int64_t(__pyx_t_8, (__pyx_v_self->top_grid_dims[0]));

              /* "yt/utilities/lib/basic_octree.pyx":412
 *                         if kk < k:
 *                             jj = (j + 1) % self.top_grid_dims[1]
 *                             if jj < j:             # <<<<<<<<<<<<<<
 *                                 ii = (i + 1) % self.top_grid_dims[0]
 *                         self.root_nodes[i][j][k].up_next = \
 */
            }

            /* "yt/utilities/lib/basic_octree.pyx":410
 *                         jj = j
 *                         kk = (k + 1) % self.top_grid_dims[2]
 *                         if kk < k:             # <<<<<<<<<<<<<<
 *                             jj = (j + 1) % self.top_grid_dims[1]
 *                             if jj < j:
 */
          }

          /* "yt/utilities/lib/basic_octree.pyx":414
 *                             if jj < j:
 *                                 ii = (i + 1) % self.top_grid_dims[0]
 *                         self.root_nodes[i][j][k].up_next = \             # <<<<<<<<<<<<<<
 *                             self.root_nodes[ii][jj][kk]
 *                     sum += 1
 */
          (((__pyx_v_self->root_nodes[__pyx_v_i])[__pyx_v_j])[__pyx_v_k])->up_next = (((__pyx_v_self->root_nodes[__pyx_v_ii])[__pyx_v_jj])[__pyx_v_kk]);

          /* "yt/utilities/lib/basic_octree.pyx":406
 *                     # Point the root_nodes.up_next to the next root_node in the
 *                     # list, except for the last one which stays pointing to NULL.
 *                     if sum < top_grid_total - 1:             # <<<<<<<<<<<<<<
 *                         ii = i
 *                         jj = j
 */
        }

        /* "yt/utilities/lib/basic_octree.pyx":416
 *                         self.root_nodes[i][j][k].up_next = \
 *                             self.root_nodes[ii][jj][kk]
 *                     sum += 1             # <<<<<<<<<<<<<<
 * 
 *     @cython.cdivision(True)
 */
        __pyx_v_sum = (__pyx_v_sum + 1);
      }
    }
  }

  /* "yt/utilities/lib/basic_octree.pyx":384
 *         self.set_up_next(initial_next)
 * 
 *     def finalize(self, int treecode = 0):             # <<<<<<<<<<<<<<
 *         # Set up the linked list for the nodes.
 *         # Set treecode = 1 if nodes with no mass are to be skipped in the
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("yt.utilities.lib.basic_octree.Octree.finalize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yt/utilities/lib/basic_octree.pyx":419
 * 
 *     @cython.cdivision(True)
 *     cdef np.float64_t fbe_main(self, np.float64_t potential, int truncate,             # <<<<<<<<<<<<<<
 *             np.float64_t kinetic):
 *         # The work is done here. Starting at the top of the linked list of
 */

static __pyx_t_5numpy_float64_t __pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_fbe_main(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, __pyx_t_5numpy_float64_t __pyx_v_potential, int __pyx_v_truncate, __pyx_t_5numpy_float64_t __pyx_v_kinetic) {
  __pyx_t_5numpy_float64_t __pyx_v_angle;
  __pyx_t_5numpy_float64_t __pyx_v_dist;
  struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_this_node;
  struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_pair_node;
  __pyx_t_5numpy_float64_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_t_2;
  int __pyx_t_3;
  __Pyx_RefNannySetupContext("fbe_main", 0);

  /* "yt/utilities/lib/basic_octree.pyx":426
 *         cdef OctreeNode *this_node
 *         cdef OctreeNode *pair_node
 *         this_node = self.root_nodes[0][0][0]             # <<<<<<<<<<<<<<
 *         while this_node is not NULL:
 *             # Iterate down the list to a node that either has no children and
 */
  __pyx_v_this_node = (((__pyx_v_self->root_nodes[0])[0])[0]);

  /* "yt/utilities/lib/basic_octree.pyx":427
 *         cdef OctreeNode *pair_node
 *         this_node = self.root_nodes[0][0][0]
 *         while this_node is not NULL:             # <<<<<<<<<<<<<<
 *             # Iterate down the list to a node that either has no children and
 *             # is at the max_level of the tree, or to a node where
 */
  while (1) {
    __pyx_t_1 = ((__pyx_v_this_node != NULL) != 0);
    if (!__pyx_t_1) break;

    /* "yt/utilities/lib/basic_octree.pyx":432
 *             # all of its children are massless. The second case is when data
 *             # from a level that isn't the deepest has been added to the tree.
 *             while this_node.max_level is not this_node.level:             # <<<<<<<<<<<<<<
 *                 this_node = this_node.next
 *                 # In case we reach the end of the list...
 */
    while (1) {
      __pyx_t_1 = ((__pyx_v_this_node->max_level != __pyx_v_this_node->level) != 0);
      if (!__pyx_t_1) break;

      /* "yt/utilities/lib/basic_octree.pyx":433
 *             # from a level that isn't the deepest has been added to the tree.
 *             while this_node.max_level is not this_node.level:
 *                 this_node = this_node.next             # <<<<<<<<<<<<<<
 *                 # In case we reach the end of the list...
 *                 if this_node is NULL: break
 */
      __pyx_t_2 = __pyx_v_this_node->next;
      __pyx_v_this_node = __pyx_t_2;

      /* "yt/utilities/lib/basic_octree.pyx":435
 *                 this_node = this_node.next
 *                 # In case we reach the end of the list...
 *                 if this_node is NULL: break             # <<<<<<<<<<<<<<
 *             if this_node is NULL: break
 *             if truncate and potential > kinetic:
 */
      __pyx_t_1 = ((__pyx_v_this_node == NULL) != 0);
      if (__pyx_t_1) {
        goto __pyx_L6_break;
      }
    }
    __pyx_L6_break:;

    /* "yt/utilities/lib/basic_octree.pyx":436
 *                 # In case we reach the end of the list...
 *                 if this_node is NULL: break
 *             if this_node is NULL: break             # <<<<<<<<<<<<<<
 *             if truncate and potential > kinetic:
 *                 print 'Truncating...'
 */
    __pyx_t_1 = ((__pyx_v_this_node == NULL) != 0);
    if (__pyx_t_1) {
      goto __pyx_L4_break;
    }

    /* "yt/utilities/lib/basic_octree.pyx":437
 *                 if this_node is NULL: break
 *             if this_node is NULL: break
 *             if truncate and potential > kinetic:             # <<<<<<<<<<<<<<
 *                 print 'Truncating...'
 *                 break
 */
    __pyx_t_3 = (__pyx_v_truncate != 0);
    if (__pyx_t_3) {
    } else {
      __pyx_t_1 = __pyx_t_3;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_3 = ((__pyx_v_potential > __pyx_v_kinetic) != 0);
    __pyx_t_1 = __pyx_t_3;
    __pyx_L10_bool_binop_done:;
    if (__pyx_t_1) {

      /* "yt/utilities/lib/basic_octree.pyx":438
 *             if this_node is NULL: break
 *             if truncate and potential > kinetic:
 *                 print 'Truncating...'             # <<<<<<<<<<<<<<
 *                 break
 *             pair_node = this_node.next
 */
      if (__Pyx_PrintOne(0, __pyx_kp_s_Truncating) < 0) __PYX_ERR(0, 438, __pyx_L1_error)

      /* "yt/utilities/lib/basic_octree.pyx":439
 *             if truncate and potential > kinetic:
 *                 print 'Truncating...'
 *                 break             # <<<<<<<<<<<<<<
 *             pair_node = this_node.next
 *             while pair_node is not NULL:
 */
      goto __pyx_L4_break;

      /* "yt/utilities/lib/basic_octree.pyx":437
 *                 if this_node is NULL: break
 *             if this_node is NULL: break
 *             if truncate and potential > kinetic:             # <<<<<<<<<<<<<<
 *                 print 'Truncating...'
 *                 break
 */
    }

    /* "yt/utilities/lib/basic_octree.pyx":440
 *                 print 'Truncating...'
 *                 break
 *             pair_node = this_node.next             # <<<<<<<<<<<<<<
 *             while pair_node is not NULL:
 *                 # If pair_node is massless, we can jump to up_next, because
 */
    __pyx_t_2 = __pyx_v_this_node->next;
    __pyx_v_pair_node = __pyx_t_2;

    /* "yt/utilities/lib/basic_octree.pyx":441
 *                 break
 *             pair_node = this_node.next
 *             while pair_node is not NULL:             # <<<<<<<<<<<<<<
 *                 # If pair_node is massless, we can jump to up_next, because
 *                 # nothing pair_node contains will have mass either.
 */
    while (1) {
      __pyx_t_1 = ((__pyx_v_pair_node != NULL) != 0);
      if (!__pyx_t_1) break;

      /* "yt/utilities/lib/basic_octree.pyx":446
 *                 # I think that this should primarily happen for root_nodes
 *                 # created for padding to make the region cubical.
 *                 if pair_node.val[0] is 0.0:             # <<<<<<<<<<<<<<
 *                     pair_node = pair_node.up_next
 *                     continue
 */
      __pyx_t_1 = (((__pyx_v_pair_node->val[0]) == 0.0) != 0);
      if (__pyx_t_1) {

        /* "yt/utilities/lib/basic_octree.pyx":447
 *                 # created for padding to make the region cubical.
 *                 if pair_node.val[0] is 0.0:
 *                     pair_node = pair_node.up_next             # <<<<<<<<<<<<<<
 *                     continue
 *                 # If pair_node is a childless node, or is a coarser node with
 */
        __pyx_t_2 = __pyx_v_pair_node->up_next;
        __pyx_v_pair_node = __pyx_t_2;

        /* "yt/utilities/lib/basic_octree.pyx":448
 *                 if pair_node.val[0] is 0.0:
 *                     pair_node = pair_node.up_next
 *                     continue             # <<<<<<<<<<<<<<
 *                 # If pair_node is a childless node, or is a coarser node with
 *                 # no children, we can calculate the pot
 */
        goto __pyx_L12_continue;

        /* "yt/utilities/lib/basic_octree.pyx":446
 *                 # I think that this should primarily happen for root_nodes
 *                 # created for padding to make the region cubical.
 *                 if pair_node.val[0] is 0.0:             # <<<<<<<<<<<<<<
 *                     pair_node = pair_node.up_next
 *                     continue
 */
      }

      /* "yt/utilities/lib/basic_octree.pyx":452
 *                 # no children, we can calculate the pot
 *                 # right now, and get a new pair_node.
 *                 if pair_node.max_level is pair_node.level:             # <<<<<<<<<<<<<<
 *                     dist = self.fbe_node_separation(this_node, pair_node)
 *                     potential += this_node.val[0] * pair_node.val[0] / dist
 */
      __pyx_t_1 = ((__pyx_v_pair_node->max_level == __pyx_v_pair_node->level) != 0);
      if (__pyx_t_1) {

        /* "yt/utilities/lib/basic_octree.pyx":453
 *                 # right now, and get a new pair_node.
 *                 if pair_node.max_level is pair_node.level:
 *                     dist = self.fbe_node_separation(this_node, pair_node)             # <<<<<<<<<<<<<<
 *                     potential += this_node.val[0] * pair_node.val[0] / dist
 *                     if truncate and potential > kinetic: break
 */
        __pyx_v_dist = ((struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self->__pyx_vtab)->fbe_node_separation(__pyx_v_self, __pyx_v_this_node, __pyx_v_pair_node);

        /* "yt/utilities/lib/basic_octree.pyx":454
 *                 if pair_node.max_level is pair_node.level:
 *                     dist = self.fbe_node_separation(this_node, pair_node)
 *                     potential += this_node.val[0] * pair_node.val[0] / dist             # <<<<<<<<<<<<<<
 *                     if truncate and potential > kinetic: break
 *                     pair_node = pair_node.next
 */
        __pyx_v_potential = (__pyx_v_potential + (((__pyx_v_this_node->val[0]) * (__pyx_v_pair_node->val[0])) / __pyx_v_dist));

        /* "yt/utilities/lib/basic_octree.pyx":455
 *                     dist = self.fbe_node_separation(this_node, pair_node)
 *                     potential += this_node.val[0] * pair_node.val[0] / dist
 *                     if truncate and potential > kinetic: break             # <<<<<<<<<<<<<<
 *                     pair_node = pair_node.next
 *                     continue
 */
        __pyx_t_3 = (__pyx_v_truncate != 0);
        if (__pyx_t_3) {
        } else {
          __pyx_t_1 = __pyx_t_3;
          goto __pyx_L17_bool_binop_done;
        }
        __pyx_t_3 = ((__pyx_v_potential > __pyx_v_kinetic) != 0);
        __pyx_t_1 = __pyx_t_3;
        __pyx_L17_bool_binop_done:;
        if (__pyx_t_1) {
          goto __pyx_L13_break;
        }

        /* "yt/utilities/lib/basic_octree.pyx":456
 *                     potential += this_node.val[0] * pair_node.val[0] / dist
 *                     if truncate and potential > kinetic: break
 *                     pair_node = pair_node.next             # <<<<<<<<<<<<<<
 *                     continue
 *                 # Next, if the opening angle to pair_node is small enough,
 */
        __pyx_t_2 = __pyx_v_pair_node->next;
        __pyx_v_pair_node = __pyx_t_2;

        /* "yt/utilities/lib/basic_octree.pyx":457
 *                     if truncate and potential > kinetic: break
 *                     pair_node = pair_node.next
 *                     continue             # <<<<<<<<<<<<<<
 *                 # Next, if the opening angle to pair_node is small enough,
 *                 # calculate the potential and get a new pair_node using
 */
        goto __pyx_L12_continue;

        /* "yt/utilities/lib/basic_octree.pyx":452
 *                 # no children, we can calculate the pot
 *                 # right now, and get a new pair_node.
 *                 if pair_node.max_level is pair_node.level:             # <<<<<<<<<<<<<<
 *                     dist = self.fbe_node_separation(this_node, pair_node)
 *                     potential += this_node.val[0] * pair_node.val[0] / dist
 */
      }

      /* "yt/utilities/lib/basic_octree.pyx":461
 *                 # calculate the potential and get a new pair_node using
 *                 # up_next because we don't need to look at pair_node's children.
 *                 angle = self.fbe_opening_angle(this_node, pair_node)             # <<<<<<<<<<<<<<
 *                 if angle < self.opening_angle:
 *                     # self.dist was just set in fbe_opening_angle, so we
 */
      __pyx_v_angle = ((struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self->__pyx_vtab)->fbe_opening_angle(__pyx_v_self, __pyx_v_this_node, __pyx_v_pair_node);

      /* "yt/utilities/lib/basic_octree.pyx":462
 *                 # up_next because we don't need to look at pair_node's children.
 *                 angle = self.fbe_opening_angle(this_node, pair_node)
 *                 if angle < self.opening_angle:             # <<<<<<<<<<<<<<
 *                     # self.dist was just set in fbe_opening_angle, so we
 *                     # can use it here without re-calculating it for these two
 */
      __pyx_t_1 = ((__pyx_v_angle < __pyx_v_self->opening_angle) != 0);
      if (__pyx_t_1) {

        /* "yt/utilities/lib/basic_octree.pyx":466
 *                     # can use it here without re-calculating it for these two
 *                     # nodes.
 *                     potential += this_node.val[0] * pair_node.val[0] / self.dist             # <<<<<<<<<<<<<<
 *                     if truncate and potential > kinetic: break
 *                     # We can skip all the nodes that are contained within
 */
        __pyx_v_potential = (__pyx_v_potential + (((__pyx_v_this_node->val[0]) * (__pyx_v_pair_node->val[0])) / __pyx_v_self->dist));

        /* "yt/utilities/lib/basic_octree.pyx":467
 *                     # nodes.
 *                     potential += this_node.val[0] * pair_node.val[0] / self.dist
 *                     if truncate and potential > kinetic: break             # <<<<<<<<<<<<<<
 *                     # We can skip all the nodes that are contained within
 *                     # pair_node, saving time walking the linked list.
 */
        __pyx_t_3 = (__pyx_v_truncate != 0);
        if (__pyx_t_3) {
        } else {
          __pyx_t_1 = __pyx_t_3;
          goto __pyx_L21_bool_binop_done;
        }
        __pyx_t_3 = ((__pyx_v_potential > __pyx_v_kinetic) != 0);
        __pyx_t_1 = __pyx_t_3;
        __pyx_L21_bool_binop_done:;
        if (__pyx_t_1) {
          goto __pyx_L13_break;
        }

        /* "yt/utilities/lib/basic_octree.pyx":470
 *                     # We can skip all the nodes that are contained within
 *                     # pair_node, saving time walking the linked list.
 *                     pair_node = pair_node.up_next             # <<<<<<<<<<<<<<
 *                 # If we've gotten this far, pair_node has children, but it's
 *                 # too coarse, so we simply dig deeper using .next.
 */
        __pyx_t_2 = __pyx_v_pair_node->up_next;
        __pyx_v_pair_node = __pyx_t_2;

        /* "yt/utilities/lib/basic_octree.pyx":462
 *                 # up_next because we don't need to look at pair_node's children.
 *                 angle = self.fbe_opening_angle(this_node, pair_node)
 *                 if angle < self.opening_angle:             # <<<<<<<<<<<<<<
 *                     # self.dist was just set in fbe_opening_angle, so we
 *                     # can use it here without re-calculating it for these two
 */
        goto __pyx_L19;
      }

      /* "yt/utilities/lib/basic_octree.pyx":474
 *                 # too coarse, so we simply dig deeper using .next.
 *                 else:
 *                     pair_node = pair_node.next             # <<<<<<<<<<<<<<
 *             # We've exhausted the pair_nodes.
 *             # Now we find a new this_node in the list, and do more searches
 */
      /*else*/ {
        __pyx_t_2 = __pyx_v_pair_node->next;
        __pyx_v_pair_node = __pyx_t_2;
      }
      __pyx_L19:;
      __pyx_L12_continue:;
    }
    __pyx_L13_break:;

    /* "yt/utilities/lib/basic_octree.pyx":478
 *             # Now we find a new this_node in the list, and do more searches
 *             # over pair_node.
 *             this_node = this_node.next             # <<<<<<<<<<<<<<
 *         return potential
 * 
 */
    __pyx_t_2 = __pyx_v_this_node->next;
    __pyx_v_this_node = __pyx_t_2;
  }
  __pyx_L4_break:;

  /* "yt/utilities/lib/basic_octree.pyx":479
 *             # over pair_node.
 *             this_node = this_node.next
 *         return potential             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __pyx_r = __pyx_v_potential;
  goto __pyx_L0;

  /* "yt/utilities/lib/basic_octree.pyx":419
 * 
 *     @cython.cdivision(True)
 *     cdef np.float64_t fbe_main(self, np.float64_t potential, int truncate,             # <<<<<<<<<<<<<<
 *             np.float64_t kinetic):
 *         # The work is done here. Starting at the top of the linked list of
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_WriteUnraisable("yt.utilities.lib.basic_octree.Octree.fbe_main", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yt/utilities/lib/basic_octree.pyx":483
 *     @cython.boundscheck(False)
 *     @cython.wraparound(False)
 *     def find_binding_energy(self, int truncate, np.float64_t kinetic,             # <<<<<<<<<<<<<<
 *         np.ndarray[np.float64_t, ndim=1] root_dx, float opening_angle = 1.0):
 *         r"""Find the binding energy of an ensemble of data points using the
 */

/* Python wrapper */
static PyObject *__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_11find_binding_energy(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_2yt_9utilities_3lib_12basic_octree_6Octree_10find_binding_energy[] = "Find the binding energy of an ensemble of data points using the\n        treecode method.\n        \n        Note: The first entry of the vals array MUST be Mass. Any other\n        values will be ignored, including the weight array.\n        ";
static PyObject *__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_11find_binding_energy(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_v_truncate;
  __pyx_t_5numpy_float64_t __pyx_v_kinetic;
  PyArrayObject *__pyx_v_root_dx = 0;
  float __pyx_v_opening_angle;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("find_binding_energy (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_truncate,&__pyx_n_s_kinetic,&__pyx_n_s_root_dx,&__pyx_n_s_opening_angle,0};
    PyObject* values[4] = {0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_truncate)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_kinetic)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("find_binding_energy", 0, 3, 4, 1); __PYX_ERR(0, 483, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_root_dx)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("find_binding_energy", 0, 3, 4, 2); __PYX_ERR(0, 483, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_opening_angle);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "find_binding_energy") < 0)) __PYX_ERR(0, 483, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_truncate = __Pyx_PyInt_As_int(values[0]); if (unlikely((__pyx_v_truncate == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 483, __pyx_L3_error)
    __pyx_v_kinetic = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_kinetic == ((npy_float64)-1)) && PyErr_Occurred())) __PYX_ERR(0, 483, __pyx_L3_error)
    __pyx_v_root_dx = ((PyArrayObject *)values[2]);
    if (values[3]) {
      __pyx_v_opening_angle = __pyx_PyFloat_AsFloat(values[3]); if (unlikely((__pyx_v_opening_angle == (float)-1) && PyErr_Occurred())) __PYX_ERR(0, 484, __pyx_L3_error)
    } else {
      __pyx_v_opening_angle = ((float)1.0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("find_binding_energy", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 483, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("yt.utilities.lib.basic_octree.Octree.find_binding_energy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_root_dx), __pyx_ptype_5numpy_ndarray, 1, "root_dx", 0))) __PYX_ERR(0, 484, __pyx_L1_error)
  __pyx_r = __pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_10find_binding_energy(((struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self), __pyx_v_truncate, __pyx_v_kinetic, __pyx_v_root_dx, __pyx_v_opening_angle);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_10find_binding_energy(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, int __pyx_v_truncate, __pyx_t_5numpy_float64_t __pyx_v_kinetic, PyArrayObject *__pyx_v_root_dx, float __pyx_v_opening_angle) {
  int __pyx_v_i;
  __pyx_t_5numpy_float64_t __pyx_v_potential;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_root_dx;
  __Pyx_Buffer __pyx_pybuffer_root_dx;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("find_binding_energy", 0);
  __pyx_pybuffer_root_dx.pybuffer.buf = NULL;
  __pyx_pybuffer_root_dx.refcount = 0;
  __pyx_pybuffernd_root_dx.data = NULL;
  __pyx_pybuffernd_root_dx.rcbuffer = &__pyx_pybuffer_root_dx;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_root_dx.rcbuffer->pybuffer, (PyObject*)__pyx_v_root_dx, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 483, __pyx_L1_error)
  }
  __pyx_pybuffernd_root_dx.diminfo[0].strides = __pyx_pybuffernd_root_dx.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_root_dx.diminfo[0].shape = __pyx_pybuffernd_root_dx.rcbuffer->pybuffer.shape[0];

  /* "yt/utilities/lib/basic_octree.pyx":495
 *         cdef int i
 *         cdef np.float64_t potential
 *         potential = 0.0             # <<<<<<<<<<<<<<
 *         self.opening_angle = opening_angle
 *         for i in range(3):
 */
  __pyx_v_potential = 0.0;

  /* "yt/utilities/lib/basic_octree.pyx":496
 *         cdef np.float64_t potential
 *         potential = 0.0
 *         self.opening_angle = opening_angle             # <<<<<<<<<<<<<<
 *         for i in range(3):
 *             self.root_dx[i] = root_dx[i]
 */
  __pyx_v_self->opening_angle = __pyx_v_opening_angle;

  /* "yt/utilities/lib/basic_octree.pyx":497
 *         potential = 0.0
 *         self.opening_angle = opening_angle
 *         for i in range(3):             # <<<<<<<<<<<<<<
 *             self.root_dx[i] = root_dx[i]
 *         potential = self.fbe_main(potential, truncate, kinetic)
 */
  for (__pyx_t_1 = 0; __pyx_t_1 < 3; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "yt/utilities/lib/basic_octree.pyx":498
 *         self.opening_angle = opening_angle
 *         for i in range(3):
 *             self.root_dx[i] = root_dx[i]             # <<<<<<<<<<<<<<
 *         potential = self.fbe_main(potential, truncate, kinetic)
 *         return potential
 */
    __pyx_t_2 = __pyx_v_i;
    (__pyx_v_self->root_dx[__pyx_v_i]) = (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_float64_t *, __pyx_pybuffernd_root_dx.rcbuffer->pybuffer.buf, __pyx_t_2, __pyx_pybuffernd_root_dx.diminfo[0].strides));
  }

  /* "yt/utilities/lib/basic_octree.pyx":499
 *         for i in range(3):
 *             self.root_dx[i] = root_dx[i]
 *         potential = self.fbe_main(potential, truncate, kinetic)             # <<<<<<<<<<<<<<
 *         return potential
 * 
 */
  __pyx_v_potential = ((struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self->__pyx_vtab)->fbe_main(__pyx_v_self, __pyx_v_potential, __pyx_v_truncate, __pyx_v_kinetic);

  /* "yt/utilities/lib/basic_octree.pyx":500
 *             self.root_dx[i] = root_dx[i]
 *         potential = self.fbe_main(potential, truncate, kinetic)
 *         return potential             # <<<<<<<<<<<<<<
 * 
 *     cdef int node_ID(self, OctreeNode *node):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyFloat_FromDouble(__pyx_v_potential); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "yt/utilities/lib/basic_octree.pyx":483
 *     @cython.boundscheck(False)
 *     @cython.wraparound(False)
 *     def find_binding_energy(self, int truncate, np.float64_t kinetic,             # <<<<<<<<<<<<<<
 *         np.ndarray[np.float64_t, ndim=1] root_dx, float opening_angle = 1.0):
 *         r"""Find the binding energy of an ensemble of data points using the
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_root_dx.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("yt.utilities.lib.basic_octree.Octree.find_binding_energy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_root_dx.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yt/utilities/lib/basic_octree.pyx":502
 *         return potential
 * 
 *     cdef int node_ID(self, OctreeNode *node):             # <<<<<<<<<<<<<<
 *         # Returns an unique ID for this node based on its position and level.
 *         cdef int ID, i, offset, root
 */

static int __pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_node_ID(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node) {
  int __pyx_v_ID;
  int __pyx_v_i;
  int __pyx_v_offset;
  int __pyx_v_root;
  __pyx_t_5numpy_int64_t __pyx_v_this_grid_dims[3];
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("node_ID", 0);

  /* "yt/utilities/lib/basic_octree.pyx":506
 *         cdef int ID, i, offset, root
 *         cdef np.int64_t this_grid_dims[3]
 *         offset = 0             # <<<<<<<<<<<<<<
 *         root = 1
 *         for i in range(3):
 */
  __pyx_v_offset = 0;

  /* "yt/utilities/lib/basic_octree.pyx":507
 *         cdef np.int64_t this_grid_dims[3]
 *         offset = 0
 *         root = 1             # <<<<<<<<<<<<<<
 *         for i in range(3):
 *             root *= self.top_grid_dims[i]
 */
  __pyx_v_root = 1;

  /* "yt/utilities/lib/basic_octree.pyx":508
 *         offset = 0
 *         root = 1
 *         for i in range(3):             # <<<<<<<<<<<<<<
 *             root *= self.top_grid_dims[i]
 *             this_grid_dims[i] = self.top_grid_dims[i] * 2**node.level
 */
  for (__pyx_t_1 = 0; __pyx_t_1 < 3; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "yt/utilities/lib/basic_octree.pyx":509
 *         root = 1
 *         for i in range(3):
 *             root *= self.top_grid_dims[i]             # <<<<<<<<<<<<<<
 *             this_grid_dims[i] = self.top_grid_dims[i] * 2**node.level
 *         for i in range(node.level):
 */
    __pyx_v_root = (__pyx_v_root * (__pyx_v_self->top_grid_dims[__pyx_v_i]));

    /* "yt/utilities/lib/basic_octree.pyx":510
 *         for i in range(3):
 *             root *= self.top_grid_dims[i]
 *             this_grid_dims[i] = self.top_grid_dims[i] * 2**node.level             # <<<<<<<<<<<<<<
 *         for i in range(node.level):
 *             offset += root * 2**(3 * i)
 */
    (__pyx_v_this_grid_dims[__pyx_v_i]) = ((__pyx_v_self->top_grid_dims[__pyx_v_i]) * __Pyx_pow_long(2, ((long)__pyx_v_node->level)));
  }

  /* "yt/utilities/lib/basic_octree.pyx":511
 *             root *= self.top_grid_dims[i]
 *             this_grid_dims[i] = self.top_grid_dims[i] * 2**node.level
 *         for i in range(node.level):             # <<<<<<<<<<<<<<
 *             offset += root * 2**(3 * i)
 *         ID = offset + (node.pos[0] + this_grid_dims[0] * (node.pos[1] + \
 */
  __pyx_t_1 = __pyx_v_node->level;
  for (__pyx_t_2 = 0; __pyx_t_2 < __pyx_t_1; __pyx_t_2+=1) {
    __pyx_v_i = __pyx_t_2;

    /* "yt/utilities/lib/basic_octree.pyx":512
 *             this_grid_dims[i] = self.top_grid_dims[i] * 2**node.level
 *         for i in range(node.level):
 *             offset += root * 2**(3 * i)             # <<<<<<<<<<<<<<
 *         ID = offset + (node.pos[0] + this_grid_dims[0] * (node.pos[1] + \
 *             this_grid_dims[1] * node.pos[2]))
 */
    __pyx_v_offset = (__pyx_v_offset + (__pyx_v_root * __Pyx_pow_long(2, (3 * __pyx_v_i))));
  }

  /* "yt/utilities/lib/basic_octree.pyx":513
 *         for i in range(node.level):
 *             offset += root * 2**(3 * i)
 *         ID = offset + (node.pos[0] + this_grid_dims[0] * (node.pos[1] + \             # <<<<<<<<<<<<<<
 *             this_grid_dims[1] * node.pos[2]))
 *         return ID
 */
  __pyx_v_ID = (__pyx_v_offset + ((__pyx_v_node->pos[0]) + ((__pyx_v_this_grid_dims[0]) * ((__pyx_v_node->pos[1]) + ((__pyx_v_this_grid_dims[1]) * (__pyx_v_node->pos[2]))))));

  /* "yt/utilities/lib/basic_octree.pyx":515
 *         ID = offset + (node.pos[0] + this_grid_dims[0] * (node.pos[1] + \
 *             this_grid_dims[1] * node.pos[2]))
 *         return ID             # <<<<<<<<<<<<<<
 * 
 *     cdef int node_ID_on_level(self, OctreeNode *node):
 */
  __pyx_r = __pyx_v_ID;
  goto __pyx_L0;

  /* "yt/utilities/lib/basic_octree.pyx":502
 *         return potential
 * 
 *     cdef int node_ID(self, OctreeNode *node):             # <<<<<<<<<<<<<<
 *         # Returns an unique ID for this node based on its position and level.
 *         cdef int ID, i, offset, root
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yt/utilities/lib/basic_octree.pyx":517
 *         return ID
 * 
 *     cdef int node_ID_on_level(self, OctreeNode *node):             # <<<<<<<<<<<<<<
 *         # Returns the node ID on node.level for this node.
 *         cdef int ID, i
 */

static int __pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_node_ID_on_level(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node) {
  int __pyx_v_ID;
  int __pyx_v_i;
  __pyx_t_5numpy_int64_t __pyx_v_this_grid_dims[3];
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("node_ID_on_level", 0);

  /* "yt/utilities/lib/basic_octree.pyx":521
 *         cdef int ID, i
 *         cdef np.int64_t this_grid_dims[3]
 *         for i in range(3):             # <<<<<<<<<<<<<<
 *             this_grid_dims[i] = self.top_grid_dims[i] * 2**node.level
 *         ID = node.pos[0] + this_grid_dims[0] * (node.pos[1] + \
 */
  for (__pyx_t_1 = 0; __pyx_t_1 < 3; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "yt/utilities/lib/basic_octree.pyx":522
 *         cdef np.int64_t this_grid_dims[3]
 *         for i in range(3):
 *             this_grid_dims[i] = self.top_grid_dims[i] * 2**node.level             # <<<<<<<<<<<<<<
 *         ID = node.pos[0] + this_grid_dims[0] * (node.pos[1] + \
 *             this_grid_dims[1] * node.pos[2])
 */
    (__pyx_v_this_grid_dims[__pyx_v_i]) = ((__pyx_v_self->top_grid_dims[__pyx_v_i]) * __Pyx_pow_long(2, ((long)__pyx_v_node->level)));
  }

  /* "yt/utilities/lib/basic_octree.pyx":523
 *         for i in range(3):
 *             this_grid_dims[i] = self.top_grid_dims[i] * 2**node.level
 *         ID = node.pos[0] + this_grid_dims[0] * (node.pos[1] + \             # <<<<<<<<<<<<<<
 *             this_grid_dims[1] * node.pos[2])
 *         return ID
 */
  __pyx_v_ID = ((__pyx_v_node->pos[0]) + ((__pyx_v_this_grid_dims[0]) * ((__pyx_v_node->pos[1]) + ((__pyx_v_this_grid_dims[1]) * (__pyx_v_node->pos[2])))));

  /* "yt/utilities/lib/basic_octree.pyx":525
 *         ID = node.pos[0] + this_grid_dims[0] * (node.pos[1] + \
 *             this_grid_dims[1] * node.pos[2])
 *         return ID             # <<<<<<<<<<<<<<
 * 
 *     cdef void print_node_info(self, OctreeNode *node):
 */
  __pyx_r = __pyx_v_ID;
  goto __pyx_L0;

  /* "yt/utilities/lib/basic_octree.pyx":517
 *         return ID
 * 
 *     cdef int node_ID_on_level(self, OctreeNode *node):             # <<<<<<<<<<<<<<
 *         # Returns the node ID on node.level for this node.
 *         cdef int ID, i
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yt/utilities/lib/basic_octree.pyx":527
 *         return ID
 * 
 *     cdef void print_node_info(self, OctreeNode *node):             # <<<<<<<<<<<<<<
 *         cdef int i, j, k
 *         line = "%d\t" % self.node_ID(node)
 */

static void __pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_print_node_info(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node) {
  int __pyx_v_i;
  int __pyx_v_j;
  int __pyx_v_k;
  PyObject *__pyx_v_line = NULL;
  PyObject *__pyx_v_nline = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("print_node_info", 0);

  /* "yt/utilities/lib/basic_octree.pyx":529
 *     cdef void print_node_info(self, OctreeNode *node):
 *         cdef int i, j, k
 *         line = "%d\t" % self.node_ID(node)             # <<<<<<<<<<<<<<
 *         if node.next is not NULL:
 *             line += "%d\t" % self.node_ID(node.next)
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(((struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self->__pyx_vtab)->node_ID(__pyx_v_self, __pyx_v_node)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyString_Format(__pyx_kp_s_d, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_line = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "yt/utilities/lib/basic_octree.pyx":530
 *         cdef int i, j, k
 *         line = "%d\t" % self.node_ID(node)
 *         if node.next is not NULL:             # <<<<<<<<<<<<<<
 *             line += "%d\t" % self.node_ID(node.next)
 *         else: line += "-1\t"
 */
  __pyx_t_3 = ((__pyx_v_node->next != NULL) != 0);
  if (__pyx_t_3) {

    /* "yt/utilities/lib/basic_octree.pyx":531
 *         line = "%d\t" % self.node_ID(node)
 *         if node.next is not NULL:
 *             line += "%d\t" % self.node_ID(node.next)             # <<<<<<<<<<<<<<
 *         else: line += "-1\t"
 *         if node.up_next is not NULL:
 */
    __pyx_t_2 = __Pyx_PyInt_From_int(((struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self->__pyx_vtab)->node_ID(__pyx_v_self, __pyx_v_node->next)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 531, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_d, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 531, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_line, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 531, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_line, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "yt/utilities/lib/basic_octree.pyx":530
 *         cdef int i, j, k
 *         line = "%d\t" % self.node_ID(node)
 *         if node.next is not NULL:             # <<<<<<<<<<<<<<
 *             line += "%d\t" % self.node_ID(node.next)
 *         else: line += "-1\t"
 */
    goto __pyx_L3;
  }

  /* "yt/utilities/lib/basic_octree.pyx":532
 *         if node.next is not NULL:
 *             line += "%d\t" % self.node_ID(node.next)
 *         else: line += "-1\t"             # <<<<<<<<<<<<<<
 *         if node.up_next is not NULL:
 *             line += "%d\t" % self.node_ID(node.up_next)
 */
  /*else*/ {
    __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_line, __pyx_kp_s_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 532, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_line, __pyx_t_2);
    __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "yt/utilities/lib/basic_octree.pyx":533
 *             line += "%d\t" % self.node_ID(node.next)
 *         else: line += "-1\t"
 *         if node.up_next is not NULL:             # <<<<<<<<<<<<<<
 *             line += "%d\t" % self.node_ID(node.up_next)
 *         else: line += "-1\t"
 */
  __pyx_t_3 = ((__pyx_v_node->up_next != NULL) != 0);
  if (__pyx_t_3) {

    /* "yt/utilities/lib/basic_octree.pyx":534
 *         else: line += "-1\t"
 *         if node.up_next is not NULL:
 *             line += "%d\t" % self.node_ID(node.up_next)             # <<<<<<<<<<<<<<
 *         else: line += "-1\t"
 *         line += "%d\t%d\t%d\t%d\t" % (node.level,node.pos[0],node.pos[1],node.pos[2])
 */
    __pyx_t_2 = __Pyx_PyInt_From_int(((struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self->__pyx_vtab)->node_ID(__pyx_v_self, __pyx_v_node->up_next)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 534, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_d, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 534, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_line, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 534, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_line, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "yt/utilities/lib/basic_octree.pyx":533
 *             line += "%d\t" % self.node_ID(node.next)
 *         else: line += "-1\t"
 *         if node.up_next is not NULL:             # <<<<<<<<<<<<<<
 *             line += "%d\t" % self.node_ID(node.up_next)
 *         else: line += "-1\t"
 */
    goto __pyx_L4;
  }

  /* "yt/utilities/lib/basic_octree.pyx":535
 *         if node.up_next is not NULL:
 *             line += "%d\t" % self.node_ID(node.up_next)
 *         else: line += "-1\t"             # <<<<<<<<<<<<<<
 *         line += "%d\t%d\t%d\t%d\t" % (node.level,node.pos[0],node.pos[1],node.pos[2])
 *         for i in range(node.nvals):
 */
  /*else*/ {
    __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_line, __pyx_kp_s_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 535, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_line, __pyx_t_2);
    __pyx_t_2 = 0;
  }
  __pyx_L4:;

  /* "yt/utilities/lib/basic_octree.pyx":536
 *             line += "%d\t" % self.node_ID(node.up_next)
 *         else: line += "-1\t"
 *         line += "%d\t%d\t%d\t%d\t" % (node.level,node.pos[0],node.pos[1],node.pos[2])             # <<<<<<<<<<<<<<
 *         for i in range(node.nvals):
 *             line += "%1.5e\t" % node.val[i]
 */
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_node->level); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyInt_From_npy_int64((__pyx_v_node->pos[0])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyInt_From_npy_int64((__pyx_v_node->pos[1])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyInt_From_npy_int64((__pyx_v_node->pos[2])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyTuple_New(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_6, 3, __pyx_t_5);
  __pyx_t_2 = 0;
  __pyx_t_1 = 0;
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyString_Format(__pyx_kp_s_d_d_d_d, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_InPlaceAdd(__pyx_v_line, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF_SET(__pyx_v_line, __pyx_t_6);
  __pyx_t_6 = 0;

  /* "yt/utilities/lib/basic_octree.pyx":537
 *         else: line += "-1\t"
 *         line += "%d\t%d\t%d\t%d\t" % (node.level,node.pos[0],node.pos[1],node.pos[2])
 *         for i in range(node.nvals):             # <<<<<<<<<<<<<<
 *             line += "%1.5e\t" % node.val[i]
 *         line += "%f\t" % node.weight_val
 */
  __pyx_t_7 = __pyx_v_node->nvals;
  for (__pyx_t_8 = 0; __pyx_t_8 < __pyx_t_7; __pyx_t_8+=1) {
    __pyx_v_i = __pyx_t_8;

    /* "yt/utilities/lib/basic_octree.pyx":538
 *         line += "%d\t%d\t%d\t%d\t" % (node.level,node.pos[0],node.pos[1],node.pos[2])
 *         for i in range(node.nvals):
 *             line += "%1.5e\t" % node.val[i]             # <<<<<<<<<<<<<<
 *         line += "%f\t" % node.weight_val
 *         line += "%s\t%s\t" % (node.children[0][0][0] is not NULL, node.parent is not NULL)
 */
    __pyx_t_6 = PyFloat_FromDouble((__pyx_v_node->val[__pyx_v_i])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 538, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __Pyx_PyString_Format(__pyx_kp_s_1_5e, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 538, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyNumber_InPlaceAdd(__pyx_v_line, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 538, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_line, __pyx_t_6);
    __pyx_t_6 = 0;
  }

  /* "yt/utilities/lib/basic_octree.pyx":539
 *         for i in range(node.nvals):
 *             line += "%1.5e\t" % node.val[i]
 *         line += "%f\t" % node.weight_val             # <<<<<<<<<<<<<<
 *         line += "%s\t%s\t" % (node.children[0][0][0] is not NULL, node.parent is not NULL)
 *         if node.children[0][0][0] is not NULL:
 */
  __pyx_t_6 = PyFloat_FromDouble(__pyx_v_node->weight_val); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = __Pyx_PyString_Format(__pyx_kp_s_f, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_InPlaceAdd(__pyx_v_line, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF_SET(__pyx_v_line, __pyx_t_6);
  __pyx_t_6 = 0;

  /* "yt/utilities/lib/basic_octree.pyx":540
 *             line += "%1.5e\t" % node.val[i]
 *         line += "%f\t" % node.weight_val
 *         line += "%s\t%s\t" % (node.children[0][0][0] is not NULL, node.parent is not NULL)             # <<<<<<<<<<<<<<
 *         if node.children[0][0][0] is not NULL:
 *             nline = ""
 */
  __pyx_t_6 = __Pyx_PyBool_FromLong(((((__pyx_v_node->children[0])[0])[0]) != NULL)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = __Pyx_PyBool_FromLong((__pyx_v_node->parent != NULL)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_5);
  __pyx_t_6 = 0;
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyString_Format(__pyx_kp_s_s_s, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_line, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF_SET(__pyx_v_line, __pyx_t_4);
  __pyx_t_4 = 0;

  /* "yt/utilities/lib/basic_octree.pyx":541
 *         line += "%f\t" % node.weight_val
 *         line += "%s\t%s\t" % (node.children[0][0][0] is not NULL, node.parent is not NULL)
 *         if node.children[0][0][0] is not NULL:             # <<<<<<<<<<<<<<
 *             nline = ""
 *             for i in range(2):
 */
  __pyx_t_3 = (((((__pyx_v_node->children[0])[0])[0]) != NULL) != 0);
  if (__pyx_t_3) {

    /* "yt/utilities/lib/basic_octree.pyx":542
 *         line += "%s\t%s\t" % (node.children[0][0][0] is not NULL, node.parent is not NULL)
 *         if node.children[0][0][0] is not NULL:
 *             nline = ""             # <<<<<<<<<<<<<<
 *             for i in range(2):
 *                 for j in range(2):
 */
    __Pyx_INCREF(__pyx_kp_s_);
    __pyx_v_nline = __pyx_kp_s_;

    /* "yt/utilities/lib/basic_octree.pyx":543
 *         if node.children[0][0][0] is not NULL:
 *             nline = ""
 *             for i in range(2):             # <<<<<<<<<<<<<<
 *                 for j in range(2):
 *                     for k in range(2):
 */
    for (__pyx_t_7 = 0; __pyx_t_7 < 2; __pyx_t_7+=1) {
      __pyx_v_i = __pyx_t_7;

      /* "yt/utilities/lib/basic_octree.pyx":544
 *             nline = ""
 *             for i in range(2):
 *                 for j in range(2):             # <<<<<<<<<<<<<<
 *                     for k in range(2):
 *                         nline += "%d," % self.node_ID(node.children[i][j][k])
 */
      for (__pyx_t_8 = 0; __pyx_t_8 < 2; __pyx_t_8+=1) {
        __pyx_v_j = __pyx_t_8;

        /* "yt/utilities/lib/basic_octree.pyx":545
 *             for i in range(2):
 *                 for j in range(2):
 *                     for k in range(2):             # <<<<<<<<<<<<<<
 *                         nline += "%d," % self.node_ID(node.children[i][j][k])
 *             line += nline
 */
        for (__pyx_t_9 = 0; __pyx_t_9 < 2; __pyx_t_9+=1) {
          __pyx_v_k = __pyx_t_9;

          /* "yt/utilities/lib/basic_octree.pyx":546
 *                 for j in range(2):
 *                     for k in range(2):
 *                         nline += "%d," % self.node_ID(node.children[i][j][k])             # <<<<<<<<<<<<<<
 *             line += nline
 *         print line
 */
          __pyx_t_4 = __Pyx_PyInt_From_int(((struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self->__pyx_vtab)->node_ID(__pyx_v_self, (((__pyx_v_node->children[__pyx_v_i])[__pyx_v_j])[__pyx_v_k]))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 546, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_5 = __Pyx_PyString_Format(__pyx_kp_s_d_2, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 546, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_nline, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 546, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF_SET(__pyx_v_nline, __pyx_t_4);
          __pyx_t_4 = 0;
        }
      }
    }

    /* "yt/utilities/lib/basic_octree.pyx":547
 *                     for k in range(2):
 *                         nline += "%d," % self.node_ID(node.children[i][j][k])
 *             line += nline             # <<<<<<<<<<<<<<
 *         print line
 *         return
 */
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_line, __pyx_v_nline); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 547, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_line, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "yt/utilities/lib/basic_octree.pyx":541
 *         line += "%f\t" % node.weight_val
 *         line += "%s\t%s\t" % (node.children[0][0][0] is not NULL, node.parent is not NULL)
 *         if node.children[0][0][0] is not NULL:             # <<<<<<<<<<<<<<
 *             nline = ""
 *             for i in range(2):
 */
  }

  /* "yt/utilities/lib/basic_octree.pyx":548
 *                         nline += "%d," % self.node_ID(node.children[i][j][k])
 *             line += nline
 *         print line             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  if (__Pyx_PrintOne(0, __pyx_v_line) < 0) __PYX_ERR(0, 548, __pyx_L1_error)

  /* "yt/utilities/lib/basic_octree.pyx":549
 *             line += nline
 *         print line
 *         return             # <<<<<<<<<<<<<<
 * 
 *     cdef void iterate_print_nodes(self, OctreeNode *node):
 */
  goto __pyx_L0;

  /* "yt/utilities/lib/basic_octree.pyx":527
 *         return ID
 * 
 *     cdef void print_node_info(self, OctreeNode *node):             # <<<<<<<<<<<<<<
 *         cdef int i, j, k
 *         line = "%d\t" % self.node_ID(node)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_WriteUnraisable("yt.utilities.lib.basic_octree.Octree.print_node_info", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_line);
  __Pyx_XDECREF(__pyx_v_nline);
  __Pyx_RefNannyFinishContext();
}

/* "yt/utilities/lib/basic_octree.pyx":551
 *         return
 * 
 *     cdef void iterate_print_nodes(self, OctreeNode *node):             # <<<<<<<<<<<<<<
 *         cdef int i, j, k
 *         self.print_node_info(node)
 */

static void __pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_iterate_print_nodes(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *__pyx_v_node) {
  int __pyx_v_i;
  int __pyx_v_j;
  int __pyx_v_k;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  __Pyx_RefNannySetupContext("iterate_print_nodes", 0);

  /* "yt/utilities/lib/basic_octree.pyx":553
 *     cdef void iterate_print_nodes(self, OctreeNode *node):
 *         cdef int i, j, k
 *         self.print_node_info(node)             # <<<<<<<<<<<<<<
 *         if node.children[0][0][0] is NULL:
 *             return
 */
  ((struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self->__pyx_vtab)->print_node_info(__pyx_v_self, __pyx_v_node);

  /* "yt/utilities/lib/basic_octree.pyx":554
 *         cdef int i, j, k
 *         self.print_node_info(node)
 *         if node.children[0][0][0] is NULL:             # <<<<<<<<<<<<<<
 *             return
 *         for i in range(2):
 */
  __pyx_t_1 = (((((__pyx_v_node->children[0])[0])[0]) == NULL) != 0);
  if (__pyx_t_1) {

    /* "yt/utilities/lib/basic_octree.pyx":555
 *         self.print_node_info(node)
 *         if node.children[0][0][0] is NULL:
 *             return             # <<<<<<<<<<<<<<
 *         for i in range(2):
 *             for j in range(2):
 */
    goto __pyx_L0;

    /* "yt/utilities/lib/basic_octree.pyx":554
 *         cdef int i, j, k
 *         self.print_node_info(node)
 *         if node.children[0][0][0] is NULL:             # <<<<<<<<<<<<<<
 *             return
 *         for i in range(2):
 */
  }

  /* "yt/utilities/lib/basic_octree.pyx":556
 *         if node.children[0][0][0] is NULL:
 *             return
 *         for i in range(2):             # <<<<<<<<<<<<<<
 *             for j in range(2):
 *                 for k in range(2):
 */
  for (__pyx_t_2 = 0; __pyx_t_2 < 2; __pyx_t_2+=1) {
    __pyx_v_i = __pyx_t_2;

    /* "yt/utilities/lib/basic_octree.pyx":557
 *             return
 *         for i in range(2):
 *             for j in range(2):             # <<<<<<<<<<<<<<
 *                 for k in range(2):
 *                     self.iterate_print_nodes(node.children[i][j][k])
 */
    for (__pyx_t_3 = 0; __pyx_t_3 < 2; __pyx_t_3+=1) {
      __pyx_v_j = __pyx_t_3;

      /* "yt/utilities/lib/basic_octree.pyx":558
 *         for i in range(2):
 *             for j in range(2):
 *                 for k in range(2):             # <<<<<<<<<<<<<<
 *                     self.iterate_print_nodes(node.children[i][j][k])
 *         return
 */
      for (__pyx_t_4 = 0; __pyx_t_4 < 2; __pyx_t_4+=1) {
        __pyx_v_k = __pyx_t_4;

        /* "yt/utilities/lib/basic_octree.pyx":559
 *             for j in range(2):
 *                 for k in range(2):
 *                     self.iterate_print_nodes(node.children[i][j][k])             # <<<<<<<<<<<<<<
 *         return
 * 
 */
        ((struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self->__pyx_vtab)->iterate_print_nodes(__pyx_v_self, (((__pyx_v_node->children[__pyx_v_i])[__pyx_v_j])[__pyx_v_k]));
      }
    }
  }

  /* "yt/utilities/lib/basic_octree.pyx":560
 *                 for k in range(2):
 *                     self.iterate_print_nodes(node.children[i][j][k])
 *         return             # <<<<<<<<<<<<<<
 * 
 *     def print_all_nodes(self):
 */
  goto __pyx_L0;

  /* "yt/utilities/lib/basic_octree.pyx":551
 *         return
 * 
 *     cdef void iterate_print_nodes(self, OctreeNode *node):             # <<<<<<<<<<<<<<
 *         cdef int i, j, k
 *         self.print_node_info(node)
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "yt/utilities/lib/basic_octree.pyx":562
 *         return
 * 
 *     def print_all_nodes(self):             # <<<<<<<<<<<<<<
 *         r"""
 *         Prints out information about all the nodes in the octree.
 */

/* Python wrapper */
static PyObject *__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_13print_all_nodes(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_2yt_9utilities_3lib_12basic_octree_6Octree_12print_all_nodes[] = "\n        Prints out information about all the nodes in the octree.\n        \n        Parameters\n        ----------\n        None.\n        \n        Examples\n        --------\n        >>> octree.print_all_nodes()\n        (many lines of data)\n        ";
static PyObject *__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_13print_all_nodes(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("print_all_nodes (wrapper)", 0);
  __pyx_r = __pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_12print_all_nodes(((struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_12print_all_nodes(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self) {
  int __pyx_v_i;
  int __pyx_v_j;
  int __pyx_v_k;
  PyObject *__pyx_v_line = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  __pyx_t_5numpy_int64_t __pyx_t_6;
  __pyx_t_5numpy_int64_t __pyx_t_7;
  __pyx_t_5numpy_int64_t __pyx_t_8;
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("print_all_nodes", 0);

  /* "yt/utilities/lib/basic_octree.pyx":576
 *         """
 *         cdef int i, j, k
 *         sys.stdout.flush()             # <<<<<<<<<<<<<<
 *         sys.stderr.flush()
 *         line = "ID\tnext\tup_n\tlevel\tx\ty\tz\t"
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_stdout); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_flush); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 576, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 576, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "yt/utilities/lib/basic_octree.pyx":577
 *         cdef int i, j, k
 *         sys.stdout.flush()
 *         sys.stderr.flush()             # <<<<<<<<<<<<<<
 *         line = "ID\tnext\tup_n\tlevel\tx\ty\tz\t"
 *         for i in range(self.nvals):
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_stderr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_flush); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 577, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 577, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "yt/utilities/lib/basic_octree.pyx":578
 *         sys.stdout.flush()
 *         sys.stderr.flush()
 *         line = "ID\tnext\tup_n\tlevel\tx\ty\tz\t"             # <<<<<<<<<<<<<<
 *         for i in range(self.nvals):
 *             line += "val%d\t\t" % i
 */
  __Pyx_INCREF(__pyx_kp_s_ID_next_up_n_level_x_y_z);
  __pyx_v_line = __pyx_kp_s_ID_next_up_n_level_x_y_z;

  /* "yt/utilities/lib/basic_octree.pyx":579
 *         sys.stderr.flush()
 *         line = "ID\tnext\tup_n\tlevel\tx\ty\tz\t"
 *         for i in range(self.nvals):             # <<<<<<<<<<<<<<
 *             line += "val%d\t\t" % i
 *         line += "weight\t\tchild?\tparent?\tchildren"
 */
  __pyx_t_4 = __pyx_v_self->nvals;
  for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
    __pyx_v_i = __pyx_t_5;

    /* "yt/utilities/lib/basic_octree.pyx":580
 *         line = "ID\tnext\tup_n\tlevel\tx\ty\tz\t"
 *         for i in range(self.nvals):
 *             line += "val%d\t\t" % i             # <<<<<<<<<<<<<<
 *         line += "weight\t\tchild?\tparent?\tchildren"
 *         print line
 */
    __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_i); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 580, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyString_Format(__pyx_kp_s_val_d, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 580, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_line, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 580, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_line, __pyx_t_1);
    __pyx_t_1 = 0;
  }

  /* "yt/utilities/lib/basic_octree.pyx":581
 *         for i in range(self.nvals):
 *             line += "val%d\t\t" % i
 *         line += "weight\t\tchild?\tparent?\tchildren"             # <<<<<<<<<<<<<<
 *         print line
 *         for i in range(self.top_grid_dims[0]):
 */
  __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_line, __pyx_kp_s_weight_child_parent_children); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 581, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF_SET(__pyx_v_line, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "yt/utilities/lib/basic_octree.pyx":582
 *             line += "val%d\t\t" % i
 *         line += "weight\t\tchild?\tparent?\tchildren"
 *         print line             # <<<<<<<<<<<<<<
 *         for i in range(self.top_grid_dims[0]):
 *             for j in range(self.top_grid_dims[1]):
 */
  if (__Pyx_PrintOne(0, __pyx_v_line) < 0) __PYX_ERR(0, 582, __pyx_L1_error)

  /* "yt/utilities/lib/basic_octree.pyx":583
 *         line += "weight\t\tchild?\tparent?\tchildren"
 *         print line
 *         for i in range(self.top_grid_dims[0]):             # <<<<<<<<<<<<<<
 *             for j in range(self.top_grid_dims[1]):
 *                 for k in range(self.top_grid_dims[2]):
 */
  __pyx_t_6 = (__pyx_v_self->top_grid_dims[0]);
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_6; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "yt/utilities/lib/basic_octree.pyx":584
 *         print line
 *         for i in range(self.top_grid_dims[0]):
 *             for j in range(self.top_grid_dims[1]):             # <<<<<<<<<<<<<<
 *                 for k in range(self.top_grid_dims[2]):
 *                     self.iterate_print_nodes(self.root_nodes[i][j][k])
 */
    __pyx_t_7 = (__pyx_v_self->top_grid_dims[1]);
    for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_7; __pyx_t_5+=1) {
      __pyx_v_j = __pyx_t_5;

      /* "yt/utilities/lib/basic_octree.pyx":585
 *         for i in range(self.top_grid_dims[0]):
 *             for j in range(self.top_grid_dims[1]):
 *                 for k in range(self.top_grid_dims[2]):             # <<<<<<<<<<<<<<
 *                     self.iterate_print_nodes(self.root_nodes[i][j][k])
 *         sys.stdout.flush()
 */
      __pyx_t_8 = (__pyx_v_self->top_grid_dims[2]);
      for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
        __pyx_v_k = __pyx_t_9;

        /* "yt/utilities/lib/basic_octree.pyx":586
 *             for j in range(self.top_grid_dims[1]):
 *                 for k in range(self.top_grid_dims[2]):
 *                     self.iterate_print_nodes(self.root_nodes[i][j][k])             # <<<<<<<<<<<<<<
 *         sys.stdout.flush()
 *         sys.stderr.flush()
 */
        ((struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self->__pyx_vtab)->iterate_print_nodes(__pyx_v_self, (((__pyx_v_self->root_nodes[__pyx_v_i])[__pyx_v_j])[__pyx_v_k]));
      }
    }
  }

  /* "yt/utilities/lib/basic_octree.pyx":587
 *                 for k in range(self.top_grid_dims[2]):
 *                     self.iterate_print_nodes(self.root_nodes[i][j][k])
 *         sys.stdout.flush()             # <<<<<<<<<<<<<<
 *         sys.stderr.flush()
 *         return
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_stdout); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_flush); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 587, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 587, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "yt/utilities/lib/basic_octree.pyx":588
 *                     self.iterate_print_nodes(self.root_nodes[i][j][k])
 *         sys.stdout.flush()
 *         sys.stderr.flush()             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_stderr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_flush); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 588, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 588, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "yt/utilities/lib/basic_octree.pyx":589
 *         sys.stdout.flush()
 *         sys.stderr.flush()
 *         return             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "yt/utilities/lib/basic_octree.pyx":562
 *         return
 * 
 *     def print_all_nodes(self):             # <<<<<<<<<<<<<<
 *         r"""
 *         Prints out information about all the nodes in the octree.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("yt.utilities.lib.basic_octree.Octree.print_all_nodes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_line);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yt/utilities/lib/basic_octree.pyx":591
 *         return
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         cdef int i, j, k
 *         for i in range(self.top_grid_dims[0]):
 */

/* Python wrapper */
static void __pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_15__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_15__dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_14__dealloc__(((struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_14__dealloc__(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self) {
  int __pyx_v_i;
  int __pyx_v_j;
  int __pyx_v_k;
  __Pyx_RefNannyDeclarations
  __pyx_t_5numpy_int64_t __pyx_t_1;
  int __pyx_t_2;
  __pyx_t_5numpy_int64_t __pyx_t_3;
  int __pyx_t_4;
  __pyx_t_5numpy_int64_t __pyx_t_5;
  int __pyx_t_6;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "yt/utilities/lib/basic_octree.pyx":593
 *     def __dealloc__(self):
 *         cdef int i, j, k
 *         for i in range(self.top_grid_dims[0]):             # <<<<<<<<<<<<<<
 *             for j in range(self.top_grid_dims[1]):
 *                 for k in range(self.top_grid_dims[2]):
 */
  __pyx_t_1 = (__pyx_v_self->top_grid_dims[0]);
  for (__pyx_t_2 = 0; __pyx_t_2 < __pyx_t_1; __pyx_t_2+=1) {
    __pyx_v_i = __pyx_t_2;

    /* "yt/utilities/lib/basic_octree.pyx":594
 *         cdef int i, j, k
 *         for i in range(self.top_grid_dims[0]):
 *             for j in range(self.top_grid_dims[1]):             # <<<<<<<<<<<<<<
 *                 for k in range(self.top_grid_dims[2]):
 *                     OTN_free(self.root_nodes[i][j][k])
 */
    __pyx_t_3 = (__pyx_v_self->top_grid_dims[1]);
    for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_j = __pyx_t_4;

      /* "yt/utilities/lib/basic_octree.pyx":595
 *         for i in range(self.top_grid_dims[0]):
 *             for j in range(self.top_grid_dims[1]):
 *                 for k in range(self.top_grid_dims[2]):             # <<<<<<<<<<<<<<
 *                     OTN_free(self.root_nodes[i][j][k])
 *                 free(self.root_nodes[i][j])
 */
      __pyx_t_5 = (__pyx_v_self->top_grid_dims[2]);
      for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
        __pyx_v_k = __pyx_t_6;

        /* "yt/utilities/lib/basic_octree.pyx":596
 *             for j in range(self.top_grid_dims[1]):
 *                 for k in range(self.top_grid_dims[2]):
 *                     OTN_free(self.root_nodes[i][j][k])             # <<<<<<<<<<<<<<
 *                 free(self.root_nodes[i][j])
 *             free(self.root_nodes[i])
 */
        __pyx_f_2yt_9utilities_3lib_12basic_octree_OTN_free((((__pyx_v_self->root_nodes[__pyx_v_i])[__pyx_v_j])[__pyx_v_k]));
      }

      /* "yt/utilities/lib/basic_octree.pyx":597
 *                 for k in range(self.top_grid_dims[2]):
 *                     OTN_free(self.root_nodes[i][j][k])
 *                 free(self.root_nodes[i][j])             # <<<<<<<<<<<<<<
 *             free(self.root_nodes[i])
 *         free(self.root_nodes)
 */
      free(((__pyx_v_self->root_nodes[__pyx_v_i])[__pyx_v_j]));
    }

    /* "yt/utilities/lib/basic_octree.pyx":598
 *                     OTN_free(self.root_nodes[i][j][k])
 *                 free(self.root_nodes[i][j])
 *             free(self.root_nodes[i])             # <<<<<<<<<<<<<<
 *         free(self.root_nodes)
 * 
 */
    free((__pyx_v_self->root_nodes[__pyx_v_i]));
  }

  /* "yt/utilities/lib/basic_octree.pyx":599
 *                 free(self.root_nodes[i][j])
 *             free(self.root_nodes[i])
 *         free(self.root_nodes)             # <<<<<<<<<<<<<<
 * 
 */
  free(__pyx_v_self->root_nodes);

  /* "yt/utilities/lib/basic_octree.pyx":591
 *         return
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         cdef int i, j, k
 *         for i in range(self.top_grid_dims[0]):
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_17__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_17__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_16__reduce_cython__(((struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_16__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("yt.utilities.lib.basic_octree.Octree.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_19__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_19__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_18__setstate_cython__(((struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_2yt_9utilities_3lib_12basic_octree_6Octree_18__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("yt.utilities.lib.basic_octree.Octree.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":214
 *         # experimental exception made for __getbuffer__ and __releasebuffer__
 *         # -- the details of this may change.
 *         def __getbuffer__(ndarray self, Py_buffer* info, int flags):             # <<<<<<<<<<<<<<
 *             # This implementation of getbuffer is geared towards Cython
 *             # requirements, and does not yet fullfill the PEP.
 */

/* Python wrapper */
static CYTHON_UNUSED int __pyx_pw_5numpy_7ndarray_1__getbuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
static CYTHON_UNUSED int __pyx_pw_5numpy_7ndarray_1__getbuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getbuffer__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5numpy_7ndarray___getbuffer__(((PyArrayObject *)__pyx_v_self), ((Py_buffer *)__pyx_v_info), ((int)__pyx_v_flags));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5numpy_7ndarray___getbuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_v_copy_shape;
  int __pyx_v_i;
  int __pyx_v_ndim;
  int __pyx_v_endian_detector;
  int __pyx_v_little_endian;
  int __pyx_v_t;
  char *__pyx_v_f;
  PyArray_Descr *__pyx_v_descr = 0;
  int __pyx_v_offset;
  int __pyx_v_hasfields;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  char *__pyx_t_7;
  __Pyx_RefNannySetupContext("__getbuffer__", 0);
  if (__pyx_v_info != NULL) {
    __pyx_v_info->obj = Py_None; __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(__pyx_v_info->obj);
  }

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":220
 *             # of flags
 * 
 *             if info == NULL: return             # <<<<<<<<<<<<<<
 * 
 *             cdef int copy_shape, i, ndim
 */
  __pyx_t_1 = ((__pyx_v_info == NULL) != 0);
  if (__pyx_t_1) {
    __pyx_r = 0;
    goto __pyx_L0;
  }

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":223
 * 
 *             cdef int copy_shape, i, ndim
 *             cdef int endian_detector = 1             # <<<<<<<<<<<<<<
 *             cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)
 * 
 */
  __pyx_v_endian_detector = 1;

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":224
 *             cdef int copy_shape, i, ndim
 *             cdef int endian_detector = 1
 *             cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)             # <<<<<<<<<<<<<<
 * 
 *             ndim = PyArray_NDIM(self)
 */
  __pyx_v_little_endian = ((((char *)(&__pyx_v_endian_detector))[0]) != 0);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":226
 *             cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)
 * 
 *             ndim = PyArray_NDIM(self)             # <<<<<<<<<<<<<<
 * 
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 */
  __pyx_v_ndim = PyArray_NDIM(__pyx_v_self);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":228
 *             ndim = PyArray_NDIM(self)
 * 
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):             # <<<<<<<<<<<<<<
 *                 copy_shape = 1
 *             else:
 */
  __pyx_t_1 = (((sizeof(npy_intp)) != (sizeof(Py_ssize_t))) != 0);
  if (__pyx_t_1) {

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":229
 * 
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 *                 copy_shape = 1             # <<<<<<<<<<<<<<
 *             else:
 *                 copy_shape = 0
 */
    __pyx_v_copy_shape = 1;

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":228
 *             ndim = PyArray_NDIM(self)
 * 
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):             # <<<<<<<<<<<<<<
 *                 copy_shape = 1
 *             else:
 */
    goto __pyx_L4;
  }

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":231
 *                 copy_shape = 1
 *             else:
 *                 copy_shape = 0             # <<<<<<<<<<<<<<
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 */
  /*else*/ {
    __pyx_v_copy_shape = 0;
  }
  __pyx_L4:;

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":233
 *                 copy_shape = 0
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")
 */
  __pyx_t_2 = (((__pyx_v_flags & PyBUF_C_CONTIGUOUS) == PyBUF_C_CONTIGUOUS) != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L6_bool_binop_done;
  }

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":234
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):             # <<<<<<<<<<<<<<
 *                 raise ValueError(u"ndarray is not C contiguous")
 * 
 */
  __pyx_t_2 = ((!(PyArray_CHKFLAGS(__pyx_v_self, NPY_C_CONTIGUOUS) != 0)) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L6_bool_binop_done:;

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":233
 *                 copy_shape = 0
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")
 */
  if (__pyx_t_1) {

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":235
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")             # <<<<<<<<<<<<<<
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(2, 235, __pyx_L1_error)

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":233
 *                 copy_shape = 0
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")
 */
  }

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":237
 *                 raise ValueError(u"ndarray is not C contiguous")
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 */
  __pyx_t_2 = (((__pyx_v_flags & PyBUF_F_CONTIGUOUS) == PyBUF_F_CONTIGUOUS) != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L9_bool_binop_done;
  }

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":238
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):             # <<<<<<<<<<<<<<
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 * 
 */
  __pyx_t_2 = ((!(PyArray_CHKFLAGS(__pyx_v_self, NPY_F_CONTIGUOUS) != 0)) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L9_bool_binop_done:;

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":237
 *                 raise ValueError(u"ndarray is not C contiguous")
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 */
  if (__pyx_t_1) {

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":239
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")             # <<<<<<<<<<<<<<
 * 
 *             info.buf = PyArray_DATA(self)
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__5, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 239, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(2, 239, __pyx_L1_error)

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":237
 *                 raise ValueError(u"ndarray is not C contiguous")
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 */
  }

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":241
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 * 
 *             info.buf = PyArray_DATA(self)             # <<<<<<<<<<<<<<
 *             info.ndim = ndim
 *             if copy_shape:
 */
  __pyx_v_info->buf = PyArray_DATA(__pyx_v_self);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":242
 * 
 *             info.buf = PyArray_DATA(self)
 *             info.ndim = ndim             # <<<<<<<<<<<<<<
 *             if copy_shape:
 *                 # Allocate new buffer for strides and shape info.
 */
  __pyx_v_info->ndim = __pyx_v_ndim;

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":243
 *             info.buf = PyArray_DATA(self)
 *             info.ndim = ndim
 *             if copy_shape:             # <<<<<<<<<<<<<<
 *                 # Allocate new buffer for strides and shape info.
 *                 # This is allocated as one block, strides first.
 */
  __pyx_t_1 = (__pyx_v_copy_shape != 0);
  if (__pyx_t_1) {

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":246
 *                 # Allocate new buffer for strides and shape info.
 *                 # This is allocated as one block, strides first.
 *                 info.strides = <Py_ssize_t*>PyObject_Malloc(sizeof(Py_ssize_t) * 2 * <size_t>ndim)             # <<<<<<<<<<<<<<
 *                 info.shape = info.strides + ndim
 *                 for i in range(ndim):
 */
    __pyx_v_info->strides = ((Py_ssize_t *)PyObject_Malloc((((sizeof(Py_ssize_t)) * 2) * ((size_t)__pyx_v_ndim))));

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":247
 *                 # This is allocated as one block, strides first.
 *                 info.strides = <Py_ssize_t*>PyObject_Malloc(sizeof(Py_ssize_t) * 2 * <size_t>ndim)
 *                 info.shape = info.strides + ndim             # <<<<<<<<<<<<<<
 *                 for i in range(ndim):
 *                     info.strides[i] = PyArray_STRIDES(self)[i]
 */
    __pyx_v_info->shape = (__pyx_v_info->strides + __pyx_v_ndim);

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":248
 *                 info.strides = <Py_ssize_t*>PyObject_Malloc(sizeof(Py_ssize_t) * 2 * <size_t>ndim)
 *                 info.shape = info.strides + ndim
 *                 for i in range(ndim):             # <<<<<<<<<<<<<<
 *                     info.strides[i] = PyArray_STRIDES(self)[i]
 *                     info.shape[i] = PyArray_DIMS(self)[i]
 */
    __pyx_t_4 = __pyx_v_ndim;
    for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
      __pyx_v_i = __pyx_t_5;

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":249
 *                 info.shape = info.strides + ndim
 *                 for i in range(ndim):
 *                     info.strides[i] = PyArray_STRIDES(self)[i]             # <<<<<<<<<<<<<<
 *                     info.shape[i] = PyArray_DIMS(self)[i]
 *             else:
 */
      (__pyx_v_info->strides[__pyx_v_i]) = (PyArray_STRIDES(__pyx_v_self)[__pyx_v_i]);

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":250
 *                 for i in range(ndim):
 *                     info.strides[i] = PyArray_STRIDES(self)[i]
 *                     info.shape[i] = PyArray_DIMS(self)[i]             # <<<<<<<<<<<<<<
 *             else:
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)
 */
      (__pyx_v_info->shape[__pyx_v_i]) = (PyArray_DIMS(__pyx_v_self)[__pyx_v_i]);
    }

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":243
 *             info.buf = PyArray_DATA(self)
 *             info.ndim = ndim
 *             if copy_shape:             # <<<<<<<<<<<<<<
 *                 # Allocate new buffer for strides and shape info.
 *                 # This is allocated as one block, strides first.
 */
    goto __pyx_L11;
  }

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":252
 *                     info.shape[i] = PyArray_DIMS(self)[i]
 *             else:
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)             # <<<<<<<<<<<<<<
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)
 *             info.suboffsets = NULL
 */
  /*else*/ {
    __pyx_v_info->strides = ((Py_ssize_t *)PyArray_STRIDES(__pyx_v_self));

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":253
 *             else:
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)             # <<<<<<<<<<<<<<
 *             info.suboffsets = NULL
 *             info.itemsize = PyArray_ITEMSIZE(self)
 */
    __pyx_v_info->shape = ((Py_ssize_t *)PyArray_DIMS(__pyx_v_self));
  }
  __pyx_L11:;

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":254
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)
 *             info.suboffsets = NULL             # <<<<<<<<<<<<<<
 *             info.itemsize = PyArray_ITEMSIZE(self)
 *             info.readonly = not PyArray_ISWRITEABLE(self)
 */
  __pyx_v_info->suboffsets = NULL;

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":255
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)
 *             info.suboffsets = NULL
 *             info.itemsize = PyArray_ITEMSIZE(self)             # <<<<<<<<<<<<<<
 *             info.readonly = not PyArray_ISWRITEABLE(self)
 * 
 */
  __pyx_v_info->itemsize = PyArray_ITEMSIZE(__pyx_v_self);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":256
 *             info.suboffsets = NULL
 *             info.itemsize = PyArray_ITEMSIZE(self)
 *             info.readonly = not PyArray_ISWRITEABLE(self)             # <<<<<<<<<<<<<<
 * 
 *             cdef int t
 */
  __pyx_v_info->readonly = (!(PyArray_ISWRITEABLE(__pyx_v_self) != 0));

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":259
 * 
 *             cdef int t
 *             cdef char* f = NULL             # <<<<<<<<<<<<<<
 *             cdef dtype descr = self.descr
 *             cdef int offset
 */
  __pyx_v_f = NULL;

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":260
 *             cdef int t
 *             cdef char* f = NULL
 *             cdef dtype descr = self.descr             # <<<<<<<<<<<<<<
 *             cdef int offset
 * 
 */
  __pyx_t_3 = ((PyObject *)__pyx_v_self->descr);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_v_descr = ((PyArray_Descr *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":263
 *             cdef int offset
 * 
 *             cdef bint hasfields = PyDataType_HASFIELDS(descr)             # <<<<<<<<<<<<<<
 * 
 *             if not hasfields and not copy_shape:
 */
  __pyx_v_hasfields = PyDataType_HASFIELDS(__pyx_v_descr);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":265
 *             cdef bint hasfields = PyDataType_HASFIELDS(descr)
 * 
 *             if not hasfields and not copy_shape:             # <<<<<<<<<<<<<<
 *                 # do not call releasebuffer
 *                 info.obj = None
 */
  __pyx_t_2 = ((!(__pyx_v_hasfields != 0)) != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L15_bool_binop_done;
  }
  __pyx_t_2 = ((!(__pyx_v_copy_shape != 0)) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L15_bool_binop_done:;
  if (__pyx_t_1) {

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":267
 *             if not hasfields and not copy_shape:
 *                 # do not call releasebuffer
 *                 info.obj = None             # <<<<<<<<<<<<<<
 *             else:
 *                 # need to call releasebuffer
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj);
    __pyx_v_info->obj = Py_None;

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":265
 *             cdef bint hasfields = PyDataType_HASFIELDS(descr)
 * 
 *             if not hasfields and not copy_shape:             # <<<<<<<<<<<<<<
 *                 # do not call releasebuffer
 *                 info.obj = None
 */
    goto __pyx_L14;
  }

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":270
 *             else:
 *                 # need to call releasebuffer
 *                 info.obj = self             # <<<<<<<<<<<<<<
 * 
 *             if not hasfields:
 */
  /*else*/ {
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj);
    __pyx_v_info->obj = ((PyObject *)__pyx_v_self);
  }
  __pyx_L14:;

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":272
 *                 info.obj = self
 * 
 *             if not hasfields:             # <<<<<<<<<<<<<<
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or
 */
  __pyx_t_1 = ((!(__pyx_v_hasfields != 0)) != 0);
  if (__pyx_t_1) {

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":273
 * 
 *             if not hasfields:
 *                 t = descr.type_num             # <<<<<<<<<<<<<<
 *                 if ((descr.byteorder == c'>' and little_endian) or
 *                     (descr.byteorder == c'<' and not little_endian)):
 */
    __pyx_t_4 = __pyx_v_descr->type_num;
    __pyx_v_t = __pyx_t_4;

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":274
 *             if not hasfields:
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")
 */
    __pyx_t_2 = ((__pyx_v_descr->byteorder == '>') != 0);
    if (!__pyx_t_2) {
      goto __pyx_L20_next_or;
    } else {
    }
    __pyx_t_2 = (__pyx_v_little_endian != 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L19_bool_binop_done;
    }
    __pyx_L20_next_or:;

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":275
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or
 *                     (descr.byteorder == c'<' and not little_endian)):             # <<<<<<<<<<<<<<
 *                     raise ValueError(u"Non-native byte order not supported")
 *                 if   t == NPY_BYTE:        f = "b"
 */
    __pyx_t_2 = ((__pyx_v_descr->byteorder == '<') != 0);
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L19_bool_binop_done;
    }
    __pyx_t_2 = ((!(__pyx_v_little_endian != 0)) != 0);
    __pyx_t_1 = __pyx_t_2;
    __pyx_L19_bool_binop_done:;

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":274
 *             if not hasfields:
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")
 */
    if (__pyx_t_1) {

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":276
 *                 if ((descr.byteorder == c'>' and little_endian) or
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 276, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(2, 276, __pyx_L1_error)

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":274
 *             if not hasfields:
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")
 */
    }

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":277
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")
 *                 if   t == NPY_BYTE:        f = "b"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_UBYTE:       f = "B"
 *                 elif t == NPY_SHORT:       f = "h"
 */
    switch (__pyx_v_t) {
      case NPY_BYTE:
      __pyx_v_f = ((char *)"b");
      break;

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":278
 *                     raise ValueError(u"Non-native byte order not supported")
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_SHORT:       f = "h"
 *                 elif t == NPY_USHORT:      f = "H"
 */
      case NPY_UBYTE:
      __pyx_v_f = ((char *)"B");
      break;

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":279
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"
 *                 elif t == NPY_SHORT:       f = "h"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_USHORT:      f = "H"
 *                 elif t == NPY_INT:         f = "i"
 */
      case NPY_SHORT:
      __pyx_v_f = ((char *)"h");
      break;

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":280
 *                 elif t == NPY_UBYTE:       f = "B"
 *                 elif t == NPY_SHORT:       f = "h"
 *                 elif t == NPY_USHORT:      f = "H"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_INT:         f = "i"
 *                 elif t == NPY_UINT:        f = "I"
 */
      case NPY_USHORT:
      __pyx_v_f = ((char *)"H");
      break;

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":281
 *                 elif t == NPY_SHORT:       f = "h"
 *                 elif t == NPY_USHORT:      f = "H"
 *                 elif t == NPY_INT:         f = "i"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_UINT:        f = "I"
 *                 elif t == NPY_LONG:        f = "l"
 */
      case NPY_INT:
      __pyx_v_f = ((char *)"i");
      break;

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":282
 *                 elif t == NPY_USHORT:      f = "H"
 *                 elif t == NPY_INT:         f = "i"
 *                 elif t == NPY_UINT:        f = "I"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_LONG:        f = "l"
 *                 elif t == NPY_ULONG:       f = "L"
 */
      case NPY_UINT:
      __pyx_v_f = ((char *)"I");
      break;

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":283
 *                 elif t == NPY_INT:         f = "i"
 *                 elif t == NPY_UINT:        f = "I"
 *                 elif t == NPY_LONG:        f = "l"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_ULONG:       f = "L"
 *                 elif t == NPY_LONGLONG:    f = "q"
 */
      case NPY_LONG:
      __pyx_v_f = ((char *)"l");
      break;

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":284
 *                 elif t == NPY_UINT:        f = "I"
 *                 elif t == NPY_LONG:        f = "l"
 *                 elif t == NPY_ULONG:       f = "L"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_LONGLONG:    f = "q"
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 */
      case NPY_ULONG:
      __pyx_v_f = ((char *)"L");
      break;

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":285
 *                 elif t == NPY_LONG:        f = "l"
 *                 elif t == NPY_ULONG:       f = "L"
 *                 elif t == NPY_LONGLONG:    f = "q"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 *                 elif t == NPY_FLOAT:       f = "f"
 */
      case NPY_LONGLONG:
      __pyx_v_f = ((char *)"q");
      break;

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":286
 *                 elif t == NPY_ULONG:       f = "L"
 *                 elif t == NPY_LONGLONG:    f = "q"
 *                 elif t == NPY_ULONGLONG:   f = "Q"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_FLOAT:       f = "f"
 *                 elif t == NPY_DOUBLE:      f = "d"
 */
      case NPY_ULONGLONG:
      __pyx_v_f = ((char *)"Q");
      break;

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":287
 *                 elif t == NPY_LONGLONG:    f = "q"
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 *                 elif t == NPY_FLOAT:       f = "f"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_DOUBLE:      f = "d"
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 */
      case NPY_FLOAT:
      __pyx_v_f = ((char *)"f");
      break;

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":288
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 *                 elif t == NPY_FLOAT:       f = "f"
 *                 elif t == NPY_DOUBLE:      f = "d"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 */
      case NPY_DOUBLE:
      __pyx_v_f = ((char *)"d");
      break;

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":289
 *                 elif t == NPY_FLOAT:       f = "f"
 *                 elif t == NPY_DOUBLE:      f = "d"
 *                 elif t == NPY_LONGDOUBLE:  f = "g"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 */
      case NPY_LONGDOUBLE:
      __pyx_v_f = ((char *)"g");
      break;

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":290
 *                 elif t == NPY_DOUBLE:      f = "d"
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 *                 elif t == NPY_CFLOAT:      f = "Zf"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"
 */
      case NPY_CFLOAT:
      __pyx_v_f = ((char *)"Zf");
      break;

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":291
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 *                 elif t == NPY_CDOUBLE:     f = "Zd"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"
 *                 elif t == NPY_OBJECT:      f = "O"
 */
      case NPY_CDOUBLE:
      __pyx_v_f = ((char *)"Zd");
      break;

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":292
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_OBJECT:      f = "O"
 *                 else:
 */
      case NPY_CLONGDOUBLE:
      __pyx_v_f = ((char *)"Zg");
      break;

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":293
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"
 *                 elif t == NPY_OBJECT:      f = "O"             # <<<<<<<<<<<<<<
 *                 else:
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 */
      case NPY_OBJECT:
      __pyx_v_f = ((char *)"O");
      break;
      default:

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":295
 *                 elif t == NPY_OBJECT:      f = "O"
 *                 else:
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)             # <<<<<<<<<<<<<<
 *                 info.format = f
 *                 return
 */
      __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_t); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 295, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = PyUnicode_Format(__pyx_kp_u_unknown_dtype_code_in_numpy_pxd, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 295, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 295, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_t_3, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 295, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(2, 295, __pyx_L1_error)
      break;
    }

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":296
 *                 else:
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 *                 info.format = f             # <<<<<<<<<<<<<<
 *                 return
 *             else:
 */
    __pyx_v_info->format = __pyx_v_f;

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":297
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 *                 info.format = f
 *                 return             # <<<<<<<<<<<<<<
 *             else:
 *                 info.format = <char*>PyObject_Malloc(_buffer_format_string_len)
 */
    __pyx_r = 0;
    goto __pyx_L0;

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":272
 *                 info.obj = self
 * 
 *             if not hasfields:             # <<<<<<<<<<<<<<
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or
 */
  }

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":299
 *                 return
 *             else:
 *                 info.format = <char*>PyObject_Malloc(_buffer_format_string_len)             # <<<<<<<<<<<<<<
 *                 info.format[0] = c'^' # Native data types, manual alignment
 *                 offset = 0
 */
  /*else*/ {
    __pyx_v_info->format = ((char *)PyObject_Malloc(0xFF));

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":300
 *             else:
 *                 info.format = <char*>PyObject_Malloc(_buffer_format_string_len)
 *                 info.format[0] = c'^' # Native data types, manual alignment             # <<<<<<<<<<<<<<
 *                 offset = 0
 *                 f = _util_dtypestring(descr, info.format + 1,
 */
    (__pyx_v_info->format[0]) = '^';

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":301
 *                 info.format = <char*>PyObject_Malloc(_buffer_format_string_len)
 *                 info.format[0] = c'^' # Native data types, manual alignment
 *                 offset = 0             # <<<<<<<<<<<<<<
 *                 f = _util_dtypestring(descr, info.format + 1,
 *                                       info.format + _buffer_format_string_len,
 */
    __pyx_v_offset = 0;

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":302
 *                 info.format[0] = c'^' # Native data types, manual alignment
 *                 offset = 0
 *                 f = _util_dtypestring(descr, info.format + 1,             # <<<<<<<<<<<<<<
 *                                       info.format + _buffer_format_string_len,
 *                                       &offset)
 */
    __pyx_t_7 = __pyx_f_5numpy__util_dtypestring(__pyx_v_descr, (__pyx_v_info->format + 1), (__pyx_v_info->format + 0xFF), (&__pyx_v_offset)); if (unlikely(__pyx_t_7 == ((char *)NULL))) __PYX_ERR(2, 302, __pyx_L1_error)
    __pyx_v_f = __pyx_t_7;

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":305
 *                                       info.format + _buffer_format_string_len,
 *                                       &offset)
 *                 f[0] = c'\0' # Terminate format string             # <<<<<<<<<<<<<<
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 */
    (__pyx_v_f[0]) = '\x00';
  }

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":214
 *         # experimental exception made for __getbuffer__ and __releasebuffer__
 *         # -- the details of this may change.
 *         def __getbuffer__(ndarray self, Py_buffer* info, int flags):             # <<<<<<<<<<<<<<
 *             # This implementation of getbuffer is geared towards Cython
 *             # requirements, and does not yet fullfill the PEP.
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("numpy.ndarray.__getbuffer__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  if (__pyx_v_info != NULL && __pyx_v_info->obj != NULL) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = NULL;
  }
  goto __pyx_L2;
  __pyx_L0:;
  if (__pyx_v_info != NULL && __pyx_v_info->obj == Py_None) {
    __Pyx_GOTREF(Py_None);
    __Pyx_DECREF(Py_None); __pyx_v_info->obj = NULL;
  }
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_descr);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":307
 *                 f[0] = c'\0' # Terminate format string
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):             # <<<<<<<<<<<<<<
 *             if PyArray_HASFIELDS(self):
 *                 PyObject_Free(info.format)
 */

/* Python wrapper */
static CYTHON_UNUSED void __pyx_pw_5numpy_7ndarray_3__releasebuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info); /*proto*/
static CYTHON_UNUSED void __pyx_pw_5numpy_7ndarray_3__releasebuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__releasebuffer__ (wrapper)", 0);
  __pyx_pf_5numpy_7ndarray_2__releasebuffer__(((PyArrayObject *)__pyx_v_self), ((Py_buffer *)__pyx_v_info));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_5numpy_7ndarray_2__releasebuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__releasebuffer__", 0);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":308
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 *             if PyArray_HASFIELDS(self):             # <<<<<<<<<<<<<<
 *                 PyObject_Free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 */
  __pyx_t_1 = (PyArray_HASFIELDS(__pyx_v_self) != 0);
  if (__pyx_t_1) {

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":309
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 *             if PyArray_HASFIELDS(self):
 *                 PyObject_Free(info.format)             # <<<<<<<<<<<<<<
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 *                 PyObject_Free(info.strides)
 */
    PyObject_Free(__pyx_v_info->format);

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":308
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 *             if PyArray_HASFIELDS(self):             # <<<<<<<<<<<<<<
 *                 PyObject_Free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 */
  }

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":310
 *             if PyArray_HASFIELDS(self):
 *                 PyObject_Free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):             # <<<<<<<<<<<<<<
 *                 PyObject_Free(info.strides)
 *                 # info.shape was stored after info.strides in the same block
 */
  __pyx_t_1 = (((sizeof(npy_intp)) != (sizeof(Py_ssize_t))) != 0);
  if (__pyx_t_1) {

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":311
 *                 PyObject_Free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 *                 PyObject_Free(info.strides)             # <<<<<<<<<<<<<<
 *                 # info.shape was stored after info.strides in the same block
 * 
 */
    PyObject_Free(__pyx_v_info->strides);

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":310
 *             if PyArray_HASFIELDS(self):
 *                 PyObject_Free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):             # <<<<<<<<<<<<<<
 *                 PyObject_Free(info.strides)
 *                 # info.shape was stored after info.strides in the same block
 */
  }

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":307
 *                 f[0] = c'\0' # Terminate format string
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):             # <<<<<<<<<<<<<<
 *             if PyArray_HASFIELDS(self):
 *                 PyObject_Free(info.format)
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":788
 * ctypedef npy_cdouble     complex_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew1(PyObject *__pyx_v_a) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew1", 0);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":789
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 *     return PyArray_MultiIterNew(1, <void*>a)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(1, ((void *)__pyx_v_a)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":788
 * ctypedef npy_cdouble     complex_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":791
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew2(PyObject *__pyx_v_a, PyObject *__pyx_v_b) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew2", 0);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":792
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(2, ((void *)__pyx_v_a), ((void *)__pyx_v_b)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":791
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":794
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew3(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew3", 0);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":795
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(3, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":794
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew3", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":797
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew4(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew4", 0);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":798
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(4, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":797
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew4", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":800
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew5(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d, PyObject *__pyx_v_e) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew5", 0);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":801
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)             # <<<<<<<<<<<<<<
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(5, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d), ((void *)__pyx_v_e)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 801, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":800
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew5", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":803
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):             # <<<<<<<<<<<<<<
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyDataType_SHAPE(PyArray_Descr *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("PyDataType_SHAPE", 0);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":804
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):             # <<<<<<<<<<<<<<
 *         return <tuple>d.subarray.shape
 *     else:
 */
  __pyx_t_1 = (PyDataType_HASSUBARRAY(__pyx_v_d) != 0);
  if (__pyx_t_1) {

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":805
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape             # <<<<<<<<<<<<<<
 *     else:
 *         return ()
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject*)__pyx_v_d->subarray->shape));
    __pyx_r = ((PyObject*)__pyx_v_d->subarray->shape);
    goto __pyx_L0;

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":804
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):             # <<<<<<<<<<<<<<
 *         return <tuple>d.subarray.shape
 *     else:
 */
  }

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":807
 *         return <tuple>d.subarray.shape
 *     else:
 *         return ()             # <<<<<<<<<<<<<<
 * 
 * cdef inline char* _util_dtypestring(dtype descr, char* f, char* end, int* offset) except NULL:
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_empty_tuple);
    __pyx_r = __pyx_empty_tuple;
    goto __pyx_L0;
  }

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":803
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):             # <<<<<<<<<<<<<<
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":809
 *         return ()
 * 
 * cdef inline char* _util_dtypestring(dtype descr, char* f, char* end, int* offset) except NULL:             # <<<<<<<<<<<<<<
 *     # Recursive utility function used in __getbuffer__ to get format
 *     # string. The new location in the format string is returned.
 */

static CYTHON_INLINE char *__pyx_f_5numpy__util_dtypestring(PyArray_Descr *__pyx_v_descr, char *__pyx_v_f, char *__pyx_v_end, int *__pyx_v_offset) {
  PyArray_Descr *__pyx_v_child = 0;
  int __pyx_v_endian_detector;
  int __pyx_v_little_endian;
  PyObject *__pyx_v_fields = 0;
  PyObject *__pyx_v_childname = NULL;
  PyObject *__pyx_v_new_offset = NULL;
  PyObject *__pyx_v_t = NULL;
  char *__pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  long __pyx_t_8;
  char *__pyx_t_9;
  __Pyx_RefNannySetupContext("_util_dtypestring", 0);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":814
 * 
 *     cdef dtype child
 *     cdef int endian_detector = 1             # <<<<<<<<<<<<<<
 *     cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)
 *     cdef tuple fields
 */
  __pyx_v_endian_detector = 1;

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":815
 *     cdef dtype child
 *     cdef int endian_detector = 1
 *     cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)             # <<<<<<<<<<<<<<
 *     cdef tuple fields
 * 
 */
  __pyx_v_little_endian = ((((char *)(&__pyx_v_endian_detector))[0]) != 0);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":818
 *     cdef tuple fields
 * 
 *     for childname in descr.names:             # <<<<<<<<<<<<<<
 *         fields = descr.fields[childname]
 *         child, new_offset = fields
 */
  if (unlikely(__pyx_v_descr->names == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(2, 818, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_descr->names; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(2, 818, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 818, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_childname, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":819
 * 
 *     for childname in descr.names:
 *         fields = descr.fields[childname]             # <<<<<<<<<<<<<<
 *         child, new_offset = fields
 * 
 */
    if (unlikely(__pyx_v_descr->fields == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(2, 819, __pyx_L1_error)
    }
    __pyx_t_3 = __Pyx_PyDict_GetItem(__pyx_v_descr->fields, __pyx_v_childname); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 819, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (!(likely(PyTuple_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_t_3)->tp_name), 0))) __PYX_ERR(2, 819, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_fields, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":820
 *     for childname in descr.names:
 *         fields = descr.fields[childname]
 *         child, new_offset = fields             # <<<<<<<<<<<<<<
 * 
 *         if (end - f) - <int>(new_offset - offset[0]) < 15:
 */
    if (likely(__pyx_v_fields != Py_None)) {
      PyObject* sequence = __pyx_v_fields;
      #if !CYTHON_COMPILING_IN_PYPY
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(2, 820, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      #else
      __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 820, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 820, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      #endif
    } else {
      __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(2, 820, __pyx_L1_error)
    }
    if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_dtype))))) __PYX_ERR(2, 820, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_child, ((PyArray_Descr *)__pyx_t_3));
    __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_new_offset, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":822
 *         child, new_offset = fields
 * 
 *         if (end - f) - <int>(new_offset - offset[0]) < 15:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 */
    __pyx_t_4 = __Pyx_PyInt_From_int((__pyx_v_offset[0])); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 822, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyNumber_Subtract(__pyx_v_new_offset, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 822, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_3); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 822, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = ((((__pyx_v_end - __pyx_v_f) - ((int)__pyx_t_5)) < 15) != 0);
    if (__pyx_t_6) {

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":823
 * 
 *         if (end - f) - <int>(new_offset - offset[0]) < 15:
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")             # <<<<<<<<<<<<<<
 * 
 *         if ((child.byteorder == c'>' and little_endian) or
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 823, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(2, 823, __pyx_L1_error)

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":822
 *         child, new_offset = fields
 * 
 *         if (end - f) - <int>(new_offset - offset[0]) < 15:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 */
    }

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":825
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 *         if ((child.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")
 */
    __pyx_t_7 = ((__pyx_v_child->byteorder == '>') != 0);
    if (!__pyx_t_7) {
      goto __pyx_L8_next_or;
    } else {
    }
    __pyx_t_7 = (__pyx_v_little_endian != 0);
    if (!__pyx_t_7) {
    } else {
      __pyx_t_6 = __pyx_t_7;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_L8_next_or:;

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":826
 * 
 *         if ((child.byteorder == c'>' and little_endian) or
 *             (child.byteorder == c'<' and not little_endian)):             # <<<<<<<<<<<<<<
 *             raise ValueError(u"Non-native byte order not supported")
 *             # One could encode it in the format string and have Cython
 */
    __pyx_t_7 = ((__pyx_v_child->byteorder == '<') != 0);
    if (__pyx_t_7) {
    } else {
      __pyx_t_6 = __pyx_t_7;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_7 = ((!(__pyx_v_little_endian != 0)) != 0);
    __pyx_t_6 = __pyx_t_7;
    __pyx_L7_bool_binop_done:;

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":825
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 *         if ((child.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")
 */
    if (__pyx_t_6) {

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":827
 *         if ((child.byteorder == c'>' and little_endian) or
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *             # One could encode it in the format string and have Cython
 *             # complain instead, BUT: < and > in format strings also imply
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__8, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 827, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(2, 827, __pyx_L1_error)

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":825
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 *         if ((child.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")
 */
    }

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":837
 * 
 *         # Output padding bytes
 *         while offset[0] < new_offset:             # <<<<<<<<<<<<<<
 *             f[0] = 120 # "x"; pad byte
 *             f += 1
 */
    while (1) {
      __pyx_t_3 = __Pyx_PyInt_From_int((__pyx_v_offset[0])); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_t_3, __pyx_v_new_offset, Py_LT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 837, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 837, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (!__pyx_t_6) break;

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":838
 *         # Output padding bytes
 *         while offset[0] < new_offset:
 *             f[0] = 120 # "x"; pad byte             # <<<<<<<<<<<<<<
 *             f += 1
 *             offset[0] += 1
 */
      (__pyx_v_f[0]) = 0x78;

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":839
 *         while offset[0] < new_offset:
 *             f[0] = 120 # "x"; pad byte
 *             f += 1             # <<<<<<<<<<<<<<
 *             offset[0] += 1
 * 
 */
      __pyx_v_f = (__pyx_v_f + 1);

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":840
 *             f[0] = 120 # "x"; pad byte
 *             f += 1
 *             offset[0] += 1             # <<<<<<<<<<<<<<
 * 
 *         offset[0] += child.itemsize
 */
      __pyx_t_8 = 0;
      (__pyx_v_offset[__pyx_t_8]) = ((__pyx_v_offset[__pyx_t_8]) + 1);
    }

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":842
 *             offset[0] += 1
 * 
 *         offset[0] += child.itemsize             # <<<<<<<<<<<<<<
 * 
 *         if not PyDataType_HASFIELDS(child):
 */
    __pyx_t_8 = 0;
    (__pyx_v_offset[__pyx_t_8]) = ((__pyx_v_offset[__pyx_t_8]) + __pyx_v_child->elsize);

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":844
 *         offset[0] += child.itemsize
 * 
 *         if not PyDataType_HASFIELDS(child):             # <<<<<<<<<<<<<<
 *             t = child.type_num
 *             if end - f < 5:
 */
    __pyx_t_6 = ((!(PyDataType_HASFIELDS(__pyx_v_child) != 0)) != 0);
    if (__pyx_t_6) {

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":845
 * 
 *         if not PyDataType_HASFIELDS(child):
 *             t = child.type_num             # <<<<<<<<<<<<<<
 *             if end - f < 5:
 *                 raise RuntimeError(u"Format string allocated too short.")
 */
      __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_child->type_num); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 845, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_XDECREF_SET(__pyx_v_t, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":846
 *         if not PyDataType_HASFIELDS(child):
 *             t = child.type_num
 *             if end - f < 5:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(u"Format string allocated too short.")
 * 
 */
      __pyx_t_6 = (((__pyx_v_end - __pyx_v_f) < 5) != 0);
      if (__pyx_t_6) {

        /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":847
 *             t = child.type_num
 *             if end - f < 5:
 *                 raise RuntimeError(u"Format string allocated too short.")             # <<<<<<<<<<<<<<
 * 
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 */
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__9, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 847, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_Raise(__pyx_t_4, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(2, 847, __pyx_L1_error)

        /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":846
 *         if not PyDataType_HASFIELDS(child):
 *             t = child.type_num
 *             if end - f < 5:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(u"Format string allocated too short.")
 * 
 */
      }

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":850
 * 
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 *             if   t == NPY_BYTE:        f[0] =  98 #"b"             # <<<<<<<<<<<<<<
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_BYTE); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 850, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 850, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 850, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 98;
        goto __pyx_L15;
      }

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":851
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 *             if   t == NPY_BYTE:        f[0] =  98 #"b"
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"             # <<<<<<<<<<<<<<
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_UBYTE); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 851, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 851, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 851, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 66;
        goto __pyx_L15;
      }

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":852
 *             if   t == NPY_BYTE:        f[0] =  98 #"b"
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"             # <<<<<<<<<<<<<<
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_SHORT); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 852, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 852, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 852, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x68;
        goto __pyx_L15;
      }

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":853
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"             # <<<<<<<<<<<<<<
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_USHORT); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 853, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 853, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 853, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 72;
        goto __pyx_L15;
      }

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":854
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 *             elif t == NPY_INT:         f[0] = 105 #"i"             # <<<<<<<<<<<<<<
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_INT); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 854, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 854, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 854, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x69;
        goto __pyx_L15;
      }

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":855
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 *             elif t == NPY_UINT:        f[0] =  73 #"I"             # <<<<<<<<<<<<<<
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_UINT); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 855, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 855, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 855, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 73;
        goto __pyx_L15;
      }

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":856
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 *             elif t == NPY_LONG:        f[0] = 108 #"l"             # <<<<<<<<<<<<<<
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_LONG); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 856, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 856, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 856, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x6C;
        goto __pyx_L15;
      }

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":857
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"             # <<<<<<<<<<<<<<
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_ULONG); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 857, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 857, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 857, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 76;
        goto __pyx_L15;
      }

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":858
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"             # <<<<<<<<<<<<<<
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_LONGLONG); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 858, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 858, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 858, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x71;
        goto __pyx_L15;
      }

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":859
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"             # <<<<<<<<<<<<<<
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_ULONGLONG); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 859, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 859, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 859, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 81;
        goto __pyx_L15;
      }

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":860
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"             # <<<<<<<<<<<<<<
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_FLOAT); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 860, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 860, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 860, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x66;
        goto __pyx_L15;
      }

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":861
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"             # <<<<<<<<<<<<<<
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_DOUBLE); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 861, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 861, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 861, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x64;
        goto __pyx_L15;
      }

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":862
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"             # <<<<<<<<<<<<<<
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_LONGDOUBLE); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 862, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 862, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 862, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x67;
        goto __pyx_L15;
      }

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":863
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf             # <<<<<<<<<<<<<<
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_CFLOAT); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 863, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 863, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 863, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 90;
        (__pyx_v_f[1]) = 0x66;
        __pyx_v_f = (__pyx_v_f + 1);
        goto __pyx_L15;
      }

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":864
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd             # <<<<<<<<<<<<<<
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_CDOUBLE); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 864, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 864, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 864, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 90;
        (__pyx_v_f[1]) = 0x64;
        __pyx_v_f = (__pyx_v_f + 1);
        goto __pyx_L15;
      }

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":865
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg             # <<<<<<<<<<<<<<
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"
 *             else:
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_CLONGDOUBLE); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 865, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 865, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 865, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 90;
        (__pyx_v_f[1]) = 0x67;
        __pyx_v_f = (__pyx_v_f + 1);
        goto __pyx_L15;
      }

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":866
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"             # <<<<<<<<<<<<<<
 *             else:
 *                 raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_OBJECT); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 866, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 866, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 866, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 79;
        goto __pyx_L15;
      }

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":868
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"
 *             else:
 *                 raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)             # <<<<<<<<<<<<<<
 *             f += 1
 *         else:
 */
      /*else*/ {
        __pyx_t_3 = PyUnicode_Format(__pyx_kp_u_unknown_dtype_code_in_numpy_pxd, __pyx_v_t); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 868, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 868, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_3);
        PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
        __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 868, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __PYX_ERR(2, 868, __pyx_L1_error)
      }
      __pyx_L15:;

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":869
 *             else:
 *                 raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 *             f += 1             # <<<<<<<<<<<<<<
 *         else:
 *             # Cython ignores struct boundary information ("T{...}"),
 */
      __pyx_v_f = (__pyx_v_f + 1);

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":844
 *         offset[0] += child.itemsize
 * 
 *         if not PyDataType_HASFIELDS(child):             # <<<<<<<<<<<<<<
 *             t = child.type_num
 *             if end - f < 5:
 */
      goto __pyx_L13;
    }

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":873
 *             # Cython ignores struct boundary information ("T{...}"),
 *             # so don't output it
 *             f = _util_dtypestring(child, f, end, offset)             # <<<<<<<<<<<<<<
 *     return f
 * 
 */
    /*else*/ {
      __pyx_t_9 = __pyx_f_5numpy__util_dtypestring(__pyx_v_child, __pyx_v_f, __pyx_v_end, __pyx_v_offset); if (unlikely(__pyx_t_9 == ((char *)NULL))) __PYX_ERR(2, 873, __pyx_L1_error)
      __pyx_v_f = __pyx_t_9;
    }
    __pyx_L13:;

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":818
 *     cdef tuple fields
 * 
 *     for childname in descr.names:             # <<<<<<<<<<<<<<
 *         fields = descr.fields[childname]
 *         child, new_offset = fields
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":874
 *             # so don't output it
 *             f = _util_dtypestring(child, f, end, offset)
 *     return f             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_f;
  goto __pyx_L0;

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":809
 *         return ()
 * 
 * cdef inline char* _util_dtypestring(dtype descr, char* f, char* end, int* offset) except NULL:             # <<<<<<<<<<<<<<
 *     # Recursive utility function used in __getbuffer__ to get format
 *     # string. The new location in the format string is returned.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("numpy._util_dtypestring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_child);
  __Pyx_XDECREF(__pyx_v_fields);
  __Pyx_XDECREF(__pyx_v_childname);
  __Pyx_XDECREF(__pyx_v_new_offset);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":990
 * 
 * 
 * cdef inline void set_array_base(ndarray arr, object base):             # <<<<<<<<<<<<<<
 *      cdef PyObject* baseptr
 *      if base is None:
 */

static CYTHON_INLINE void __pyx_f_5numpy_set_array_base(PyArrayObject *__pyx_v_arr, PyObject *__pyx_v_base) {
  PyObject *__pyx_v_baseptr;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("set_array_base", 0);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":992
 * cdef inline void set_array_base(ndarray arr, object base):
 *      cdef PyObject* baseptr
 *      if base is None:             # <<<<<<<<<<<<<<
 *          baseptr = NULL
 *      else:
 */
  __pyx_t_1 = (__pyx_v_base == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":993
 *      cdef PyObject* baseptr
 *      if base is None:
 *          baseptr = NULL             # <<<<<<<<<<<<<<
 *      else:
 *          Py_INCREF(base) # important to do this before decref below!
 */
    __pyx_v_baseptr = NULL;

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":992
 * cdef inline void set_array_base(ndarray arr, object base):
 *      cdef PyObject* baseptr
 *      if base is None:             # <<<<<<<<<<<<<<
 *          baseptr = NULL
 *      else:
 */
    goto __pyx_L3;
  }

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":995
 *          baseptr = NULL
 *      else:
 *          Py_INCREF(base) # important to do this before decref below!             # <<<<<<<<<<<<<<
 *          baseptr = <PyObject*>base
 *      Py_XDECREF(arr.base)
 */
  /*else*/ {
    Py_INCREF(__pyx_v_base);

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":996
 *      else:
 *          Py_INCREF(base) # important to do this before decref below!
 *          baseptr = <PyObject*>base             # <<<<<<<<<<<<<<
 *      Py_XDECREF(arr.base)
 *      arr.base = baseptr
 */
    __pyx_v_baseptr = ((PyObject *)__pyx_v_base);
  }
  __pyx_L3:;

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":997
 *          Py_INCREF(base) # important to do this before decref below!
 *          baseptr = <PyObject*>base
 *      Py_XDECREF(arr.base)             # <<<<<<<<<<<<<<
 *      arr.base = baseptr
 * 
 */
  Py_XDECREF(__pyx_v_arr->base);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":998
 *          baseptr = <PyObject*>base
 *      Py_XDECREF(arr.base)
 *      arr.base = baseptr             # <<<<<<<<<<<<<<
 * 
 * cdef inline object get_array_base(ndarray arr):
 */
  __pyx_v_arr->base = __pyx_v_baseptr;

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":990
 * 
 * 
 * cdef inline void set_array_base(ndarray arr, object base):             # <<<<<<<<<<<<<<
 *      cdef PyObject* baseptr
 *      if base is None:
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1000
 *      arr.base = baseptr
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     if arr.base is NULL:
 *         return None
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_get_array_base(PyArrayObject *__pyx_v_arr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("get_array_base", 0);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1001
 * 
 * cdef inline object get_array_base(ndarray arr):
 *     if arr.base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     else:
 */
  __pyx_t_1 = ((__pyx_v_arr->base == NULL) != 0);
  if (__pyx_t_1) {

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1002
 * cdef inline object get_array_base(ndarray arr):
 *     if arr.base is NULL:
 *         return None             # <<<<<<<<<<<<<<
 *     else:
 *         return <object>arr.base
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1001
 * 
 * cdef inline object get_array_base(ndarray arr):
 *     if arr.base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     else:
 */
  }

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1004
 *         return None
 *     else:
 *         return <object>arr.base             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject *)__pyx_v_arr->base));
    __pyx_r = ((PyObject *)__pyx_v_arr->base);
    goto __pyx_L0;
  }

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1000
 *      arr.base = baseptr
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     if arr.base is NULL:
 *         return None
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1009
 * # Versions of the import_* functions which are more suitable for
 * # Cython code.
 * cdef inline int import_array() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_array()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_array(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("import_array", 0);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1010
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_array()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1011
 * cdef inline int import_array() except -1:
 *     try:
 *         _import_array()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")
 */
      __pyx_t_4 = _import_array(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(2, 1011, __pyx_L3_error)

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1010
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_array()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1012
 *     try:
 *         _import_array()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(2, 1012, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1013
 *         _import_array()
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_umath() except -1:
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__10, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1013, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(2, 1013, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1010
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_array()
 *     except Exception:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1009
 * # Versions of the import_* functions which are more suitable for
 * # Cython code.
 * cdef inline int import_array() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_array()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1015
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 * cdef inline int import_umath() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_umath(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("import_umath", 0);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1016
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1017
 * cdef inline int import_umath() except -1:
 *     try:
 *         _import_umath()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")
 */
      __pyx_t_4 = _import_umath(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(2, 1017, __pyx_L3_error)

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1016
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1018
 *     try:
 *         _import_umath()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_umath", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(2, 1018, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1019
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_ufunc() except -1:
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1019, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(2, 1019, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1016
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1015
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 * cdef inline int import_umath() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_umath", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1021
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 * cdef inline int import_ufunc() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_ufunc(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("import_ufunc", 0);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1022
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1023
 * cdef inline int import_ufunc() except -1:
 *     try:
 *         _import_umath()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")
 */
      __pyx_t_4 = _import_umath(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(2, 1023, __pyx_L3_error)

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1022
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1024
 *     try:
 *         _import_umath()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.umath failed to import")
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_ufunc", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(2, 1024, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1025
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1025, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(2, 1025, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1022
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1021
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 * cdef inline int import_ufunc() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_ufunc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yt/utilities/lib/fp_utils.pxd":19
 * cimport cython
 * 
 * cdef inline np.int64_t imax(np.int64_t i0, np.int64_t i1) nogil:             # <<<<<<<<<<<<<<
 *     if i0 > i1: return i0
 *     return i1
 */

static CYTHON_INLINE __pyx_t_5numpy_int64_t __pyx_f_2yt_9utilities_3lib_8fp_utils_imax(__pyx_t_5numpy_int64_t __pyx_v_i0, __pyx_t_5numpy_int64_t __pyx_v_i1) {
  __pyx_t_5numpy_int64_t __pyx_r;
  int __pyx_t_1;

  /* "yt/utilities/lib/fp_utils.pxd":20
 * 
 * cdef inline np.int64_t imax(np.int64_t i0, np.int64_t i1) nogil:
 *     if i0 > i1: return i0             # <<<<<<<<<<<<<<
 *     return i1
 * 
 */
  __pyx_t_1 = ((__pyx_v_i0 > __pyx_v_i1) != 0);
  if (__pyx_t_1) {
    __pyx_r = __pyx_v_i0;
    goto __pyx_L0;
  }

  /* "yt/utilities/lib/fp_utils.pxd":21
 * cdef inline np.int64_t imax(np.int64_t i0, np.int64_t i1) nogil:
 *     if i0 > i1: return i0
 *     return i1             # <<<<<<<<<<<<<<
 * 
 * cdef inline np.float64_t fmax(np.float64_t f0, np.float64_t f1) nogil:
 */
  __pyx_r = __pyx_v_i1;
  goto __pyx_L0;

  /* "yt/utilities/lib/fp_utils.pxd":19
 * cimport cython
 * 
 * cdef inline np.int64_t imax(np.int64_t i0, np.int64_t i1) nogil:             # <<<<<<<<<<<<<<
 *     if i0 > i1: return i0
 *     return i1
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "yt/utilities/lib/fp_utils.pxd":23
 *     return i1
 * 
 * cdef inline np.float64_t fmax(np.float64_t f0, np.float64_t f1) nogil:             # <<<<<<<<<<<<<<
 *     if f0 > f1: return f0
 *     return f1
 */

static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_2yt_9utilities_3lib_8fp_utils_fmax(__pyx_t_5numpy_float64_t __pyx_v_f0, __pyx_t_5numpy_float64_t __pyx_v_f1) {
  __pyx_t_5numpy_float64_t __pyx_r;
  int __pyx_t_1;

  /* "yt/utilities/lib/fp_utils.pxd":24
 * 
 * cdef inline np.float64_t fmax(np.float64_t f0, np.float64_t f1) nogil:
 *     if f0 > f1: return f0             # <<<<<<<<<<<<<<
 *     return f1
 * 
 */
  __pyx_t_1 = ((__pyx_v_f0 > __pyx_v_f1) != 0);
  if (__pyx_t_1) {
    __pyx_r = __pyx_v_f0;
    goto __pyx_L0;
  }

  /* "yt/utilities/lib/fp_utils.pxd":25
 * cdef inline np.float64_t fmax(np.float64_t f0, np.float64_t f1) nogil:
 *     if f0 > f1: return f0
 *     return f1             # <<<<<<<<<<<<<<
 * 
 * cdef inline np.int64_t imin(np.int64_t i0, np.int64_t i1) nogil:
 */
  __pyx_r = __pyx_v_f1;
  goto __pyx_L0;

  /* "yt/utilities/lib/fp_utils.pxd":23
 *     return i1
 * 
 * cdef inline np.float64_t fmax(np.float64_t f0, np.float64_t f1) nogil:             # <<<<<<<<<<<<<<
 *     if f0 > f1: return f0
 *     return f1
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "yt/utilities/lib/fp_utils.pxd":27
 *     return f1
 * 
 * cdef inline np.int64_t imin(np.int64_t i0, np.int64_t i1) nogil:             # <<<<<<<<<<<<<<
 *     if i0 < i1: return i0
 *     return i1
 */

static CYTHON_INLINE __pyx_t_5numpy_int64_t __pyx_f_2yt_9utilities_3lib_8fp_utils_imin(__pyx_t_5numpy_int64_t __pyx_v_i0, __pyx_t_5numpy_int64_t __pyx_v_i1) {
  __pyx_t_5numpy_int64_t __pyx_r;
  int __pyx_t_1;

  /* "yt/utilities/lib/fp_utils.pxd":28
 * 
 * cdef inline np.int64_t imin(np.int64_t i0, np.int64_t i1) nogil:
 *     if i0 < i1: return i0             # <<<<<<<<<<<<<<
 *     return i1
 * 
 */
  __pyx_t_1 = ((__pyx_v_i0 < __pyx_v_i1) != 0);
  if (__pyx_t_1) {
    __pyx_r = __pyx_v_i0;
    goto __pyx_L0;
  }

  /* "yt/utilities/lib/fp_utils.pxd":29
 * cdef inline np.int64_t imin(np.int64_t i0, np.int64_t i1) nogil:
 *     if i0 < i1: return i0
 *     return i1             # <<<<<<<<<<<<<<
 * 
 * cdef inline np.float64_t fmin(np.float64_t f0, np.float64_t f1) nogil:
 */
  __pyx_r = __pyx_v_i1;
  goto __pyx_L0;

  /* "yt/utilities/lib/fp_utils.pxd":27
 *     return f1
 * 
 * cdef inline np.int64_t imin(np.int64_t i0, np.int64_t i1) nogil:             # <<<<<<<<<<<<<<
 *     if i0 < i1: return i0
 *     return i1
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "yt/utilities/lib/fp_utils.pxd":31
 *     return i1
 * 
 * cdef inline np.float64_t fmin(np.float64_t f0, np.float64_t f1) nogil:             # <<<<<<<<<<<<<<
 *     if f0 < f1: return f0
 *     return f1
 */

static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_2yt_9utilities_3lib_8fp_utils_fmin(__pyx_t_5numpy_float64_t __pyx_v_f0, __pyx_t_5numpy_float64_t __pyx_v_f1) {
  __pyx_t_5numpy_float64_t __pyx_r;
  int __pyx_t_1;

  /* "yt/utilities/lib/fp_utils.pxd":32
 * 
 * cdef inline np.float64_t fmin(np.float64_t f0, np.float64_t f1) nogil:
 *     if f0 < f1: return f0             # <<<<<<<<<<<<<<
 *     return f1
 * 
 */
  __pyx_t_1 = ((__pyx_v_f0 < __pyx_v_f1) != 0);
  if (__pyx_t_1) {
    __pyx_r = __pyx_v_f0;
    goto __pyx_L0;
  }

  /* "yt/utilities/lib/fp_utils.pxd":33
 * cdef inline np.float64_t fmin(np.float64_t f0, np.float64_t f1) nogil:
 *     if f0 < f1: return f0
 *     return f1             # <<<<<<<<<<<<<<
 * 
 * cdef inline np.float64_t fabs(np.float64_t f0) nogil:
 */
  __pyx_r = __pyx_v_f1;
  goto __pyx_L0;

  /* "yt/utilities/lib/fp_utils.pxd":31
 *     return i1
 * 
 * cdef inline np.float64_t fmin(np.float64_t f0, np.float64_t f1) nogil:             # <<<<<<<<<<<<<<
 *     if f0 < f1: return f0
 *     return f1
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "yt/utilities/lib/fp_utils.pxd":35
 *     return f1
 * 
 * cdef inline np.float64_t fabs(np.float64_t f0) nogil:             # <<<<<<<<<<<<<<
 *     if f0 < 0.0: return -f0
 *     return f0
 */

static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_2yt_9utilities_3lib_8fp_utils_fabs(__pyx_t_5numpy_float64_t __pyx_v_f0) {
  __pyx_t_5numpy_float64_t __pyx_r;
  int __pyx_t_1;

  /* "yt/utilities/lib/fp_utils.pxd":36
 * 
 * cdef inline np.float64_t fabs(np.float64_t f0) nogil:
 *     if f0 < 0.0: return -f0             # <<<<<<<<<<<<<<
 *     return f0
 * 
 */
  __pyx_t_1 = ((__pyx_v_f0 < 0.0) != 0);
  if (__pyx_t_1) {
    __pyx_r = (-__pyx_v_f0);
    goto __pyx_L0;
  }

  /* "yt/utilities/lib/fp_utils.pxd":37
 * cdef inline np.float64_t fabs(np.float64_t f0) nogil:
 *     if f0 < 0.0: return -f0
 *     return f0             # <<<<<<<<<<<<<<
 * 
 * cdef inline np.int64_t iclip(np.int64_t i, np.int64_t a, np.int64_t b) nogil:
 */
  __pyx_r = __pyx_v_f0;
  goto __pyx_L0;

  /* "yt/utilities/lib/fp_utils.pxd":35
 *     return f1
 * 
 * cdef inline np.float64_t fabs(np.float64_t f0) nogil:             # <<<<<<<<<<<<<<
 *     if f0 < 0.0: return -f0
 *     return f0
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "yt/utilities/lib/fp_utils.pxd":39
 *     return f0
 * 
 * cdef inline np.int64_t iclip(np.int64_t i, np.int64_t a, np.int64_t b) nogil:             # <<<<<<<<<<<<<<
 *     if i < a: return a
 *     if i > b: return b
 */

static CYTHON_INLINE __pyx_t_5numpy_int64_t __pyx_f_2yt_9utilities_3lib_8fp_utils_iclip(__pyx_t_5numpy_int64_t __pyx_v_i, __pyx_t_5numpy_int64_t __pyx_v_a, __pyx_t_5numpy_int64_t __pyx_v_b) {
  __pyx_t_5numpy_int64_t __pyx_r;
  int __pyx_t_1;

  /* "yt/utilities/lib/fp_utils.pxd":40
 * 
 * cdef inline np.int64_t iclip(np.int64_t i, np.int64_t a, np.int64_t b) nogil:
 *     if i < a: return a             # <<<<<<<<<<<<<<
 *     if i > b: return b
 *     return i
 */
  __pyx_t_1 = ((__pyx_v_i < __pyx_v_a) != 0);
  if (__pyx_t_1) {
    __pyx_r = __pyx_v_a;
    goto __pyx_L0;
  }

  /* "yt/utilities/lib/fp_utils.pxd":41
 * cdef inline np.int64_t iclip(np.int64_t i, np.int64_t a, np.int64_t b) nogil:
 *     if i < a: return a
 *     if i > b: return b             # <<<<<<<<<<<<<<
 *     return i
 * 
 */
  __pyx_t_1 = ((__pyx_v_i > __pyx_v_b) != 0);
  if (__pyx_t_1) {
    __pyx_r = __pyx_v_b;
    goto __pyx_L0;
  }

  /* "yt/utilities/lib/fp_utils.pxd":42
 *     if i < a: return a
 *     if i > b: return b
 *     return i             # <<<<<<<<<<<<<<
 * 
 * cdef inline np.int64_t i64clip(np.int64_t i, np.int64_t a, np.int64_t b) nogil:
 */
  __pyx_r = __pyx_v_i;
  goto __pyx_L0;

  /* "yt/utilities/lib/fp_utils.pxd":39
 *     return f0
 * 
 * cdef inline np.int64_t iclip(np.int64_t i, np.int64_t a, np.int64_t b) nogil:             # <<<<<<<<<<<<<<
 *     if i < a: return a
 *     if i > b: return b
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "yt/utilities/lib/fp_utils.pxd":44
 *     return i
 * 
 * cdef inline np.int64_t i64clip(np.int64_t i, np.int64_t a, np.int64_t b) nogil:             # <<<<<<<<<<<<<<
 *     if i < a: return a
 *     if i > b: return b
 */

static CYTHON_INLINE __pyx_t_5numpy_int64_t __pyx_f_2yt_9utilities_3lib_8fp_utils_i64clip(__pyx_t_5numpy_int64_t __pyx_v_i, __pyx_t_5numpy_int64_t __pyx_v_a, __pyx_t_5numpy_int64_t __pyx_v_b) {
  __pyx_t_5numpy_int64_t __pyx_r;
  int __pyx_t_1;

  /* "yt/utilities/lib/fp_utils.pxd":45
 * 
 * cdef inline np.int64_t i64clip(np.int64_t i, np.int64_t a, np.int64_t b) nogil:
 *     if i < a: return a             # <<<<<<<<<<<<<<
 *     if i > b: return b
 *     return i
 */
  __pyx_t_1 = ((__pyx_v_i < __pyx_v_a) != 0);
  if (__pyx_t_1) {
    __pyx_r = __pyx_v_a;
    goto __pyx_L0;
  }

  /* "yt/utilities/lib/fp_utils.pxd":46
 * cdef inline np.int64_t i64clip(np.int64_t i, np.int64_t a, np.int64_t b) nogil:
 *     if i < a: return a
 *     if i > b: return b             # <<<<<<<<<<<<<<
 *     return i
 * 
 */
  __pyx_t_1 = ((__pyx_v_i > __pyx_v_b) != 0);
  if (__pyx_t_1) {
    __pyx_r = __pyx_v_b;
    goto __pyx_L0;
  }

  /* "yt/utilities/lib/fp_utils.pxd":47
 *     if i < a: return a
 *     if i > b: return b
 *     return i             # <<<<<<<<<<<<<<
 * 
 * cdef inline np.float64_t fclip(np.float64_t f,
 */
  __pyx_r = __pyx_v_i;
  goto __pyx_L0;

  /* "yt/utilities/lib/fp_utils.pxd":44
 *     return i
 * 
 * cdef inline np.int64_t i64clip(np.int64_t i, np.int64_t a, np.int64_t b) nogil:             # <<<<<<<<<<<<<<
 *     if i < a: return a
 *     if i > b: return b
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "yt/utilities/lib/fp_utils.pxd":49
 *     return i
 * 
 * cdef inline np.float64_t fclip(np.float64_t f,             # <<<<<<<<<<<<<<
 *                       np.float64_t a, np.float64_t b) nogil:
 *     return fmin(fmax(f, a), b)
 */

static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_2yt_9utilities_3lib_8fp_utils_fclip(__pyx_t_5numpy_float64_t __pyx_v_f, __pyx_t_5numpy_float64_t __pyx_v_a, __pyx_t_5numpy_float64_t __pyx_v_b) {
  __pyx_t_5numpy_float64_t __pyx_r;

  /* "yt/utilities/lib/fp_utils.pxd":51
 * cdef inline np.float64_t fclip(np.float64_t f,
 *                       np.float64_t a, np.float64_t b) nogil:
 *     return fmin(fmax(f, a), b)             # <<<<<<<<<<<<<<
 * 
 * cdef inline np.int64_t i64max(np.int64_t i0, np.int64_t i1) nogil:
 */
  __pyx_r = __pyx_f_2yt_9utilities_3lib_8fp_utils_fmin(__pyx_f_2yt_9utilities_3lib_8fp_utils_fmax(__pyx_v_f, __pyx_v_a), __pyx_v_b);
  goto __pyx_L0;

  /* "yt/utilities/lib/fp_utils.pxd":49
 *     return i
 * 
 * cdef inline np.float64_t fclip(np.float64_t f,             # <<<<<<<<<<<<<<
 *                       np.float64_t a, np.float64_t b) nogil:
 *     return fmin(fmax(f, a), b)
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "yt/utilities/lib/fp_utils.pxd":53
 *     return fmin(fmax(f, a), b)
 * 
 * cdef inline np.int64_t i64max(np.int64_t i0, np.int64_t i1) nogil:             # <<<<<<<<<<<<<<
 *     if i0 > i1: return i0
 *     return i1
 */

static CYTHON_INLINE __pyx_t_5numpy_int64_t __pyx_f_2yt_9utilities_3lib_8fp_utils_i64max(__pyx_t_5numpy_int64_t __pyx_v_i0, __pyx_t_5numpy_int64_t __pyx_v_i1) {
  __pyx_t_5numpy_int64_t __pyx_r;
  int __pyx_t_1;

  /* "yt/utilities/lib/fp_utils.pxd":54
 * 
 * cdef inline np.int64_t i64max(np.int64_t i0, np.int64_t i1) nogil:
 *     if i0 > i1: return i0             # <<<<<<<<<<<<<<
 *     return i1
 * 
 */
  __pyx_t_1 = ((__pyx_v_i0 > __pyx_v_i1) != 0);
  if (__pyx_t_1) {
    __pyx_r = __pyx_v_i0;
    goto __pyx_L0;
  }

  /* "yt/utilities/lib/fp_utils.pxd":55
 * cdef inline np.int64_t i64max(np.int64_t i0, np.int64_t i1) nogil:
 *     if i0 > i1: return i0
 *     return i1             # <<<<<<<<<<<<<<
 * 
 * cdef inline np.int64_t i64min(np.int64_t i0, np.int64_t i1) nogil:
 */
  __pyx_r = __pyx_v_i1;
  goto __pyx_L0;

  /* "yt/utilities/lib/fp_utils.pxd":53
 *     return fmin(fmax(f, a), b)
 * 
 * cdef inline np.int64_t i64max(np.int64_t i0, np.int64_t i1) nogil:             # <<<<<<<<<<<<<<
 *     if i0 > i1: return i0
 *     return i1
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "yt/utilities/lib/fp_utils.pxd":57
 *     return i1
 * 
 * cdef inline np.int64_t i64min(np.int64_t i0, np.int64_t i1) nogil:             # <<<<<<<<<<<<<<
 *     if i0 < i1: return i0
 *     return i1
 */

static CYTHON_INLINE __pyx_t_5numpy_int64_t __pyx_f_2yt_9utilities_3lib_8fp_utils_i64min(__pyx_t_5numpy_int64_t __pyx_v_i0, __pyx_t_5numpy_int64_t __pyx_v_i1) {
  __pyx_t_5numpy_int64_t __pyx_r;
  int __pyx_t_1;

  /* "yt/utilities/lib/fp_utils.pxd":58
 * 
 * cdef inline np.int64_t i64min(np.int64_t i0, np.int64_t i1) nogil:
 *     if i0 < i1: return i0             # <<<<<<<<<<<<<<
 *     return i1
 * 
 */
  __pyx_t_1 = ((__pyx_v_i0 < __pyx_v_i1) != 0);
  if (__pyx_t_1) {
    __pyx_r = __pyx_v_i0;
    goto __pyx_L0;
  }

  /* "yt/utilities/lib/fp_utils.pxd":59
 * cdef inline np.int64_t i64min(np.int64_t i0, np.int64_t i1) nogil:
 *     if i0 < i1: return i0
 *     return i1             # <<<<<<<<<<<<<<
 * 
 */
  __pyx_r = __pyx_v_i1;
  goto __pyx_L0;

  /* "yt/utilities/lib/fp_utils.pxd":57
 *     return i1
 * 
 * cdef inline np.int64_t i64min(np.int64_t i0, np.int64_t i1) nogil:             # <<<<<<<<<<<<<<
 *     if i0 < i1: return i0
 *     return i1
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}
static struct __pyx_vtabstruct_2yt_9utilities_3lib_12basic_octree_Octree __pyx_vtable_2yt_9utilities_3lib_12basic_octree_Octree;

static PyObject *__pyx_tp_new_2yt_9utilities_3lib_12basic_octree_Octree(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *)o);
  p->__pyx_vtab = __pyx_vtabptr_2yt_9utilities_3lib_12basic_octree_Octree;
  if (unlikely(__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_2yt_9utilities_3lib_12basic_octree_Octree(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    ++Py_REFCNT(o);
    __pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_15__dealloc__(o);
    --Py_REFCNT(o);
    PyErr_Restore(etype, eval, etb);
  }
  (*Py_TYPE(o)->tp_free)(o);
}

static PyMethodDef __pyx_methods_2yt_9utilities_3lib_12basic_octree_Octree[] = {
  {"add_array_to_tree", (PyCFunction)__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_3add_array_to_tree, METH_VARARGS|METH_KEYWORDS, 0},
  {"add_grid_to_tree", (PyCFunction)__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_5add_grid_to_tree, METH_VARARGS|METH_KEYWORDS, 0},
  {"get_all_from_level", (PyCFunction)__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_7get_all_from_level, METH_VARARGS|METH_KEYWORDS, 0},
  {"finalize", (PyCFunction)__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_9finalize, METH_VARARGS|METH_KEYWORDS, 0},
  {"find_binding_energy", (PyCFunction)__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_11find_binding_energy, METH_VARARGS|METH_KEYWORDS, __pyx_doc_2yt_9utilities_3lib_12basic_octree_6Octree_10find_binding_energy},
  {"print_all_nodes", (PyCFunction)__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_13print_all_nodes, METH_NOARGS, __pyx_doc_2yt_9utilities_3lib_12basic_octree_6Octree_12print_all_nodes},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_17__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_2yt_9utilities_3lib_12basic_octree_6Octree_19__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_2yt_9utilities_3lib_12basic_octree_Octree = {
  PyVarObject_HEAD_INIT(0, 0)
  "yt.utilities.lib.basic_octree.Octree", /*tp_name*/
  sizeof(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_2yt_9utilities_3lib_12basic_octree_Octree, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_2yt_9utilities_3lib_12basic_octree_Octree, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_2yt_9utilities_3lib_12basic_octree_Octree, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_basic_octree(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_basic_octree},
  {0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    "basic_octree",
    __pyx_k_A_refine_by_two_AMR_specific_oc, /* m_doc */
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    0, /* m_size */
  #else
    -1, /* m_size */
  #endif
    __pyx_methods /* m_methods */,
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    __pyx_moduledef_slots, /* m_slots */
  #else
    NULL, /* m_reload */
  #endif
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_s_, __pyx_k_, sizeof(__pyx_k_), 0, 0, 1, 0},
  {&__pyx_kp_s_1, __pyx_k_1, sizeof(__pyx_k_1), 0, 0, 1, 0},
  {&__pyx_kp_s_1_5e, __pyx_k_1_5e, sizeof(__pyx_k_1_5e), 0, 0, 1, 0},
  {&__pyx_kp_u_Format_string_allocated_too_shor, __pyx_k_Format_string_allocated_too_shor, sizeof(__pyx_k_Format_string_allocated_too_shor), 0, 1, 0, 0},
  {&__pyx_kp_u_Format_string_allocated_too_shor_2, __pyx_k_Format_string_allocated_too_shor_2, sizeof(__pyx_k_Format_string_allocated_too_shor_2), 0, 1, 0, 0},
  {&__pyx_kp_s_ID_next_up_n_level_x_y_z, __pyx_k_ID_next_up_n_level_x_y_z, sizeof(__pyx_k_ID_next_up_n_level_x_y_z), 0, 0, 1, 0},
  {&__pyx_n_s_ImportError, __pyx_k_ImportError, sizeof(__pyx_k_ImportError), 0, 0, 1, 1},
  {&__pyx_kp_u_Non_native_byte_order_not_suppor, __pyx_k_Non_native_byte_order_not_suppor, sizeof(__pyx_k_Non_native_byte_order_not_suppor), 0, 1, 0, 0},
  {&__pyx_kp_u_Octree_print_all_nodes_line_562, __pyx_k_Octree_print_all_nodes_line_562, sizeof(__pyx_k_Octree_print_all_nodes_line_562), 0, 1, 0, 0},
  {&__pyx_kp_u_Prints_out_information_about_al, __pyx_k_Prints_out_information_about_al, sizeof(__pyx_k_Prints_out_information_about_al), 0, 1, 0, 0},
  {&__pyx_n_s_RuntimeError, __pyx_k_RuntimeError, sizeof(__pyx_k_RuntimeError), 0, 0, 1, 1},
  {&__pyx_kp_s_Truncating, __pyx_k_Truncating, sizeof(__pyx_k_Truncating), 0, 0, 1, 0},
  {&__pyx_n_s_TypeError, __pyx_k_TypeError, sizeof(__pyx_k_TypeError), 0, 0, 1, 1},
  {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_cm, __pyx_k_cm, sizeof(__pyx_k_cm), 0, 0, 1, 1},
  {&__pyx_n_s_count_only, __pyx_k_count_only, sizeof(__pyx_k_count_only), 0, 0, 1, 1},
  {&__pyx_kp_s_d, __pyx_k_d, sizeof(__pyx_k_d), 0, 0, 1, 0},
  {&__pyx_kp_s_d_2, __pyx_k_d_2, sizeof(__pyx_k_d_2), 0, 0, 1, 0},
  {&__pyx_kp_s_d_d_d_d, __pyx_k_d_d_d_d, sizeof(__pyx_k_d_d_d_d), 0, 0, 1, 0},
  {&__pyx_n_s_dtype, __pyx_k_dtype, sizeof(__pyx_k_dtype), 0, 0, 1, 1},
  {&__pyx_n_s_end, __pyx_k_end, sizeof(__pyx_k_end), 0, 0, 1, 1},
  {&__pyx_kp_s_f, __pyx_k_f, sizeof(__pyx_k_f), 0, 0, 1, 0},
  {&__pyx_n_s_file, __pyx_k_file, sizeof(__pyx_k_file), 0, 0, 1, 1},
  {&__pyx_n_s_float64, __pyx_k_float64, sizeof(__pyx_k_float64), 0, 0, 1, 1},
  {&__pyx_n_s_flush, __pyx_k_flush, sizeof(__pyx_k_flush), 0, 0, 1, 1},
  {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_incremental, __pyx_k_incremental, sizeof(__pyx_k_incremental), 0, 0, 1, 1},
  {&__pyx_n_s_int64, __pyx_k_int64, sizeof(__pyx_k_int64), 0, 0, 1, 1},
  {&__pyx_n_s_kinetic, __pyx_k_kinetic, sizeof(__pyx_k_kinetic), 0, 0, 1, 1},
  {&__pyx_n_s_level, __pyx_k_level, sizeof(__pyx_k_level), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_kp_u_ndarray_is_not_C_contiguous, __pyx_k_ndarray_is_not_C_contiguous, sizeof(__pyx_k_ndarray_is_not_C_contiguous), 0, 1, 0, 0},
  {&__pyx_kp_u_ndarray_is_not_Fortran_contiguou, __pyx_k_ndarray_is_not_Fortran_contiguou, sizeof(__pyx_k_ndarray_is_not_Fortran_contiguou), 0, 1, 0, 0},
  {&__pyx_kp_s_no_default___reduce___due_to_non, __pyx_k_no_default___reduce___due_to_non, sizeof(__pyx_k_no_default___reduce___due_to_non), 0, 0, 1, 0},
  {&__pyx_n_s_np, __pyx_k_np, sizeof(__pyx_k_np), 0, 0, 1, 1},
  {&__pyx_n_s_numpy, __pyx_k_numpy, sizeof(__pyx_k_numpy), 0, 0, 1, 1},
  {&__pyx_kp_s_numpy_core_multiarray_failed_to, __pyx_k_numpy_core_multiarray_failed_to, sizeof(__pyx_k_numpy_core_multiarray_failed_to), 0, 0, 1, 0},
  {&__pyx_kp_s_numpy_core_umath_failed_to_impor, __pyx_k_numpy_core_umath_failed_to_impor, sizeof(__pyx_k_numpy_core_umath_failed_to_impor), 0, 0, 1, 0},
  {&__pyx_n_s_nvals, __pyx_k_nvals, sizeof(__pyx_k_nvals), 0, 0, 1, 1},
  {&__pyx_n_s_opening_angle, __pyx_k_opening_angle, sizeof(__pyx_k_opening_angle), 0, 0, 1, 1},
  {&__pyx_n_s_print, __pyx_k_print, sizeof(__pyx_k_print), 0, 0, 1, 1},
  {&__pyx_n_s_pvals, __pyx_k_pvals, sizeof(__pyx_k_pvals), 0, 0, 1, 1},
  {&__pyx_n_s_pweight_vals, __pyx_k_pweight_vals, sizeof(__pyx_k_pweight_vals), 0, 0, 1, 1},
  {&__pyx_n_s_pxs, __pyx_k_pxs, sizeof(__pyx_k_pxs), 0, 0, 1, 1},
  {&__pyx_n_s_pys, __pyx_k_pys, sizeof(__pyx_k_pys), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
  {&__pyx_n_s_pzs, __pyx_k_pzs, sizeof(__pyx_k_pzs), 0, 0, 1, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
  {&__pyx_n_s_root_dx, __pyx_k_root_dx, sizeof(__pyx_k_root_dx), 0, 0, 1, 1},
  {&__pyx_kp_s_s_s, __pyx_k_s_s, sizeof(__pyx_k_s_s), 0, 0, 1, 0},
  {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
  {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
  {&__pyx_n_s_start_index, __pyx_k_start_index, sizeof(__pyx_k_start_index), 0, 0, 1, 1},
  {&__pyx_n_s_stderr, __pyx_k_stderr, sizeof(__pyx_k_stderr), 0, 0, 1, 1},
  {&__pyx_n_s_stdout, __pyx_k_stdout, sizeof(__pyx_k_stdout), 0, 0, 1, 1},
  {&__pyx_n_s_sys, __pyx_k_sys, sizeof(__pyx_k_sys), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_time, __pyx_k_time, sizeof(__pyx_k_time), 0, 0, 1, 1},
  {&__pyx_n_s_top_grid_dims, __pyx_k_top_grid_dims, sizeof(__pyx_k_top_grid_dims), 0, 0, 1, 1},
  {&__pyx_n_s_treecode, __pyx_k_treecode, sizeof(__pyx_k_treecode), 0, 0, 1, 1},
  {&__pyx_n_s_truncate, __pyx_k_truncate, sizeof(__pyx_k_truncate), 0, 0, 1, 1},
  {&__pyx_kp_u_unknown_dtype_code_in_numpy_pxd, __pyx_k_unknown_dtype_code_in_numpy_pxd, sizeof(__pyx_k_unknown_dtype_code_in_numpy_pxd), 0, 1, 0, 0},
  {&__pyx_kp_s_val_d, __pyx_k_val_d, sizeof(__pyx_k_val_d), 0, 0, 1, 0},
  {&__pyx_kp_s_weight_child_parent_children, __pyx_k_weight_child_parent_children, sizeof(__pyx_k_weight_child_parent_children), 0, 0, 1, 0},
  {&__pyx_n_s_wvals, __pyx_k_wvals, sizeof(__pyx_k_wvals), 0, 0, 1, 1},
  {&__pyx_n_s_zeros, __pyx_k_zeros, sizeof(__pyx_k_zeros), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 54, __pyx_L1_error)
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s_TypeError); if (!__pyx_builtin_TypeError) __PYX_ERR(1, 2, __pyx_L1_error)
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) __PYX_ERR(2, 235, __pyx_L1_error)
  __pyx_builtin_RuntimeError = __Pyx_GetBuiltinName(__pyx_n_s_RuntimeError); if (!__pyx_builtin_RuntimeError) __PYX_ERR(2, 823, __pyx_L1_error)
  __pyx_builtin_ImportError = __Pyx_GetBuiltinName(__pyx_n_s_ImportError); if (!__pyx_builtin_ImportError) __PYX_ERR(2, 1013, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__2 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__2)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__2);
  __Pyx_GIVEREF(__pyx_tuple__2);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__3 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__3)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":235
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")             # <<<<<<<<<<<<<<
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 */
  __pyx_tuple__4 = PyTuple_Pack(1, __pyx_kp_u_ndarray_is_not_C_contiguous); if (unlikely(!__pyx_tuple__4)) __PYX_ERR(2, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__4);
  __Pyx_GIVEREF(__pyx_tuple__4);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":239
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")             # <<<<<<<<<<<<<<
 * 
 *             info.buf = PyArray_DATA(self)
 */
  __pyx_tuple__5 = PyTuple_Pack(1, __pyx_kp_u_ndarray_is_not_Fortran_contiguou); if (unlikely(!__pyx_tuple__5)) __PYX_ERR(2, 239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":276
 *                 if ((descr.byteorder == c'>' and little_endian) or
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"
 */
  __pyx_tuple__6 = PyTuple_Pack(1, __pyx_kp_u_Non_native_byte_order_not_suppor); if (unlikely(!__pyx_tuple__6)) __PYX_ERR(2, 276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__6);
  __Pyx_GIVEREF(__pyx_tuple__6);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":823
 * 
 *         if (end - f) - <int>(new_offset - offset[0]) < 15:
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")             # <<<<<<<<<<<<<<
 * 
 *         if ((child.byteorder == c'>' and little_endian) or
 */
  __pyx_tuple__7 = PyTuple_Pack(1, __pyx_kp_u_Format_string_allocated_too_shor); if (unlikely(!__pyx_tuple__7)) __PYX_ERR(2, 823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__7);
  __Pyx_GIVEREF(__pyx_tuple__7);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":827
 *         if ((child.byteorder == c'>' and little_endian) or
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *             # One could encode it in the format string and have Cython
 *             # complain instead, BUT: < and > in format strings also imply
 */
  __pyx_tuple__8 = PyTuple_Pack(1, __pyx_kp_u_Non_native_byte_order_not_suppor); if (unlikely(!__pyx_tuple__8)) __PYX_ERR(2, 827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__8);
  __Pyx_GIVEREF(__pyx_tuple__8);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":847
 *             t = child.type_num
 *             if end - f < 5:
 *                 raise RuntimeError(u"Format string allocated too short.")             # <<<<<<<<<<<<<<
 * 
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 */
  __pyx_tuple__9 = PyTuple_Pack(1, __pyx_kp_u_Format_string_allocated_too_shor_2); if (unlikely(!__pyx_tuple__9)) __PYX_ERR(2, 847, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1013
 *         _import_array()
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_umath() except -1:
 */
  __pyx_tuple__10 = PyTuple_Pack(1, __pyx_kp_s_numpy_core_multiarray_failed_to); if (unlikely(!__pyx_tuple__10)) __PYX_ERR(2, 1013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__10);
  __Pyx_GIVEREF(__pyx_tuple__10);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1019
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_ufunc() except -1:
 */
  __pyx_tuple__11 = PyTuple_Pack(1, __pyx_kp_s_numpy_core_umath_failed_to_impor); if (unlikely(!__pyx_tuple__11)) __PYX_ERR(2, 1019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);

  /* "../../../../usr/local/lib/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1025
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__12 = PyTuple_Pack(1, __pyx_kp_s_numpy_core_umath_failed_to_impor); if (unlikely(!__pyx_tuple__12)) __PYX_ERR(2, 1025, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__12);
  __Pyx_GIVEREF(__pyx_tuple__12);
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

#if PY_MAJOR_VERSION < 3
PyMODINIT_FUNC initbasic_octree(void); /*proto*/
PyMODINIT_FUNC initbasic_octree(void)
#else
PyMODINIT_FUNC PyInit_basic_octree(void); /*proto*/
PyMODINIT_FUNC PyInit_basic_octree(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        result = PyDict_SetItemString(moddict, to_name, value);
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__") < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__") < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__") < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__") < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static int __pyx_pymod_exec_basic_octree(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m && __pyx_m == __pyx_pyinit_module) return 0;
  #endif
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
      PyErr_Clear();
      __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
      if (!__Pyx_RefNanny)
          Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  __Pyx_RefNannySetupContext("PyMODINIT_FUNC PyInit_basic_octree(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("basic_octree", __pyx_methods, __pyx_k_A_refine_by_two_AMR_specific_oc, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  #if CYTHON_COMPILING_IN_PYPY
  Py_INCREF(__pyx_b);
  #endif
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_yt__utilities__lib__basic_octree) {
    if (PyObject_SetAttrString(__pyx_m, "__name__", __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "yt.utilities.lib.basic_octree")) {
      if (unlikely(PyDict_SetItemString(modules, "yt.utilities.lib.basic_octree", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global init code ---*/
  /*--- Variable export code ---*/
  /*--- Function export code ---*/
  /*--- Type init code ---*/
  __pyx_vtabptr_2yt_9utilities_3lib_12basic_octree_Octree = &__pyx_vtable_2yt_9utilities_3lib_12basic_octree_Octree;
  __pyx_vtable_2yt_9utilities_3lib_12basic_octree_Octree.add_to_position = (void (*)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, int, __pyx_t_5numpy_int64_t *, __pyx_t_5numpy_float64_t *, __pyx_t_5numpy_float64_t, PyObject *))__pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_add_to_position;
  __pyx_vtable_2yt_9utilities_3lib_12basic_octree_Octree.find_on_root_level = (struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *(*)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, __pyx_t_5numpy_int64_t *, int))__pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_find_on_root_level;
  __pyx_vtable_2yt_9utilities_3lib_12basic_octree_Octree.count_at_level = (int (*)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *, int))__pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_count_at_level;
  __pyx_vtable_2yt_9utilities_3lib_12basic_octree_Octree.fill_from_level = (int (*)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *, int, __pyx_t_5numpy_int64_t, __pyx_t_5numpy_int64_t *, __pyx_t_5numpy_float64_t *, __pyx_t_5numpy_float64_t *))__pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_fill_from_level;
  __pyx_vtable_2yt_9utilities_3lib_12basic_octree_Octree.fbe_node_separation = (__pyx_t_5numpy_float64_t (*)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *))__pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_fbe_node_separation;
  __pyx_vtable_2yt_9utilities_3lib_12basic_octree_Octree.fbe_opening_angle = (__pyx_t_5numpy_float64_t (*)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *))__pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_fbe_opening_angle;
  __pyx_vtable_2yt_9utilities_3lib_12basic_octree_Octree.set_next = (void (*)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *, int))__pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_set_next;
  __pyx_vtable_2yt_9utilities_3lib_12basic_octree_Octree.set_up_next = (void (*)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *))__pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_set_up_next;
  __pyx_vtable_2yt_9utilities_3lib_12basic_octree_Octree.fbe_main = (__pyx_t_5numpy_float64_t (*)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, __pyx_t_5numpy_float64_t, int, __pyx_t_5numpy_float64_t))__pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_fbe_main;
  __pyx_vtable_2yt_9utilities_3lib_12basic_octree_Octree.node_ID = (int (*)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *))__pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_node_ID;
  __pyx_vtable_2yt_9utilities_3lib_12basic_octree_Octree.node_ID_on_level = (int (*)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *))__pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_node_ID_on_level;
  __pyx_vtable_2yt_9utilities_3lib_12basic_octree_Octree.print_node_info = (void (*)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *))__pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_print_node_info;
  __pyx_vtable_2yt_9utilities_3lib_12basic_octree_Octree.iterate_print_nodes = (void (*)(struct __pyx_obj_2yt_9utilities_3lib_12basic_octree_Octree *, struct __pyx_t_2yt_9utilities_3lib_12basic_octree_OctreeNode *))__pyx_f_2yt_9utilities_3lib_12basic_octree_6Octree_iterate_print_nodes;
  if (PyType_Ready(&__pyx_type_2yt_9utilities_3lib_12basic_octree_Octree) < 0) __PYX_ERR(0, 119, __pyx_L1_error)
  __pyx_type_2yt_9utilities_3lib_12basic_octree_Octree.tp_print = 0;
  if (__Pyx_SetVtable(__pyx_type_2yt_9utilities_3lib_12basic_octree_Octree.tp_dict, __pyx_vtabptr_2yt_9utilities_3lib_12basic_octree_Octree) < 0) __PYX_ERR(0, 119, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "Octree", (PyObject *)&__pyx_type_2yt_9utilities_3lib_12basic_octree_Octree) < 0) __PYX_ERR(0, 119, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_2yt_9utilities_3lib_12basic_octree_Octree) < 0) __PYX_ERR(0, 119, __pyx_L1_error)
  __pyx_ptype_2yt_9utilities_3lib_12basic_octree_Octree = &__pyx_type_2yt_9utilities_3lib_12basic_octree_Octree;
  /*--- Type import code ---*/
  __pyx_ptype_7cpython_4type_type = __Pyx_ImportType(__Pyx_BUILTIN_MODULE_NAME, "type", 
  #if CYTHON_COMPILING_IN_PYPY
  sizeof(PyTypeObject),
  #else
  sizeof(PyHeapTypeObject),
  #endif
  0); if (unlikely(!__pyx_ptype_7cpython_4type_type)) __PYX_ERR(3, 9, __pyx_L1_error)
  __pyx_ptype_5numpy_dtype = __Pyx_ImportType("numpy", "dtype", sizeof(PyArray_Descr), 0); if (unlikely(!__pyx_ptype_5numpy_dtype)) __PYX_ERR(2, 163, __pyx_L1_error)
  __pyx_ptype_5numpy_flatiter = __Pyx_ImportType("numpy", "flatiter", sizeof(PyArrayIterObject), 0); if (unlikely(!__pyx_ptype_5numpy_flatiter)) __PYX_ERR(2, 185, __pyx_L1_error)
  __pyx_ptype_5numpy_broadcast = __Pyx_ImportType("numpy", "broadcast", sizeof(PyArrayMultiIterObject), 0); if (unlikely(!__pyx_ptype_5numpy_broadcast)) __PYX_ERR(2, 189, __pyx_L1_error)
  __pyx_ptype_5numpy_ndarray = __Pyx_ImportType("numpy", "ndarray", sizeof(PyArrayObject), 0); if (unlikely(!__pyx_ptype_5numpy_ndarray)) __PYX_ERR(2, 198, __pyx_L1_error)
  __pyx_ptype_5numpy_ufunc = __Pyx_ImportType("numpy", "ufunc", sizeof(PyUFuncObject), 0); if (unlikely(!__pyx_ptype_5numpy_ufunc)) __PYX_ERR(2, 885, __pyx_L1_error)
  /*--- Variable import code ---*/
  /*--- Function import code ---*/
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "yt/utilities/lib/basic_octree.pyx":17
 * 
 * 
 * import numpy as np             # <<<<<<<<<<<<<<
 * cimport numpy as np
 * # Double up here for def'd functions
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_numpy, 0, -1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_np, __pyx_t_1) < 0) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "yt/utilities/lib/basic_octree.pyx":26
 * from libc.stdlib cimport malloc, free, abs
 * 
 * import sys, time             # <<<<<<<<<<<<<<
 * 
 * cdef extern from "platform_dep.h":
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_sys, 0, -1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sys, __pyx_t_1) < 0) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_time, 0, -1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_time, __pyx_t_1) < 0) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "yt/utilities/lib/basic_octree.pyx":1
 * """             # <<<<<<<<<<<<<<
 * A refine-by-two AMR-specific octree
 * 
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_Octree_print_all_nodes_line_562, __pyx_kp_u_Prints_out_information_about_al) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_1) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "yt/utilities/lib/fp_utils.pxd":57
 *     return i1
 * 
 * cdef inline np.int64_t i64min(np.int64_t i0, np.int64_t i1) nogil:             # <<<<<<<<<<<<<<
 *     if i0 < i1: return i0
 *     return i1
 */

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init yt.utilities.lib.basic_octree", 0, __pyx_lineno, __pyx_filename);
    }
    Py_DECREF(__pyx_m); __pyx_m = 0;
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init yt.utilities.lib.basic_octree");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule((char *)modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, (char *)"RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_CheckExact(key)) || likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (PyUnicode_GET_SIZE(**name) != PyUnicode_GET_SIZE(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (PyUnicode_GET_SIZE(**argname) != PyUnicode_GET_SIZE(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* ArgTypeTest */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected %.200s, got %.200s)",
        name, type->tp_name, Py_TYPE(obj)->tp_name);
    return 0;
}

/* IsLittleEndian */
static CYTHON_INLINE int __Pyx_Is_Little_Endian(void)
{
  union {
    uint32_t u32;
    uint8_t u8[4];
  } S;
  S.u32 = 0x01020304;
  return S.u8[0] == 4;
}

/* BufferFormatCheck */
static void __Pyx_BufFmt_Init(__Pyx_BufFmt_Context* ctx,
                              __Pyx_BufFmt_StackElem* stack,
                              __Pyx_TypeInfo* type) {
  stack[0].field = &ctx->root;
  stack[0].parent_offset = 0;
  ctx->root.type = type;
  ctx->root.name = "buffer dtype";
  ctx->root.offset = 0;
  ctx->head = stack;
  ctx->head->field = &ctx->root;
  ctx->fmt_offset = 0;
  ctx->head->parent_offset = 0;
  ctx->new_packmode = '@';
  ctx->enc_packmode = '@';
  ctx->new_count = 1;
  ctx->enc_count = 0;
  ctx->enc_type = 0;
  ctx->is_complex = 0;
  ctx->is_valid_array = 0;
  ctx->struct_alignment = 0;
  while (type->typegroup == 'S') {
    ++ctx->head;
    ctx->head->field = type->fields;
    ctx->head->parent_offset = 0;
    type = type->fields->type;
  }
}
static int __Pyx_BufFmt_ParseNumber(const char** ts) {
    int count;
    const char* t = *ts;
    if (*t < '0' || *t > '9') {
      return -1;
    } else {
        count = *t++ - '0';
        while (*t >= '0' && *t < '9') {
            count *= 10;
            count += *t++ - '0';
        }
    }
    *ts = t;
    return count;
}
static int __Pyx_BufFmt_ExpectNumber(const char **ts) {
    int number = __Pyx_BufFmt_ParseNumber(ts);
    if (number == -1)
        PyErr_Format(PyExc_ValueError,\
                     "Does not understand character buffer dtype format string ('%c')", **ts);
    return number;
}
static void __Pyx_BufFmt_RaiseUnexpectedChar(char ch) {
  PyErr_Format(PyExc_ValueError,
               "Unexpected format string character: '%c'", ch);
}
static const char* __Pyx_BufFmt_DescribeTypeChar(char ch, int is_complex) {
  switch (ch) {
    case 'c': return "'char'";
    case 'b': return "'signed char'";
    case 'B': return "'unsigned char'";
    case 'h': return "'short'";
    case 'H': return "'unsigned short'";
    case 'i': return "'int'";
    case 'I': return "'unsigned int'";
    case 'l': return "'long'";
    case 'L': return "'unsigned long'";
    case 'q': return "'long long'";
    case 'Q': return "'unsigned long long'";
    case 'f': return (is_complex ? "'complex float'" : "'float'");
    case 'd': return (is_complex ? "'complex double'" : "'double'");
    case 'g': return (is_complex ? "'complex long double'" : "'long double'");
    case 'T': return "a struct";
    case 'O': return "Python object";
    case 'P': return "a pointer";
    case 's': case 'p': return "a string";
    case 0: return "end";
    default: return "unparseable format string";
  }
}
static size_t __Pyx_BufFmt_TypeCharToStandardSize(char ch, int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return 2;
    case 'i': case 'I': case 'l': case 'L': return 4;
    case 'q': case 'Q': return 8;
    case 'f': return (is_complex ? 8 : 4);
    case 'd': return (is_complex ? 16 : 8);
    case 'g': {
      PyErr_SetString(PyExc_ValueError, "Python does not define a standard format string size for long double ('g')..");
      return 0;
    }
    case 'O': case 'P': return sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
static size_t __Pyx_BufFmt_TypeCharToNativeSize(char ch, int is_complex) {
  switch (ch) {
    case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(short);
    case 'i': case 'I': return sizeof(int);
    case 'l': case 'L': return sizeof(long);
    #ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(PY_LONG_LONG);
    #endif
    case 'f': return sizeof(float) * (is_complex ? 2 : 1);
    case 'd': return sizeof(double) * (is_complex ? 2 : 1);
    case 'g': return sizeof(long double) * (is_complex ? 2 : 1);
    case 'O': case 'P': return sizeof(void*);
    default: {
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
  }
}
typedef struct { char c; short x; } __Pyx_st_short;
typedef struct { char c; int x; } __Pyx_st_int;
typedef struct { char c; long x; } __Pyx_st_long;
typedef struct { char c; float x; } __Pyx_st_float;
typedef struct { char c; double x; } __Pyx_st_double;
typedef struct { char c; long double x; } __Pyx_st_longdouble;
typedef struct { char c; void *x; } __Pyx_st_void_p;
#ifdef HAVE_LONG_LONG
typedef struct { char c; PY_LONG_LONG x; } __Pyx_st_longlong;
#endif
static size_t __Pyx_BufFmt_TypeCharToAlignment(char ch, CYTHON_UNUSED int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(__Pyx_st_short) - sizeof(short);
    case 'i': case 'I': return sizeof(__Pyx_st_int) - sizeof(int);
    case 'l': case 'L': return sizeof(__Pyx_st_long) - sizeof(long);
#ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(__Pyx_st_longlong) - sizeof(PY_LONG_LONG);
#endif
    case 'f': return sizeof(__Pyx_st_float) - sizeof(float);
    case 'd': return sizeof(__Pyx_st_double) - sizeof(double);
    case 'g': return sizeof(__Pyx_st_longdouble) - sizeof(long double);
    case 'P': case 'O': return sizeof(__Pyx_st_void_p) - sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
/* These are for computing the padding at the end of the struct to align
   on the first member of the struct. This will probably the same as above,
   but we don't have any guarantees.
 */
typedef struct { short x; char c; } __Pyx_pad_short;
typedef struct { int x; char c; } __Pyx_pad_int;
typedef struct { long x; char c; } __Pyx_pad_long;
typedef struct { float x; char c; } __Pyx_pad_float;
typedef struct { double x; char c; } __Pyx_pad_double;
typedef struct { long double x; char c; } __Pyx_pad_longdouble;
typedef struct { void *x; char c; } __Pyx_pad_void_p;
#ifdef HAVE_LONG_LONG
typedef struct { PY_LONG_LONG x; char c; } __Pyx_pad_longlong;
#endif
static size_t __Pyx_BufFmt_TypeCharToPadding(char ch, CYTHON_UNUSED int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(__Pyx_pad_short) - sizeof(short);
    case 'i': case 'I': return sizeof(__Pyx_pad_int) - sizeof(int);
    case 'l': case 'L': return sizeof(__Pyx_pad_long) - sizeof(long);
#ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(__Pyx_pad_longlong) - sizeof(PY_LONG_LONG);
#endif
    case 'f': return sizeof(__Pyx_pad_float) - sizeof(float);
    case 'd': return sizeof(__Pyx_pad_double) - sizeof(double);
    case 'g': return sizeof(__Pyx_pad_longdouble) - sizeof(long double);
    case 'P': case 'O': return sizeof(__Pyx_pad_void_p) - sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
static char __Pyx_BufFmt_TypeCharToGroup(char ch, int is_complex) {
  switch (ch) {
    case 'c':
        return 'H';
    case 'b': case 'h': case 'i':
    case 'l': case 'q': case 's': case 'p':
        return 'I';
    case 'B': case 'H': case 'I': case 'L': case 'Q':
        return 'U';
    case 'f': case 'd': case 'g':
        return (is_complex ? 'C' : 'R');
    case 'O':
        return 'O';
    case 'P':
        return 'P';
    default: {
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
  }
}
static void __Pyx_BufFmt_RaiseExpected(__Pyx_BufFmt_Context* ctx) {
  if (ctx->head == NULL || ctx->head->field == &ctx->root) {
    const char* expected;
    const char* quote;
    if (ctx->head == NULL) {
      expected = "end";
      quote = "";
    } else {
      expected = ctx->head->field->type->name;
      quote = "'";
    }
    PyErr_Format(PyExc_ValueError,
                 "Buffer dtype mismatch, expected %s%s%s but got %s",
                 quote, expected, quote,
                 __Pyx_BufFmt_DescribeTypeChar(ctx->enc_type, ctx->is_complex));
  } else {
    __Pyx_StructField* field = ctx->head->field;
    __Pyx_StructField* parent = (ctx->head - 1)->field;
    PyErr_Format(PyExc_ValueError,
                 "Buffer dtype mismatch, expected '%s' but got %s in '%s.%s'",
                 field->type->name, __Pyx_BufFmt_DescribeTypeChar(ctx->enc_type, ctx->is_complex),
                 parent->type->name, field->name);
  }
}
static int __Pyx_BufFmt_ProcessTypeChunk(__Pyx_BufFmt_Context* ctx) {
  char group;
  size_t size, offset, arraysize = 1;
  if (ctx->enc_type == 0) return 0;
  if (ctx->head->field->type->arraysize[0]) {
    int i, ndim = 0;
    if (ctx->enc_type == 's' || ctx->enc_type == 'p') {
        ctx->is_valid_array = ctx->head->field->type->ndim == 1;
        ndim = 1;
        if (ctx->enc_count != ctx->head->field->type->arraysize[0]) {
            PyErr_Format(PyExc_ValueError,
                         "Expected a dimension of size %zu, got %zu",
                         ctx->head->field->type->arraysize[0], ctx->enc_count);
            return -1;
        }
    }
    if (!ctx->is_valid_array) {
      PyErr_Format(PyExc_ValueError, "Expected %d dimensions, got %d",
                   ctx->head->field->type->ndim, ndim);
      return -1;
    }
    for (i = 0; i < ctx->head->field->type->ndim; i++) {
      arraysize *= ctx->head->field->type->arraysize[i];
    }
    ctx->is_valid_array = 0;
    ctx->enc_count = 1;
  }
  group = __Pyx_BufFmt_TypeCharToGroup(ctx->enc_type, ctx->is_complex);
  do {
    __Pyx_StructField* field = ctx->head->field;
    __Pyx_TypeInfo* type = field->type;
    if (ctx->enc_packmode == '@' || ctx->enc_packmode == '^') {
      size = __Pyx_BufFmt_TypeCharToNativeSize(ctx->enc_type, ctx->is_complex);
    } else {
      size = __Pyx_BufFmt_TypeCharToStandardSize(ctx->enc_type, ctx->is_complex);
    }
    if (ctx->enc_packmode == '@') {
      size_t align_at = __Pyx_BufFmt_TypeCharToAlignment(ctx->enc_type, ctx->is_complex);
      size_t align_mod_offset;
      if (align_at == 0) return -1;
      align_mod_offset = ctx->fmt_offset % align_at;
      if (align_mod_offset > 0) ctx->fmt_offset += align_at - align_mod_offset;
      if (ctx->struct_alignment == 0)
          ctx->struct_alignment = __Pyx_BufFmt_TypeCharToPadding(ctx->enc_type,
                                                                 ctx->is_complex);
    }
    if (type->size != size || type->typegroup != group) {
      if (type->typegroup == 'C' && type->fields != NULL) {
        size_t parent_offset = ctx->head->parent_offset + field->offset;
        ++ctx->head;
        ctx->head->field = type->fields;
        ctx->head->parent_offset = parent_offset;
        continue;
      }
      if ((type->typegroup == 'H' || group == 'H') && type->size == size) {
      } else {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return -1;
      }
    }
    offset = ctx->head->parent_offset + field->offset;
    if (ctx->fmt_offset != offset) {
      PyErr_Format(PyExc_ValueError,
                   "Buffer dtype mismatch; next field is at offset %" CYTHON_FORMAT_SSIZE_T "d but %" CYTHON_FORMAT_SSIZE_T "d expected",
                   (Py_ssize_t)ctx->fmt_offset, (Py_ssize_t)offset);
      return -1;
    }
    ctx->fmt_offset += size;
    if (arraysize)
      ctx->fmt_offset += (arraysize - 1) * size;
    --ctx->enc_count;
    while (1) {
      if (field == &ctx->root) {
        ctx->head = NULL;
        if (ctx->enc_count != 0) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return -1;
        }
        break;
      }
      ctx->head->field = ++field;
      if (field->type == NULL) {
        --ctx->head;
        field = ctx->head->field;
        continue;
      } else if (field->type->typegroup == 'S') {
        size_t parent_offset = ctx->head->parent_offset + field->offset;
        if (field->type->fields->type == NULL) continue;
        field = field->type->fields;
        ++ctx->head;
        ctx->head->field = field;
        ctx->head->parent_offset = parent_offset;
        break;
      } else {
        break;
      }
    }
  } while (ctx->enc_count);
  ctx->enc_type = 0;
  ctx->is_complex = 0;
  return 0;
}
static PyObject *
__pyx_buffmt_parse_array(__Pyx_BufFmt_Context* ctx, const char** tsp)
{
    const char *ts = *tsp;
    int i = 0, number;
    int ndim = ctx->head->field->type->ndim;
;
    ++ts;
    if (ctx->new_count != 1) {
        PyErr_SetString(PyExc_ValueError,
                        "Cannot handle repeated arrays in format string");
        return NULL;
    }
    if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
    while (*ts && *ts != ')') {
        switch (*ts) {
            case ' ': case '\f': case '\r': case '\n': case '\t': case '\v':  continue;
            default:  break;
        }
        number = __Pyx_BufFmt_ExpectNumber(&ts);
        if (number == -1) return NULL;
        if (i < ndim && (size_t) number != ctx->head->field->type->arraysize[i])
            return PyErr_Format(PyExc_ValueError,
                        "Expected a dimension of size %zu, got %d",
                        ctx->head->field->type->arraysize[i], number);
        if (*ts != ',' && *ts != ')')
            return PyErr_Format(PyExc_ValueError,
                                "Expected a comma in format string, got '%c'", *ts);
        if (*ts == ',') ts++;
        i++;
    }
    if (i != ndim)
        return PyErr_Format(PyExc_ValueError, "Expected %d dimension(s), got %d",
                            ctx->head->field->type->ndim, i);
    if (!*ts) {
        PyErr_SetString(PyExc_ValueError,
                        "Unexpected end of format string, expected ')'");
        return NULL;
    }
    ctx->is_valid_array = 1;
    ctx->new_count = 1;
    *tsp = ++ts;
    return Py_None;
}
static const char* __Pyx_BufFmt_CheckString(__Pyx_BufFmt_Context* ctx, const char* ts) {
  int got_Z = 0;
  while (1) {
    switch(*ts) {
      case 0:
        if (ctx->enc_type != 0 && ctx->head == NULL) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return NULL;
        }
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        if (ctx->head != NULL) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return NULL;
        }
        return ts;
      case ' ':
      case '\r':
      case '\n':
        ++ts;
        break;
      case '<':
        if (!__Pyx_Is_Little_Endian()) {
          PyErr_SetString(PyExc_ValueError, "Little-endian buffer not supported on big-endian compiler");
          return NULL;
        }
        ctx->new_packmode = '=';
        ++ts;
        break;
      case '>':
      case '!':
        if (__Pyx_Is_Little_Endian()) {
          PyErr_SetString(PyExc_ValueError, "Big-endian buffer not supported on little-endian compiler");
          return NULL;
        }
        ctx->new_packmode = '=';
        ++ts;
        break;
      case '=':
      case '@':
      case '^':
        ctx->new_packmode = *ts++;
        break;
      case 'T':
        {
          const char* ts_after_sub;
          size_t i, struct_count = ctx->new_count;
          size_t struct_alignment = ctx->struct_alignment;
          ctx->new_count = 1;
          ++ts;
          if (*ts != '{') {
            PyErr_SetString(PyExc_ValueError, "Buffer acquisition: Expected '{' after 'T'");
            return NULL;
          }
          if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
          ctx->enc_type = 0;
          ctx->enc_count = 0;
          ctx->struct_alignment = 0;
          ++ts;
          ts_after_sub = ts;
          for (i = 0; i != struct_count; ++i) {
            ts_after_sub = __Pyx_BufFmt_CheckString(ctx, ts);
            if (!ts_after_sub) return NULL;
          }
          ts = ts_after_sub;
          if (struct_alignment) ctx->struct_alignment = struct_alignment;
        }
        break;
      case '}':
        {
          size_t alignment = ctx->struct_alignment;
          ++ts;
          if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
          ctx->enc_type = 0;
          if (alignment && ctx->fmt_offset % alignment) {
            ctx->fmt_offset += alignment - (ctx->fmt_offset % alignment);
          }
        }
        return ts;
      case 'x':
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        ctx->fmt_offset += ctx->new_count;
        ctx->new_count = 1;
        ctx->enc_count = 0;
        ctx->enc_type = 0;
        ctx->enc_packmode = ctx->new_packmode;
        ++ts;
        break;
      case 'Z':
        got_Z = 1;
        ++ts;
        if (*ts != 'f' && *ts != 'd' && *ts != 'g') {
          __Pyx_BufFmt_RaiseUnexpectedChar('Z');
          return NULL;
        }
      case 'c': case 'b': case 'B': case 'h': case 'H': case 'i': case 'I':
      case 'l': case 'L': case 'q': case 'Q':
      case 'f': case 'd': case 'g':
      case 'O': case 'p':
        if (ctx->enc_type == *ts && got_Z == ctx->is_complex &&
            ctx->enc_packmode == ctx->new_packmode) {
          ctx->enc_count += ctx->new_count;
          ctx->new_count = 1;
          got_Z = 0;
          ++ts;
          break;
        }
      case 's':
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        ctx->enc_count = ctx->new_count;
        ctx->enc_packmode = ctx->new_packmode;
        ctx->enc_type = *ts;
        ctx->is_complex = got_Z;
        ++ts;
        ctx->new_count = 1;
        got_Z = 0;
        break;
      case ':':
        ++ts;
        while(*ts != ':') ++ts;
        ++ts;
        break;
      case '(':
        if (!__pyx_buffmt_parse_array(ctx, &ts)) return NULL;
        break;
      default:
        {
          int number = __Pyx_BufFmt_ExpectNumber(&ts);
          if (number == -1) return NULL;
          ctx->new_count = (size_t)number;
        }
    }
  }
}

/* BufferGetAndValidate */
  static CYTHON_INLINE void __Pyx_SafeReleaseBuffer(Py_buffer* info) {
  if (unlikely(info->buf == NULL)) return;
  if (info->suboffsets == __Pyx_minusones) info->suboffsets = NULL;
  __Pyx_ReleaseBuffer(info);
}
static void __Pyx_ZeroBuffer(Py_buffer* buf) {
  buf->buf = NULL;
  buf->obj = NULL;
  buf->strides = __Pyx_zeros;
  buf->shape = __Pyx_zeros;
  buf->suboffsets = __Pyx_minusones;
}
static int __Pyx__GetBufferAndValidate(
        Py_buffer* buf, PyObject* obj,  __Pyx_TypeInfo* dtype, int flags,
        int nd, int cast, __Pyx_BufFmt_StackElem* stack)
{
  buf->buf = NULL;
  if (unlikely(__Pyx_GetBuffer(obj, buf, flags) == -1)) {
    __Pyx_ZeroBuffer(buf);
    return -1;
  }
  if (unlikely(buf->ndim != nd)) {
    PyErr_Format(PyExc_ValueError,
                 "Buffer has wrong number of dimensions (expected %d, got %d)",
                 nd, buf->ndim);
    goto fail;
  }
  if (!cast) {
    __Pyx_BufFmt_Context ctx;
    __Pyx_BufFmt_Init(&ctx, stack, dtype);
    if (!__Pyx_BufFmt_CheckString(&ctx, buf->format)) goto fail;
  }
  if (unlikely((unsigned)buf->itemsize != dtype->size)) {
    PyErr_Format(PyExc_ValueError,
      "Item size of buffer (%" CYTHON_FORMAT_SSIZE_T "d byte%s) does not match size of '%s' (%" CYTHON_FORMAT_SSIZE_T "d byte%s)",
      buf->itemsize, (buf->itemsize > 1) ? "s" : "",
      dtype->name, (Py_ssize_t)dtype->size, (dtype->size > 1) ? "s" : "");
    goto fail;
  }
  if (buf->suboffsets == NULL) buf->suboffsets = __Pyx_minusones;
  return 0;
fail:;
  __Pyx_SafeReleaseBuffer(buf);
  return -1;
}

/* BufferIndexError */
  static void __Pyx_RaiseBufferIndexError(int axis) {
  PyErr_Format(PyExc_IndexError,
     "Out of bounds on buffer access (axis %d)", axis);
}

/* PyErrFetchRestore */
  #if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* WriteUnraisableException */
  static void __Pyx_WriteUnraisable(const char *name, CYTHON_UNUSED int clineno,
                                  CYTHON_UNUSED int lineno, CYTHON_UNUSED const char *filename,
                                  int full_traceback, CYTHON_UNUSED int nogil) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_PyThreadState_declare
#ifdef WITH_THREAD
    PyGILState_STATE state;
    if (nogil)
        state = PyGILState_Ensure();
#ifdef _MSC_VER
    else state = (PyGILState_STATE)-1;
#endif
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    if (full_traceback) {
        Py_XINCREF(old_exc);
        Py_XINCREF(old_val);
        Py_XINCREF(old_tb);
        __Pyx_ErrRestore(old_exc, old_val, old_tb);
        PyErr_PrintEx(1);
    }
    #if PY_MAJOR_VERSION < 3
    ctx = PyString_FromString(name);
    #else
    ctx = PyUnicode_FromString(name);
    #endif
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
#ifdef WITH_THREAD
    if (nogil)
        PyGILState_Release(state);
#endif
}

/* None */
  static CYTHON_INLINE __pyx_t_5numpy_int64_t __Pyx_div___pyx_t_5numpy_int64_t(__pyx_t_5numpy_int64_t a, __pyx_t_5numpy_int64_t b) {
    __pyx_t_5numpy_int64_t q = a / b;
    __pyx_t_5numpy_int64_t r = a - q*b;
    q -= ((r != 0) & ((r ^ b) < 0));
    return q;
}

/* GetModuleGlobalName */
  static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name) {
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
    result = PyDict_GetItem(__pyx_d, name);
    if (likely(result)) {
        Py_INCREF(result);
    } else {
#else
    result = PyObject_GetItem(__pyx_d, name);
    if (!result) {
        PyErr_Clear();
#endif
        result = __Pyx_GetBuiltinName(name);
    }
    return result;
}

/* PyObjectCall */
    #if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* ExtTypeTest */
    static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

/* BufferFallbackError */
    static void __Pyx_RaiseBufferFallbackError(void) {
  PyErr_SetString(PyExc_ValueError,
     "Buffer acquisition failed on assignment; and then reacquiring the old buffer failed too!");
}

/* None */
    static CYTHON_INLINE __pyx_t_5numpy_int64_t __Pyx_mod___pyx_t_5numpy_int64_t(__pyx_t_5numpy_int64_t a, __pyx_t_5numpy_int64_t b) {
    __pyx_t_5numpy_int64_t r = a % b;
    r += ((r != 0) & ((r ^ b) < 0)) * b;
    return r;
}

/* PyCFunctionFastCall */
    #if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    int flags = PyCFunction_GET_FLAGS(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    if ((PY_VERSION_HEX < 0x030700A0) || unlikely(flags & METH_KEYWORDS)) {
        return (*((__Pyx_PyCFunctionFastWithKeywords)meth)) (self, args, nargs, NULL);
    } else {
        return (*((__Pyx_PyCFunctionFast)meth)) (self, args, nargs);
    }
}
#endif

/* PyFunctionFastCall */
    #if CYTHON_FAST_PYCALL
#include "frameobject.h"
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = f->f_localsplus;
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, int nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif
#endif

/* PyObjectCallMethO */
    #if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallOneArg */
    #if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
    if (likely(PyCFunction_Check(func))) {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (PyCFunction_GET_FLAGS(func) & METH_FASTCALL) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* PyObjectCallNoArg */
    #if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, NULL, 0);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || __Pyx_TypeCheck(func, __pyx_CyFunctionType))) {
#else
    if (likely(PyCFunction_Check(func))) {
#endif
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

/* RaiseException */
      #if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    __Pyx_PyThreadState_declare
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* RaiseTooManyValuesToUnpack */
      static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
      static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* RaiseNoneIterError */
      static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* SaveResetException */
      #if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    #if PY_VERSION_HEX >= 0x030700A2
    *type = tstate->exc_state.exc_type;
    *value = tstate->exc_state.exc_value;
    *tb = tstate->exc_state.exc_traceback;
    #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    #endif
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if PY_VERSION_HEX >= 0x030700A2
    tmp_type = tstate->exc_state.exc_type;
    tmp_value = tstate->exc_state.exc_value;
    tmp_tb = tstate->exc_state.exc_traceback;
    tstate->exc_state.exc_type = type;
    tstate->exc_state.exc_value = value;
    tstate->exc_state.exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
#endif

/* PyErrExceptionMatches */
      #if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    PyObject *exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
    if (unlikely(PyTuple_Check(err)))
        return __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    return __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
}
#endif

/* GetException */
      #if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb) {
#endif
    PyObject *local_type, *local_value, *local_tb;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if PY_VERSION_HEX >= 0x030700A2
    tmp_type = tstate->exc_state.exc_type;
    tmp_value = tstate->exc_state.exc_value;
    tmp_tb = tstate->exc_state.exc_traceback;
    tstate->exc_state.exc_type = local_type;
    tstate->exc_state.exc_value = local_value;
    tstate->exc_state.exc_traceback = local_tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* SetVTable */
        static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s_pyx_vtable, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* SetupReduce */
        static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStr(meth, __pyx_n_s_name);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    if (_PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate)) goto GOOD;
#else
    if (PyObject_HasAttr(type_obj, __pyx_n_s_getstate)) goto GOOD;
#endif
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_cython); if (unlikely(!reduce_cython)) goto BAD;
            ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto BAD;
            ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto BAD;
            setstate = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_setstate_cython); if (unlikely(!setstate_cython)) goto BAD;
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto BAD;
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto GOOD;
BAD:
    if (!PyErr_Occurred())
        PyErr_Format(PyExc_RuntimeError, "Unable to initialize pickling for %s", ((PyTypeObject*)type_obj)->tp_name);
    ret = -1;
GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}

/* Import */
        static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.')) {
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* CLineInTraceback */
        #ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(CYTHON_UNUSED PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
      use_cline = PyDict_GetItem(*cython_runtime_dict, __pyx_n_s_cline_in_traceback);
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (PyObject_Not(use_cline) != 0) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
        static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, (size_t)new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
        #include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

#if PY_MAJOR_VERSION < 3
static int __Pyx_GetBuffer(PyObject *obj, Py_buffer *view, int flags) {
    if (PyObject_CheckBuffer(obj)) return PyObject_GetBuffer(obj, view, flags);
        if (__Pyx_TypeCheck(obj, __pyx_ptype_5numpy_ndarray)) return __pyx_pw_5numpy_7ndarray_1__getbuffer__(obj, view, flags);
    PyErr_Format(PyExc_TypeError, "'%.200s' does not have the buffer interface", Py_TYPE(obj)->tp_name);
    return -1;
}
static void __Pyx_ReleaseBuffer(Py_buffer *view) {
    PyObject *obj = view->obj;
    if (!obj) return;
    if (PyObject_CheckBuffer(obj)) {
        PyBuffer_Release(view);
        return;
    }
    if ((0)) {}
        else if (__Pyx_TypeCheck(obj, __pyx_ptype_5numpy_ndarray)) __pyx_pw_5numpy_7ndarray_3__releasebuffer__(obj, view);
    view->obj = NULL;
    Py_DECREF(obj);
}
#endif


        /* CIntFromPyVerify */
        #define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntToPy */
        static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
    const int neg_one = (int) -1, const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

/* None */
        static CYTHON_INLINE long __Pyx_pow_long(long b, long e) {
    long t = b;
    switch (e) {
        case 3:
            t *= b;
        CYTHON_FALLTHROUGH;
        case 2:
            t *= b;
        CYTHON_FALLTHROUGH;
        case 1:
            return t;
        case 0:
            return 1;
    }
    #if 1
    if (unlikely(e<0)) return 0;
    #endif
    t = 1;
    while (likely(e)) {
        t *= (b * (e&1)) | ((~e)&1);
        b *= b;
        e >>= 1;
    }
    return t;
}

/* CIntToPy */
        static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_int64(npy_int64 value) {
    const npy_int64 neg_one = (npy_int64) -1, const_zero = (npy_int64) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(npy_int64) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(npy_int64) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_int64) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(npy_int64) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_int64) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(npy_int64),
                                     little, !is_unsigned);
    }
}

/* Print */
        #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION < 3
static PyObject *__Pyx_GetStdout(void) {
    PyObject *f = PySys_GetObject((char *)"stdout");
    if (!f) {
        PyErr_SetString(PyExc_RuntimeError, "lost sys.stdout");
    }
    return f;
}
static int __Pyx_Print(PyObject* f, PyObject *arg_tuple, int newline) {
    int i;
    if (!f) {
        if (!(f = __Pyx_GetStdout()))
            return -1;
    }
    Py_INCREF(f);
    for (i=0; i < PyTuple_GET_SIZE(arg_tuple); i++) {
        PyObject* v;
        if (PyFile_SoftSpace(f, 1)) {
            if (PyFile_WriteString(" ", f) < 0)
                goto error;
        }
        v = PyTuple_GET_ITEM(arg_tuple, i);
        if (PyFile_WriteObject(v, f, Py_PRINT_RAW) < 0)
            goto error;
        if (PyString_Check(v)) {
            char *s = PyString_AsString(v);
            Py_ssize_t len = PyString_Size(v);
            if (len > 0) {
                switch (s[len-1]) {
                    case ' ': break;
                    case '\f': case '\r': case '\n': case '\t': case '\v':
                        PyFile_SoftSpace(f, 0);
                        break;
                    default:  break;
                }
            }
        }
    }
    if (newline) {
        if (PyFile_WriteString("\n", f) < 0)
            goto error;
        PyFile_SoftSpace(f, 0);
    }
    Py_DECREF(f);
    return 0;
error:
    Py_DECREF(f);
    return -1;
}
#else
static int __Pyx_Print(PyObject* stream, PyObject *arg_tuple, int newline) {
    PyObject* kwargs = 0;
    PyObject* result = 0;
    PyObject* end_string;
    if (unlikely(!__pyx_print)) {
        __pyx_print = PyObject_GetAttr(__pyx_b, __pyx_n_s_print);
        if (!__pyx_print)
            return -1;
    }
    if (stream) {
        kwargs = PyDict_New();
        if (unlikely(!kwargs))
            return -1;
        if (unlikely(PyDict_SetItem(kwargs, __pyx_n_s_file, stream) < 0))
            goto bad;
        if (!newline) {
            end_string = PyUnicode_FromStringAndSize(" ", 1);
            if (unlikely(!end_string))
                goto bad;
            if (PyDict_SetItem(kwargs, __pyx_n_s_end, end_string) < 0) {
                Py_DECREF(end_string);
                goto bad;
            }
            Py_DECREF(end_string);
        }
    } else if (!newline) {
        if (unlikely(!__pyx_print_kwargs)) {
            __pyx_print_kwargs = PyDict_New();
            if (unlikely(!__pyx_print_kwargs))
                return -1;
            end_string = PyUnicode_FromStringAndSize(" ", 1);
            if (unlikely(!end_string))
                return -1;
            if (PyDict_SetItem(__pyx_print_kwargs, __pyx_n_s_end, end_string) < 0) {
                Py_DECREF(end_string);
                return -1;
            }
            Py_DECREF(end_string);
        }
        kwargs = __pyx_print_kwargs;
    }
    result = PyObject_Call(__pyx_print, arg_tuple, kwargs);
    if (unlikely(kwargs) && (kwargs != __pyx_print_kwargs))
        Py_DECREF(kwargs);
    if (!result)
        return -1;
    Py_DECREF(result);
    return 0;
bad:
    if (kwargs != __pyx_print_kwargs)
        Py_XDECREF(kwargs);
    return -1;
}
#endif

/* Declarations */
        #if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return ::std::complex< float >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return x + y*(__pyx_t_float_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      __pyx_t_float_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

/* Arithmetic */
        #if CYTHON_CCOMPLEX
#else
    static CYTHON_INLINE int __Pyx_c_eq_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sum_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_diff_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prod_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    #if 1
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        if (b.imag == 0) {
            return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else if (fabsf(b.real) >= fabsf(b.imag)) {
            if (b.real == 0 && b.imag == 0) {
                return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.imag);
            } else {
                float r = b.imag / b.real;
                float s = 1.0 / (b.real + b.imag * r);
                return __pyx_t_float_complex_from_parts(
                    (a.real + a.imag * r) * s, (a.imag - a.real * r) * s);
            }
        } else {
            float r = b.real / b.imag;
            float s = 1.0 / (b.imag + b.real * r);
            return __pyx_t_float_complex_from_parts(
                (a.real * r + a.imag) * s, (a.imag * r - a.real) * s);
        }
    }
    #else
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        if (b.imag == 0) {
            return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else {
            float denom = b.real * b.real + b.imag * b.imag;
            return __pyx_t_float_complex_from_parts(
                (a.real * b.real + a.imag * b.imag) / denom,
                (a.imag * b.real - a.real * b.imag) / denom);
        }
    }
    #endif
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_neg_float(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero_float(__pyx_t_float_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conj_float(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE float __Pyx_c_abs_float(__pyx_t_float_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrtf(z.real*z.real + z.imag*z.imag);
          #else
            return hypotf(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_pow_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
            __pyx_t_float_complex z;
            float r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    float denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        z = __Pyx_c_prod_float(a, a);
                        return __Pyx_c_prod_float(a, a);
                    case 3:
                        z = __Pyx_c_prod_float(a, a);
                        return __Pyx_c_prod_float(z, a);
                    case 4:
                        z = __Pyx_c_prod_float(a, a);
                        return __Pyx_c_prod_float(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                } else if (b.imag == 0) {
                    z.real = powf(a.real, b.real);
                    z.imag = 0;
                    return z;
                } else if (a.real > 0) {
                    r = a.real;
                    theta = 0;
                } else {
                    r = -a.real;
                    theta = atan2f(0, -1);
                }
            } else {
                r = __Pyx_c_abs_float(a);
                theta = atan2f(a.imag, a.real);
            }
            lnr = logf(r);
            z_r = expf(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cosf(z_theta);
            z.imag = z_r * sinf(z_theta);
            return z;
        }
    #endif
#endif

/* Declarations */
        #if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return ::std::complex< double >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return x + y*(__pyx_t_double_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      __pyx_t_double_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

/* Arithmetic */
        #if CYTHON_CCOMPLEX
#else
    static CYTHON_INLINE int __Pyx_c_eq_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    #if 1
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        if (b.imag == 0) {
            return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else if (fabs(b.real) >= fabs(b.imag)) {
            if (b.real == 0 && b.imag == 0) {
                return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.imag);
            } else {
                double r = b.imag / b.real;
                double s = 1.0 / (b.real + b.imag * r);
                return __pyx_t_double_complex_from_parts(
                    (a.real + a.imag * r) * s, (a.imag - a.real * r) * s);
            }
        } else {
            double r = b.real / b.imag;
            double s = 1.0 / (b.imag + b.real * r);
            return __pyx_t_double_complex_from_parts(
                (a.real * r + a.imag) * s, (a.imag * r - a.real) * s);
        }
    }
    #else
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        if (b.imag == 0) {
            return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else {
            double denom = b.real * b.real + b.imag * b.imag;
            return __pyx_t_double_complex_from_parts(
                (a.real * b.real + a.imag * b.imag) / denom,
                (a.imag * b.real - a.real * b.imag) / denom);
        }
    }
    #endif
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg_double(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero_double(__pyx_t_double_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj_double(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs_double(__pyx_t_double_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrt(z.real*z.real + z.imag*z.imag);
          #else
            return hypot(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
            __pyx_t_double_complex z;
            double r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    double denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        z = __Pyx_c_prod_double(a, a);
                        return __Pyx_c_prod_double(a, a);
                    case 3:
                        z = __Pyx_c_prod_double(a, a);
                        return __Pyx_c_prod_double(z, a);
                    case 4:
                        z = __Pyx_c_prod_double(a, a);
                        return __Pyx_c_prod_double(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                } else if (b.imag == 0) {
                    z.real = pow(a.real, b.real);
                    z.imag = 0;
                    return z;
                } else if (a.real > 0) {
                    r = a.real;
                    theta = 0;
                } else {
                    r = -a.real;
                    theta = atan2(0, -1);
                }
            } else {
                r = __Pyx_c_abs_double(a);
                theta = atan2(a.imag, a.real);
            }
            lnr = log(r);
            z_r = exp(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cos(z_theta);
            z.imag = z_r * sin(z_theta);
            return z;
        }
    #endif
#endif

/* CIntToPy */
        static CYTHON_INLINE PyObject* __Pyx_PyInt_From_enum__NPY_TYPES(enum NPY_TYPES value) {
    const enum NPY_TYPES neg_one = (enum NPY_TYPES) -1, const_zero = (enum NPY_TYPES) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(enum NPY_TYPES) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(enum NPY_TYPES) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(enum NPY_TYPES) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(enum NPY_TYPES) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(enum NPY_TYPES) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(enum NPY_TYPES),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
        static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) -1, const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* PrintOne */
        #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION < 3
static int __Pyx_PrintOne(PyObject* f, PyObject *o) {
    if (!f) {
        if (!(f = __Pyx_GetStdout()))
            return -1;
    }
    Py_INCREF(f);
    if (PyFile_SoftSpace(f, 0)) {
        if (PyFile_WriteString(" ", f) < 0)
            goto error;
    }
    if (PyFile_WriteObject(o, f, Py_PRINT_RAW) < 0)
        goto error;
    if (PyFile_WriteString("\n", f) < 0)
        goto error;
    Py_DECREF(f);
    return 0;
error:
    Py_DECREF(f);
    return -1;
    /* the line below is just to avoid C compiler
     * warnings about unused functions */
    return __Pyx_Print(f, NULL, 0);
}
#else
static int __Pyx_PrintOne(PyObject* stream, PyObject *o) {
    int res;
    PyObject* arg_tuple = PyTuple_Pack(1, o);
    if (unlikely(!arg_tuple))
        return -1;
    res = __Pyx_Print(stream, arg_tuple, 1);
    Py_DECREF(arg_tuple);
    return res;
}
#endif

/* CIntToPy */
        static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) -1, const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
        static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) -1, const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* FastTypeChecks */
        #if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* CheckBinaryVersion */
        static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* ModuleImport */
        #ifndef __PYX_HAVE_RT_ImportModule
#define __PYX_HAVE_RT_ImportModule
static PyObject *__Pyx_ImportModule(const char *name) {
    PyObject *py_name = 0;
    PyObject *py_module = 0;
    py_name = __Pyx_PyIdentifier_FromString(name);
    if (!py_name)
        goto bad;
    py_module = PyImport_Import(py_name);
    Py_DECREF(py_name);
    return py_module;
bad:
    Py_XDECREF(py_name);
    return 0;
}
#endif

/* TypeImport */
        #ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(const char *module_name, const char *class_name,
    size_t size, int strict)
{
    PyObject *py_module = 0;
    PyObject *result = 0;
    PyObject *py_name = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    py_module = __Pyx_ImportModule(module_name);
    if (!py_module)
        goto bad;
    py_name = __Pyx_PyIdentifier_FromString(class_name);
    if (!py_name)
        goto bad;
    result = PyObject_GetAttr(py_module, py_name);
    Py_DECREF(py_name);
    py_name = 0;
    Py_DECREF(py_module);
    py_module = 0;
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if (!strict && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. Expected %zd, got %zd",
            module_name, class_name, basicsize, size);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    else if ((size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s has the wrong size, try recompiling. Expected %zd, got %zd",
            module_name, class_name, basicsize, size);
        goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(py_module);
    Py_XDECREF(result);
    return NULL;
}
#endif

/* InitStrings */
        static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            PyErr_Clear();
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(x);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
